@@ -23,30 +23,9 @@
  */
 package net.sf.jasperreports.charts.util;
 
-import java.awt.geom.Rectangle2D;
-
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
-import net.sf.jasperreports.engine.JasperReportsContext;
-
-import org.jfree.chart.JFreeChart;
-
-
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
  */
 public abstract class AbstractChartRenderableFactory implements ChartRenderableFactory
 {
-	
-	/**
-	 * @deprecated Replaced by {@link #getRenderable(JasperReportsContext, JFreeChart, ChartHyperlinkProvider, Rectangle2D)}.
-	 */
-	public final net.sf.jasperreports.engine.JRRenderable getRenderer(
-		JFreeChart chart, 
-		ChartHyperlinkProvider chartHyperlinkProvider, 
-		Rectangle2D rectangle
-		)
-	{
-		return getRenderable(DefaultJasperReportsContext.getInstance(), chart, chartHyperlinkProvider, rectangle);
-	}
-
 }
