@@ -34,9 +34,7 @@ import org.xml.sax.Attributes;
  */
 public class JRDataRangeFactory extends JRBaseFactory
 {
-	/**
-	 *
-	 */
+	@Override
 	public Object createObject(Attributes atts)
 	{
 		return new JRDesignDataRange(null);
