@@ -43,15 +43,15 @@ import net.sf.jasperreports.components.barcode4j.UPCAComponent;
 import net.sf.jasperreports.components.barcode4j.UPCEComponent;
 import net.sf.jasperreports.components.barcode4j.USPSIntelligentMailComponent;
 import net.sf.jasperreports.components.iconlabel.IconLabelComponentDigester;
+import net.sf.jasperreports.components.items.Item;
+import net.sf.jasperreports.components.items.ItemData;
+import net.sf.jasperreports.components.items.ItemDataXmlFactory;
+import net.sf.jasperreports.components.items.ItemDatasetFactory;
+import net.sf.jasperreports.components.items.ItemProperty;
+import net.sf.jasperreports.components.items.ItemPropertyXmlFactory;
+import net.sf.jasperreports.components.items.ItemXmlFactory;
 import net.sf.jasperreports.components.list.DesignListContents;
 import net.sf.jasperreports.components.list.StandardListComponent;
-import net.sf.jasperreports.components.map.Item;
-import net.sf.jasperreports.components.map.ItemData;
-import net.sf.jasperreports.components.map.ItemDataXmlFactory;
-import net.sf.jasperreports.components.map.ItemDatasetFactory;
-import net.sf.jasperreports.components.map.ItemProperty;
-import net.sf.jasperreports.components.map.ItemPropertyXmlFactory;
-import net.sf.jasperreports.components.map.ItemXmlFactory;
 import net.sf.jasperreports.components.map.MapXmlFactory;
 import net.sf.jasperreports.components.sort.SortComponentDigester;
 import net.sf.jasperreports.components.spiderchart.SpiderChartDigester;
@@ -84,6 +84,7 @@ import org.apache.commons.digester.Digester;
  */
 public class ComponentsXmlDigesterConfigurer implements XmlDigesterConfigurer
 {
+	@Override
 	public void configureDigester(Digester digester)
 	{
 		addListRules(digester);
