@@ -29,11 +29,11 @@ import java.util.List;
 import net.sf.jasperreports.components.barbecue.BarbecueComponent;
 import net.sf.jasperreports.components.barcode4j.BarcodeComponent;
 import net.sf.jasperreports.components.barcode4j.BarcodeXmlWriter;
+import net.sf.jasperreports.components.items.Item;
+import net.sf.jasperreports.components.items.ItemData;
+import net.sf.jasperreports.components.items.ItemProperty;
 import net.sf.jasperreports.components.list.ListComponent;
 import net.sf.jasperreports.components.list.ListContents;
-import net.sf.jasperreports.components.map.Item;
-import net.sf.jasperreports.components.map.ItemData;
-import net.sf.jasperreports.components.map.ItemProperty;
 import net.sf.jasperreports.components.map.MapComponent;
 import net.sf.jasperreports.components.map.MapXmlFactory;
 import net.sf.jasperreports.components.map.type.MapImageTypeEnum;
@@ -81,6 +81,7 @@ public class ComponentsXmlWriter extends AbstractComponentXmlWriter
 		super(jasperReportsContext);
 	}
 
+	@Override
 	public void writeToXml(JRComponentElement componentElement, JRXmlWriter reportWriter) throws IOException
 	{
 		Component component = componentElement.getComponent();
@@ -428,6 +429,7 @@ public class ComponentsXmlWriter extends AbstractComponentXmlWriter
 		
 		ColumnVisitor<Void> columnWriter = new ColumnVisitor<Void>()
 		{
+			@Override
 			public Void visitColumn(Column column)
 			{
 				try
@@ -463,6 +465,7 @@ public class ComponentsXmlWriter extends AbstractComponentXmlWriter
 				return null;
 			}
 
+			@Override
 			public Void visitColumnGroup(ColumnGroup columnGroup)
 			{
 				try
