@@ -69,6 +69,8 @@ import net.sf.jasperreports.engine.JRGenericPrintElement;
 import net.sf.jasperreports.engine.JRIdentifiable;
 import net.sf.jasperreports.engine.JRPropertiesMap;
 import net.sf.jasperreports.engine.JRSortField;
+import net.sf.jasperreports.engine.JRStyle;
+import net.sf.jasperreports.engine.JRStyleContainer;
 import net.sf.jasperreports.engine.JRVariable;
 import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.JasperReportsContext;
@@ -114,7 +116,9 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 
 	private static final List<String> datePatterns = new ArrayList<String>(); 
 	private static final List<String> timePatterns = new ArrayList<String>(); 
-	private static final Map<String, String> numberPatternsMap = new LinkedHashMap<String, String>(); 
+	private static final Map<String, String> numberPatternsMap = new LinkedHashMap<String, String>();
+
+	private static final String DURATION_PATTERN = "[h]:mm:ss";
 	
 	static {
 		// date patterns
@@ -150,10 +154,12 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 		numberPatternsMap.put("###0;(###0)", "(1234)");
 		numberPatternsMap.put("###0;(-###0)", "(-1234)");
 		numberPatternsMap.put("###0;(###0-)", "(1234-)");
+		numberPatternsMap.put(DURATION_PATTERN, "[h]:mm:ss");
 	}
 	
 	private static final String TABLE_UUID = "exporter_first_attempt";
 
+	@Override
 	public String getJsonFragment(JsonExporterContext context, JRGenericPrintElement element)
 	{
 		boolean templateAlreadyLoaded = false;
@@ -229,7 +235,7 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 			if (!tableUUID.equals(context.getValue(TABLE_UUID))) 
 			{
 				Map<String, ColumnInfo> columnNames = getAllColumnNames(element, jrContext, contextMap);
-				List<Map<String, Object>> columnGroupsData = getColumnGroupsData(jrContext, jasperDesign, dataset, table, tableUUID, locale, timeZone);
+				List<Map<String, Object>> columnGroupsData = getColumnGroupsData(jrContext, reportContext, target, jasperDesign, dataset, table, tableUUID, locale, timeZone);
 				// column names are normally set on the first column, but check if we got them
 				if (!columnNames.isEmpty()) {
 					context.setValue(TABLE_UUID, tableUUID);
@@ -296,8 +302,8 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 			contextMap.put("fontExtensionsFontNames", getFontExtensionsFontNames(jrContext));
 			contextMap.put("systemFontNames", getSystemFontNames(jrContext));
 
-			setColumnHeaderData(columnLabel, columnIndex, tableUUID, contextMap, jrContext, reportContext, locale);
-			setColumnValueData(columnIndex, tableUUID, contextMap, jrContext, reportContext, locale);
+			setColumnHeaderData(columnLabel, columnIndex, target, contextMap, jrContext, reportContext, locale);
+			EditTextElementData columnValueData = setColumnValueData(columnIndex, target, contextMap, jrContext, reportContext, locale);
 
 			String columnName = element.getPropertiesMap().getProperty(HeaderToolbarElement.PROPERTY_COLUMN_NAME);
 			String columnComponentName = element.getPropertiesMap().getProperty(HeaderToolbarElement.PROPERTY_COLUMN_COMPONENT_NAME);
@@ -311,7 +317,7 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 
 			if (canFilter)
 			{
-				FilterData filterData = getFilterData(jrContext, dataset, tableUUID, columnName, columnType, filterType,
+				FilterData filterData = getFilterData(jrContext, dataset, columnName, columnType, filterType, columnValueData.getFormatPattern(),
 						locale, timeZone);
 
 				contextMap.put("dataType", filterType.getName());
@@ -466,6 +472,7 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 		return null;
 	}
 	
+	@Override
 	public boolean toExport(JRGenericPrintElement element) {
 		return true;
 	}
@@ -496,10 +503,10 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 	private static FilterData getFilterData(
 		JasperReportsContext jasperReportsContext,
 		JRDesignDataset dataset,
-		String tableUuid,
 		String columnName,
 		String columnType,
 		FilterTypesEnum filterType,
+		String columnValuePattern,
 		Locale locale,
 		TimeZone timeZone
 		) 
@@ -544,6 +551,10 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 		{
 			String filterPattern = HeaderToolbarElementUtils.getFilterPattern(jasperReportsContext, locale, filterType);
 
+			if (FilterTypesEnum.NUMERIC.equals(filterType) && DURATION_PATTERN.equals(columnValuePattern)) {
+				filterPattern = DURATION_PATTERN;
+			}
+
 			HeaderToolbarElementUtils.updateFilterData(
 				filterData,
 				filterPattern,
@@ -559,13 +570,8 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 		return filterData;
 	}
 
-	private void setColumnHeaderData(String sortColumnLabel, Integer columnIndex, String tableUuid, Map<String, Object> contextMap,
+	private void setColumnHeaderData(String sortColumnLabel, Integer columnIndex, CommandTarget target, Map<String, Object> contextMap,
 			JasperReportsContext jasperReportsContext, ReportContext reportContext, Locale locale) {
-		FilterAction action = new FilterAction();
-		action.init(jasperReportsContext, reportContext);
-		CommandTarget target = action.getCommandTarget(UUID.fromString(tableUuid));
-		EditTextElementData textElementData = new EditTextElementData();
-
 		if (target != null){
 			JRIdentifiable identifiable = target.getIdentifiable();
 			JRDesignComponentElement componentElement = identifiable instanceof JRDesignComponentElement ? (JRDesignComponentElement)identifiable : null;
@@ -579,41 +585,135 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 				JRDesignTextElement textElement = TableUtil.getCellElement(JRDesignTextElement.class, column.getColumnHeader(), true);
 
 				if (textElement != null) {
+					EditTextElementData textElementData = new EditTextElementData();
+
 					textElementData.setHeadingName(JRStringUtil.htmlEncode(sortColumnLabel));
 					textElementData.setColumnIndex(columnIndex);
-					HeaderToolbarElementUtils.copyTextElementStyle(textElementData, textElement, locale);
+					JRDesignTextElement styledElement = resolveElementStyle(textElement, reportContext, target);
+					HeaderToolbarElementUtils.copyTextElementStyle(textElementData, styledElement, locale);
+
+					contextMap.put("colHeaderData", JacksonUtil.getInstance(jasperReportsContext).getJsonString(textElementData));
 				}
 			}
 		}
-		contextMap.put("colHeaderData", JacksonUtil.getInstance(jasperReportsContext).getJsonString(textElementData));
 	}
 	
-	private void setColumnValueData(Integer columnIndex, String tableUuid, Map<String, Object> contextMap,
-			JasperReportsContext jasperReportsContext, ReportContext reportContext, Locale locale) {
-		FilterAction action = new FilterAction();
-		action.init(jasperReportsContext, reportContext);
-		CommandTarget target = action.getCommandTarget(UUID.fromString(tableUuid));
-		EditTextElementData textElementData = new EditTextElementData();
+	private JRDesignTextElement resolveElementStyle(JRDesignTextElement element, ReportContext context, 
+			CommandTarget target)
+	{
+		JRStyle defaultStyle = element.getDefaultStyleProvider() == null ? null 
+				: element.getDefaultStyleProvider().getDefaultStyle();
+		boolean hasExternalStyle = hasExternalStyle(element) 
+				|| (defaultStyle != null && hasExternalStyle(defaultStyle));
+		if (!hasExternalStyle && defaultStyle != null)
+		{
+			//we have everything
+			return element;
+		}
 		
+		JasperDesignCache designCache = JasperDesignCache.getExistingInstance(context);
+		List<JRStyle> reportStyles = designCache == null ? null : designCache.getStyles(
+				target.getUri(), target.getIdentifiable() == null ? null : target.getIdentifiable().getUUID());
+		if (reportStyles == null || reportStyles.isEmpty())
+		{
+			return element;
+		}
+		
+		JRStyle externalDefault = null;
+		if (defaultStyle == null)
+		{
+			for (JRStyle style : reportStyles)
+			{
+				if (style.isDefault())
+				{
+					externalDefault = style;
+				}
+			}
+			
+			if (!hasExternalStyle && externalDefault == null)
+			{
+				//nothing to change
+				return element;
+			}
+		}
+		
+		JRStyle elementStyle;
+		if (element.getStyle() == null && element.getStyleNameReference() == null)
+		{
+			elementStyle = externalDefault;
+		}
+		else
+		{
+			String elementStyleName = element.getStyleNameReference() == null 
+					? element.getStyle().getName() : element.getStyleNameReference();
+					
+			elementStyle = null;
+			for (JRStyle style : reportStyles)
+			{
+				if (style.getName().equals(elementStyleName))
+				{
+					elementStyle = style;
+				}
+			}
+		}
+		
+		if (elementStyle == null)
+		{
+			//didn't find a style for the element
+			return element;
+		}
+		
+		JRDesignTextElement elementClone = (JRDesignTextElement) element.clone();
+		elementClone.setStyle(elementStyle);
+		return elementClone;
+	}
+	
+	private boolean hasExternalStyle(JRStyleContainer styleContainer)
+	{
+		if (styleContainer.getStyle() == null && styleContainer.getStyleNameReference() != null)
+		{
+			return true;
+		}
+		
+		JRStyle style = styleContainer.getStyle();
+		while (style != null)
+		{
+			if (style.getStyle() == null && style.getStyleNameReference() != null)
+			{
+				return true;
+			}
+			
+			style = style.getStyle();
+		}
+		return false;
+	}
+	
+	private EditTextElementData setColumnValueData(Integer columnIndex, CommandTarget target, Map<String, Object> contextMap,
+			JasperReportsContext jasperReportsContext, ReportContext reportContext, Locale locale) {
+		EditTextElementData textElementData = new EditTextElementData();
+
 		if (target != null){
 			JRIdentifiable identifiable = target.getIdentifiable();
 			JRDesignComponentElement componentElement = identifiable instanceof JRDesignComponentElement ? (JRDesignComponentElement)identifiable : null;
 			StandardTable table = componentElement == null ? null : (StandardTable)componentElement.getComponent();
-			
+
 			List<BaseColumn> tableColumns = TableUtil.getAllColumns(table);
-			
+
 			if (columnIndex != null) {
 				StandardColumn column = (StandardColumn) tableColumns.get(columnIndex);
-				
+
 				JRDesignTextField textElement = TableUtil.getCellElement(JRDesignTextField.class, column.getDetailCell(), true);
-				
+
 				if (textElement != null) {
 					textElementData.setColumnIndex(columnIndex);
-					HeaderToolbarElementUtils.copyTextElementStyle(textElementData, textElement, locale);
+					JRDesignTextElement styledElement = resolveElementStyle(textElement, reportContext, target);
+					HeaderToolbarElementUtils.copyTextElementStyle(textElementData, styledElement, locale);
 				}
 			}
 		}
 		contextMap.put("colValueData", JacksonUtil.getInstance(jasperReportsContext).getJsonString(textElementData));
+
+		return textElementData;
 	}
 
 	public static class ColumnInfo {
@@ -723,7 +823,8 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 		return result;
 	}
 
-	private List<Map<String, Object>> getColumnGroupsData(JasperReportsContext jasperReportsContext, JasperDesign jasperDesign,
+	private List<Map<String, Object>> getColumnGroupsData(JasperReportsContext jasperReportsContext, 
+			ReportContext reportContext, CommandTarget target, JasperDesign jasperDesign,
 			JRDesignDataset dataset, StandardTable table, String tableUuid, Locale locale, TimeZone timeZone)
 	{
 		List<BaseColumn> allColumns = TableUtil.getAllColumns(table);
@@ -814,12 +915,14 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 			EditTextElementData textElementData;
 			textElementData = new EditTextElementData();
 			textElementData.setGroupName(groupInfo.getName());
-			HeaderToolbarElementUtils.copyTextElementStyle(textElementData, textElement, locale);
+			JRDesignTextElement styledElement = resolveElementStyle(textElement, reportContext, target);
+			HeaderToolbarElementUtils.copyTextElementStyle(textElementData, styledElement, locale);
 
 			Map<String, Object> groupData = new HashMap<String, Object>();
-			groupData.put("grouptype", groupInfo.getType());
+			groupData.put("groupType", groupInfo.getType());
 			groupData.put("id", groupInfo.getType() + "_" + i);
 			groupData.put("groupData", textElementData);
+			groupData.put("groupName", groupInfo.getName());
 			groupData.put("forColumns", groupInfo.getForColumns());
 
 			JRDesignTextField textField = textElement instanceof JRDesignTextField ? (JRDesignTextField)textElement : null;
@@ -838,10 +941,13 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 			
 			if (cfData != null) 
 			{
-				textElementData.setDataType(cfData.getConditionType());
-
+				groupData.put("dataType", cfData.getConditionType());
 				groupData.put("conditionalFormattingData", cfData);
 			}
+			else
+			{
+				groupData.put("dataType", FilterTypesEnum.TEXT.getName());
+			}
 
 			groupsData.add(groupData);
 
@@ -934,6 +1040,10 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 			{
 				String conditionPattern = HeaderToolbarElementUtils.getFilterPattern(jasperReportsContext, locale, conditionType);
 
+				if (FilterTypesEnum.NUMERIC.equals(conditionType) && DURATION_PATTERN.equals(textField.getPattern())) {
+					conditionPattern = DURATION_PATTERN;
+				}
+
 				HeaderToolbarElementUtils.updateConditionalFormattingData(
 					cfd,
 					conditionPattern,
@@ -953,7 +1063,7 @@ public class HeaderToolbarElementJsonHandler implements GenericElementJsonHandle
 	private Set<String> getFontExtensionsFontNames(JasperReportsContext jasperReportsContext) {
 		Set<String> classes = new TreeSet<String>(); 
 
-		Collection<String> extensionFonts = FontUtil.getInstance(jasperReportsContext).getFontFamilyNames();
+		Collection<String> extensionFonts = FontUtil.getInstance(jasperReportsContext).getFontNames();
 		for (Iterator<String> it = extensionFonts.iterator(); it.hasNext();) {
 			String fname = it.next();
 			classes.add(fname);
