@@ -23,22 +23,12 @@
  */
 package net.sf.jasperreports.components.map;
 
-import net.sf.jasperreports.engine.xml.JRBaseFactory;
-
-import org.xml.sax.Attributes;
 
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
+ * @deprecated Replaced by {@link net.sf.jasperreports.components.items.ItemXmlFactory}.
  */
-public class ItemXmlFactory extends JRBaseFactory
+public class ItemXmlFactory extends net.sf.jasperreports.components.items.ItemXmlFactory
 {
-
-	/**
-	 *
-	 */
-	public Object createObject(Attributes atts)
-	{
-		return new StandardItem();
-	}
 }
