@@ -53,6 +53,7 @@ import net.sf.jasperreports.engine.component.BaseFillComponent;
 import net.sf.jasperreports.engine.component.FillPrepareResult;
 import net.sf.jasperreports.engine.design.JRAbstractCompiler;
 import net.sf.jasperreports.engine.design.JRReportCompileData;
+import net.sf.jasperreports.engine.export.JRPdfExporterTagHelper;
 import net.sf.jasperreports.engine.fill.JRFillCloneFactory;
 import net.sf.jasperreports.engine.fill.JRFillComponentElement;
 import net.sf.jasperreports.engine.fill.JRFillContext;
@@ -113,6 +114,7 @@ public class FillTable extends BaseFillComponent
 		this.printFrameTemplates = table.printFrameTemplates;
 	}
 
+	@Override
 	public void evaluate(byte evaluation) throws JRException
 	{
 		if (filling)
@@ -216,6 +218,7 @@ public class FillTable extends BaseFillComponent
 			this.evaluation = evaluation;
 		}
 
+		@Override
 		public FillColumn visitColumn(Column column)
 		{
 			try
@@ -234,6 +237,7 @@ public class FillTable extends BaseFillComponent
 			}
 		}
 
+		@Override
 		public FillColumn visitColumnGroup(ColumnGroup columnGroup)
 		{
 			try
@@ -401,6 +405,7 @@ public class FillTable extends BaseFillComponent
 		return tableReportCompileData;
 	}
 	
+	@Override
 	public FillPrepareResult prepare(int availableHeight)
 	{
 		try
@@ -413,12 +418,19 @@ public class FillTable extends BaseFillComponent
 			
 			JRTemplatePrintFrame printFrame = new JRTemplatePrintFrame(getFrameTemplate(), printElementOriginator);
 			JRLineBox lineBox = printFrame.getLineBox();
-
+			int verticalPadding = lineBox.getTopPadding() + lineBox.getBottomPadding();
+			
 			FillPrepareResult result = 
 				fillSubreport.prepareSubreport(
-					availableHeight - lineBox.getTopPadding() - lineBox.getBottomPadding(), 
+					availableHeight - verticalPadding, 
 					filling
 					);
+			
+			if (verticalPadding != 0)
+			{
+				result = result.addStretch(verticalPadding);
+			}
+			
 			filling = result.willOverflow();
 			return result;
 		}
@@ -428,6 +440,7 @@ public class FillTable extends BaseFillComponent
 		}
 	}
 
+	@Override
 	public JRPrintElement fill()
 	{
 		JRTemplatePrintFrame printFrame = new JRTemplatePrintFrame(getFrameTemplate(), printElementOriginator);
@@ -440,6 +453,10 @@ public class FillTable extends BaseFillComponent
 		printFrame.setY(fillContext.getElementPrintY());
 		printFrame.setWidth(fillWidth + lineBox.getLeftPadding() + lineBox.getRightPadding());
 		printFrame.setHeight(fillSubreport.getContentsStretchHeight() + lineBox.getTopPadding() + lineBox.getBottomPadding());
+		if (fillSubreport.getTableReport().getBaseReport().isGeneratePdfTags())
+		{
+			printFrame.getPropertiesMap().setProperty(JRPdfExporterTagHelper.PROPERTY_TAG_TABLE, JRPdfExporterTagHelper.TAG_FULL);
+		}
 		
 		List<JRStyle> styles = fillSubreport.getSubreportStyles();
 		for (Iterator<JRStyle> it = styles.iterator(); it.hasNext();)
