@@ -93,6 +93,7 @@ import net.sf.jasperreports.engine.design.JRDesignGroup;
 import net.sf.jasperreports.engine.design.JRDesignSection;
 import net.sf.jasperreports.engine.design.JRDesignTextField;
 import net.sf.jasperreports.engine.export.HtmlExporter;
+import net.sf.jasperreports.engine.export.JRPdfExporterTagHelper;
 import net.sf.jasperreports.engine.export.MatcherExporterFilter;
 import net.sf.jasperreports.engine.fill.DatasetExpressionEvaluator;
 import net.sf.jasperreports.engine.fill.JRExpressionEvalException;
@@ -112,7 +113,9 @@ import net.sf.jasperreports.engine.type.StretchTypeEnum;
 import net.sf.jasperreports.engine.type.WhenNoDataTypeEnum;
 import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 import net.sf.jasperreports.engine.util.JRDataUtils;
+import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.Pair;
+import net.sf.jasperreports.engine.util.StyleResolver;
 import net.sf.jasperreports.engine.util.StyleUtil;
 import net.sf.jasperreports.web.util.JacksonUtil;
 
@@ -161,7 +164,24 @@ public class TableReport implements JRReport
 	 * <p>
 	 * The default global value of this property is <code>true</code>
 	 */
-	private static final String PROPERTY_INTERACTIVE_TABLE = JRPropertiesUtil.PROPERTY_PREFIX + "components.table.interactive";
+	public static final String PROPERTY_INTERACTIVE_TABLE = JRPropertiesUtil.PROPERTY_PREFIX + "components.table.interactive";
+
+	/**
+	 * Property that enables/disables the automatic addition of specific custom properties to table cell elements,
+	 * that would in turn trigger the creation of special document accessibility tags during PDF export
+	 * 
+	 * <p>
+	 * The property can be set:
+	 * <ul>
+	 * 	<li>globally</li>
+	 * 	<li>at report level</li>
+	 * 	<li>at component level</li>
+	 * </ul>
+	 * 
+	 * <p>
+	 * The default global value of this property is <code>false</code>
+	 */
+	public static final String PROPERTY_GENERATE_TABLE_PDF_TAGS = JRPropertiesUtil.PROPERTY_PREFIX + "components.table.generate.pdf.tags";
 
 	/**
 	 * Column property that specifies the field to be used for sorting, filtering and conditional formatting 
@@ -227,6 +247,7 @@ public class TableReport implements JRReport
 	
 	private final JRPropertiesUtil propertiesUtil;
 	private boolean isInteractiveTable;
+	private boolean isGeneratePdfTags;
 	private Map<Column, Pair<Boolean, String>> columnInteractivityMapping;
 	
 	public TableReport(
@@ -274,6 +295,7 @@ public class TableReport implements JRReport
 		}
 		// end: table interactivity
 		
+		this.isGeneratePdfTags  = Boolean.valueOf(propertiesUtil.getProperty(PROPERTY_GENERATE_TABLE_PDF_TAGS, fillContext.getComponentElement(), this.parentReport));
 		
 		this.columnHeader = createColumnHeader(fillColumns);
 		this.detail = wrapBand(createDetailBand(fillColumns), new JROrigin(BandTypeEnum.DETAIL));
@@ -305,35 +327,115 @@ public class TableReport implements JRReport
 	protected class ReportBandInfo
 	{
 		final JRDesignBand band;
-		final List<JRDesignElementGroup> rowGroups = new ArrayList<JRDesignElementGroup>();
+		final List<BandRowInfo> rows = new ArrayList<BandRowInfo>();
 		
 		ReportBandInfo(JRDesignBand band)
 		{
 			this.band = band;
 		}
 
-		protected void elementAdded(JRElement element)
+		protected void cellAdded(int rowLevel, CellInfo cell)
 		{
+			JRElement element = cell.getElement();
 			if (band.getHeight() < element.getHeight() + element.getY())
 			{
 				band.setHeight(element.getHeight() + element.getY());
 			}
+			
+			BandRowInfo row = getBandRowInfo(rowLevel);
+			
+			row.addCell(cell);
 		}
 		
 		JRDesignElementGroup getRowElementGroup(int rowLevel)
 		{
-			int rowCount = rowGroups.size();
+			BandRowInfo row = getBandRowInfo(rowLevel);
+			JRDesignElementGroup elementGroup = row.getElementGroup();
+			if (elementGroup == null)
+			{
+				elementGroup = new JRDesignElementGroup();
+				row.setElementGroup(elementGroup);
+				band.addElementGroup(elementGroup);
+			}
+			return elementGroup;
+		}
+		
+		BandRowInfo getBandRowInfo(int rowLevel)
+		{
+			int rowCount = rows.size();
 			if (rowLevel >= rowCount)
 			{
 				for (int level = rowCount; level <= rowLevel; ++level)
 				{
-					JRDesignElementGroup group = new JRDesignElementGroup();
-					band.addElementGroup(group);
-					rowGroups.add(group);
+					rows.add(new BandRowInfo());
 				}
 			}
 			
-			return rowGroups.get(rowLevel);
+			return rows.get(rowLevel);
+		}
+		
+		List<BandRowInfo> getRows()
+		{
+			return rows;
+		}
+	}
+
+	protected class BandRowInfo
+	{
+		JRDesignElementGroup elementGroup;
+		List<CellInfo> cells = new ArrayList<CellInfo>();
+		
+		BandRowInfo()
+		{
+		}
+
+		protected JRDesignElementGroup getElementGroup()
+		{
+			return elementGroup;
+		}
+
+		protected void setElementGroup(JRDesignElementGroup elementGroup)
+		{
+			this.elementGroup = elementGroup;
+		}
+		
+		protected List<CellInfo> getCells()
+		{
+			return cells;
+		}
+		
+		protected void addCell(CellInfo cell)
+		{
+			cells.add(cell);
+		}
+	}
+
+	protected class CellInfo
+	{
+		final JRElement element;
+		final int rowSpan;
+		final int colSpan;
+		
+		CellInfo(JRElement element, int rowSpan, int colSpan)
+		{
+			this.element = element;
+			this.rowSpan = rowSpan;
+			this.colSpan = colSpan;
+		}
+
+		protected JRElement getElement()
+		{
+			return element;
+		}
+		
+		protected int getRowSpan()
+		{
+			return rowSpan;
+		}
+		
+		protected int getColSpan()
+		{
+			return colSpan;
 		}
 	}
 
@@ -360,6 +462,7 @@ public class TableReport implements JRReport
 			return cell == null;
 		}
 		
+		@Override
 		public Void visitColumn(Column column)
 		{
 			Cell cell = columnCell(column);
@@ -372,7 +475,7 @@ public class TableReport implements JRReport
 				
 				JRElement cellElement = createColumnCell(column, elementGroup, cell);
 				elementGroup.addElement(cellElement);
-				bandInfo.elementAdded(cellElement);
+				bandInfo.cellAdded(level, new CellInfo(cellElement, rowSpan, fillColumn.getColSpan()));
 				
 				yOffset += cell.getHeight();
 			}
@@ -396,6 +499,7 @@ public class TableReport implements JRReport
 					xOffset, yOffset, column.hashCode(), forceFrame);
 		}
 		
+		@Override
 		public Void visitColumnGroup(ColumnGroup columnGroup)
 		{
 			Cell cell = columnGroupCell(columnGroup);
@@ -405,11 +509,19 @@ public class TableReport implements JRReport
 			{
 				int rowSpan = cell.getRowSpan() == null ? 1 : cell.getRowSpan();
 				int rowLevel = level + rowSpan - 1;
+
+				int colSpan = 0;
+				for (FillColumn subcolumn : fillColumn.getSubcolumns())
+				{
+					colSpan += subcolumn.getColSpan();
+				}
+				colSpan = colSpan == 0 ? 1 : colSpan;
+				
 				JRDesignElementGroup elementGroup = bandInfo.getRowElementGroup(rowLevel);
 				
 				JRElement cellElement = createColumnGroupCell(columnGroup, cell, elementGroup);
 				elementGroup.addElement(cellElement);
-				bandInfo.elementAdded(cellElement);
+				bandInfo.cellAdded(level, new CellInfo(cellElement, rowSpan, colSpan));
 				
 				cellHeight = cell.getHeight();
 				sublevel += rowSpan;
@@ -473,6 +585,8 @@ public class TableReport implements JRReport
 			int origXOffset = xOffset;
 			int origYOffset = yOffset;
 			
+			int colSpan = 0;
+			
 			for (FillColumn subcolumn : fillColumn.getSubcolumns())
 			{
 				ReportBandCreator subVisitor = createSubVisitor(subcolumn, 
@@ -483,8 +597,11 @@ public class TableReport implements JRReport
 				{
 					yOffset = subVisitor.yOffset;
 				}
+				colSpan += subcolumn.getColSpan();
 			}
 			
+			colSpan = colSpan == 0 ? 1 : colSpan; 
+			
 			if (cell != null)
 			{
 				int rowLevel = level + rowSpan - 1;
@@ -494,7 +611,7 @@ public class TableReport implements JRReport
 						columnGroup.getWidth(), fillColumn.getWidth(), 
 						origXOffset, yOffset, null, false);
 				elementGroup.addElement(cellElement);
-				bandInfo.elementAdded(cellElement);
+				bandInfo.cellAdded(level, new CellInfo(cellElement, rowSpan, colSpan));
 				
 				yOffset += cell.getHeight();
 			}
@@ -560,6 +677,8 @@ public class TableReport implements JRReport
 			subVisitor.visit();
 			xOffset = subVisitor.xOffset;
 		}
+
+		setPdfTags(bandInfo, false);
 		
 		return detailBand;
 	}
@@ -826,7 +945,7 @@ public class TableReport implements JRReport
 				frame.getPropertiesMap().setProperty(HeaderToolbarElement.PROPERTY_TABLE_UUID, fillContext.getComponentElement().getUUID().toString());
 				frame.getPropertiesMap().setProperty(HeaderToolbarElement.PROPERTY_COLUMN_INDEX, String.valueOf(columnIndex));
 
-				String cellIdFixedPart = cellId + "_";
+				String cellIdFixedPart = JRStringUtil.getCSSClass(cellId + "_");
 				TableIndexProperties cellIdProperties = new TableIndexProperties(
 						HeaderToolbarElement.PROPERTY_CELL_ID, cellIdFixedPart);
 				tableIndexProperties.add(cellIdProperties);
@@ -993,6 +1112,8 @@ public class TableReport implements JRReport
 			subVisitor.visit();
 			xOffset = subVisitor.xOffset;
 		}
+
+		setPdfTags(bandInfo, true);
 		
 		if (columnHeader.getHeight() == 0)
 		{
@@ -1044,6 +1165,8 @@ public class TableReport implements JRReport
 			xOffset = subVisitor.xOffset;
 		}
 		
+		setPdfTags(bandInfo, false);
+
 		if (pageFooter.getHeight() == 0)
 		{
 			pageFooter = null;
@@ -1093,6 +1216,8 @@ public class TableReport implements JRReport
 			subVisitor.visit();
 			xOffset = subVisitor.xOffset;
 		}
+
+		setPdfTags(bandInfo, false);
 		
 		if (title.getHeight() == 0)
 		{
@@ -1144,6 +1269,8 @@ public class TableReport implements JRReport
 			xOffset = subVisitor.xOffset;
 		}
 		
+		setPdfTags(bandInfo, false);
+
 		if (summary.getHeight() == 0)
 		{
 			summary = null;
@@ -1200,6 +1327,8 @@ public class TableReport implements JRReport
 			xOffset = subVisitor.xOffset;
 		}
 		
+		setPdfTags(bandInfo, false);
+		
 		if (header.getHeight() == 0)
 		{
 			header = null;
@@ -1255,6 +1384,8 @@ public class TableReport implements JRReport
 			subVisitor.visit();
 			xOffset = subVisitor.xOffset;
 		}
+
+		setPdfTags(bandInfo, false);
 		
 		if (footer.getHeight() == 0)
 		{
@@ -1286,6 +1417,50 @@ public class TableReport implements JRReport
 		
 	}
 
+	private void setPdfTags(ReportBandInfo bandInfo, boolean isHeader)
+	{
+		if (!isGeneratePdfTags)
+		{
+			return;
+		}
+		
+		String cellTagProp = isHeader ? JRPdfExporterTagHelper.PROPERTY_TAG_TH : JRPdfExporterTagHelper.PROPERTY_TAG_TD;
+
+		List<BandRowInfo> rows = bandInfo.getRows();
+		
+		for (BandRowInfo row : rows)
+		{
+			List<CellInfo> cells = row.getCells();
+			CellInfo firstCell = cells.get(0);
+			firstCell.getElement().getPropertiesMap().setProperty(JRPdfExporterTagHelper.PROPERTY_TAG_TR, JRPdfExporterTagHelper.TAG_START);
+			
+			for (CellInfo cell : cells)
+			{
+				cell.getElement().getPropertiesMap().setProperty(cellTagProp, JRPdfExporterTagHelper.TAG_FULL);
+				if (cell.getRowSpan() > 1)
+				{
+					cell.getElement().getPropertiesMap().setProperty(JRPdfExporterTagHelper.PROPERTY_TAG_ROWSPAN, String.valueOf(cell.getRowSpan()));
+				}
+				if (cell.getColSpan() > 1)
+				{
+					cell.getElement().getPropertiesMap().setProperty(JRPdfExporterTagHelper.PROPERTY_TAG_COLSPAN, String.valueOf(cell.getColSpan()));
+				}
+			}
+			
+			CellInfo lastCell = cells.get(cells.size() - 1);
+			lastCell.getElement().getPropertiesMap().setProperty(
+				JRPdfExporterTagHelper.PROPERTY_TAG_TR, 
+				cells.size() == 1 ? JRPdfExporterTagHelper.TAG_FULL : JRPdfExporterTagHelper.TAG_END
+				);
+		}		
+	}
+
+	protected boolean isGeneratePdfTags()
+	{
+		return isGeneratePdfTags;
+	}
+
+	
 	protected static final String TABLE_SCRIPTLET_NAME = "__Table";
 	
 	protected class SummaryGroupFooterPrintWhenEvaluator implements BuiltinExpressionEvaluator
@@ -1294,6 +1469,7 @@ public class TableReport implements JRReport
 		private JRValueParameter tableScriptletParam;
 		private TableReportScriptlet tableScriptlet;
 		
+		@Override
 		public void init(Map<String, JRFillParameter> parametersMap, 
 				Map<String, JRFillField> fieldsMap, 
 				Map<String, JRFillVariable> variablesMap, 
@@ -1312,18 +1488,21 @@ public class TableReport implements JRReport
 			}
 		}
 		
+		@Override
 		public Object evaluate(DatasetExpressionEvaluator evaluator) throws JRExpressionEvalException
 		{
 			ensureValue();
 			return tableScriptlet.hasDetailOnPage();
 		}
 
+		@Override
 		public Object evaluateEstimated(DatasetExpressionEvaluator evaluator) throws JRExpressionEvalException
 		{
 			ensureValue();
 			return tableScriptlet.hasDetailOnPage();
 		}
 
+		@Override
 		public Object evaluateOld(DatasetExpressionEvaluator evaluator) throws JRExpressionEvalException
 		{
 			ensureValue();
@@ -1419,7 +1598,7 @@ public class TableReport implements JRReport
 		frame.setY(y);
 		frame.setWidth(width);
 		frame.setHeight(cell.getHeight());
-		frame.setStretchType(StretchTypeEnum.RELATIVE_TO_TALLEST_OBJECT);
+		frame.setStretchType(StretchTypeEnum.ELEMENT_GROUP_HEIGHT);
 		
 		frame.setStyle(cell.getStyle());
 		frame.setStyleNameReference(cell.getStyleNameReference());
@@ -1532,7 +1711,7 @@ public class TableReport implements JRReport
 		JRElement cellElement = element.clone(elementGroup, y);
 		cellElement.setX(x);
 		cellElement.setWidth(width);
-		cellElement.setStretchType(StretchTypeEnum.RELATIVE_TO_TALLEST_OBJECT);
+		cellElement.setStretchType(StretchTypeEnum.ELEMENT_GROUP_HEIGHT);
 
 		if (columnHashCode != null && headerHtmlBaseProperties.get(columnHashCode) != null)
 		{
@@ -1566,41 +1745,49 @@ public class TableReport implements JRReport
 		return section;
 	}
 	
+	@Override
 	public JRBand getBackground()
 	{
 		return null;
 	}
 
+	@Override
 	public int getBottomMargin()
 	{
 		return 0;
 	}
 
+	@Override
 	public int getColumnCount()
 	{
 		return 1;
 	}
 
+	@Override
 	public JRBand getColumnFooter()
 	{
 		return null;
 	}
 
+	@Override
 	public JRBand getColumnHeader()
 	{
 		return columnHeader;
 	}
 
+	@Override
 	public int getColumnSpacing()
 	{
 		return 0;
 	}
 
+	@Override
 	public int getColumnWidth()
 	{
 		return fillContext.getComponentElement().getWidth();
 	}
 
+	@Override
 	public JRDataset[] getDatasets()
 	{
 		return parentReport.getDatasets();
@@ -1613,11 +1800,13 @@ public class TableReport implements JRReport
 		return null;
 	}
 
+	@Override
 	public JRSection getDetailSection()
 	{
 		return detail;
 	}
 
+	@Override
 	public JRField[] getFields()
 	{
 		return mainDataset.getFields();
@@ -1637,157 +1826,188 @@ public class TableReport implements JRReport
 		return found;
 	}
 
+	@Override
 	public String getFormatFactoryClass()
 	{
 		return parentReport.getFormatFactoryClass();
 	}
 
+	@Override
 	public JRGroup[] getGroups()
 	{
 		return mainDataset.getGroups();
 	}
 
+	@Override
 	public String[] getImports()
 	{
 		return parentReport.getImports();
 	}
 
+	@Override
 	public String getLanguage()
 	{
 		return parentReport.getLanguage();
 	}
 
+	@Override
 	public JRBand getLastPageFooter()
 	{
 		return lastPageFooter;
 	}
 
+	@Override
 	public int getLeftMargin()
 	{
 		return 0;
 	}
 
+	@Override
 	public JRDataset getMainDataset()
 	{
 		return mainDataset;
 	}
 
+	@Override
 	public String getName()
 	{
 		return mainDataset.getName();
 	}
 
+	@Override
 	public JRBand getNoData()
 	{
 		return null;
 	}
 
+	@Override
 	public OrientationEnum getOrientationValue()
 	{
 		return OrientationEnum.PORTRAIT;
 	}
 
+	@Override
 	public JRBand getPageFooter()
 	{
 		return pageFooter;
 	}
 
+	@Override
 	public JRBand getPageHeader()
 	{
 		return null;
 	}
 
+	@Override
 	public int getPageHeight()
 	{
 		return parentReport.getPageHeight();
 	}
 
+	@Override
 	public int getPageWidth()
 	{
 		return fillContext.getComponentElement().getWidth();
 	}
 
+	@Override
 	public JRParameter[] getParameters()
 	{
 		return mainDataset.getParameters();
 	}
 
+	@Override
 	public PrintOrderEnum getPrintOrderValue()
 	{
 		return PrintOrderEnum.VERTICAL;
 	}
 
+	@Override
 	public RunDirectionEnum getColumnDirection()
 	{
 		return RunDirectionEnum.LTR;
 	}
 
+	@Override
 	public String getProperty(String name)
 	{
 		return mainDataset.getPropertiesMap().getProperty(name);	
 	}
 
+	@Override
 	public String[] getPropertyNames()
 	{
 		return mainDataset.getPropertiesMap().getPropertyNames();
 	}
 
+	@Override
 	public JRQuery getQuery()
 	{
 		return mainDataset.getQuery();
 	}
 
+	@Override
 	public String getResourceBundle()
 	{
 		return mainDataset.getResourceBundle();
 	}
 
+	@Override
 	public int getRightMargin()
 	{
 		return 0;
 	}
 
+	@Override
 	public String getScriptletClass()
 	{
 		return mainDataset.getScriptletClass();
 	}
 
+	@Override
 	public JRScriptlet[] getScriptlets()
 	{
 		return mainDataset.getScriptlets();
 	}
 
+	@Override
 	public JRSortField[] getSortFields()
 	{
 		return mainDataset.getSortFields();
 	}
 
+	@Override
 	public JRStyle[] getStyles()
 	{
 		return parentReport.getStyles();
 	}
 
+	@Override
 	public JRBand getSummary()
 	{
 		return summary;
 	}
 
+	@Override
 	public JRReportTemplate[] getTemplates()
 	{
 		// the parent report's templates are always used for the subreport
 		return null;
 	}
 
+	@Override
 	public JRBand getTitle()
 	{
 		return title;
 	}
 
+	@Override
 	public int getTopMargin()
 	{
 		return 0;
 	}
 
+	@Override
 	public JRVariable[] getVariables()
 	{
 		return mainDataset.getVariables();
@@ -1807,6 +2027,7 @@ public class TableReport implements JRReport
 		return found;
 	}
 	
+	@Override
 	public WhenNoDataTypeEnum getWhenNoDataTypeValue()
 	{
 		WhenNoDataTypeTableEnum whenNoDataType = table.getWhenNoDataType(); 
@@ -1835,77 +2056,98 @@ public class TableReport implements JRReport
 		}
 	}
 
+	@Override
 	public SectionTypeEnum getSectionType()
 	{
 		return SectionTypeEnum.BAND;
 	}
 
+	@Override
 	public WhenResourceMissingTypeEnum getWhenResourceMissingTypeValue()
 	{
 		return mainDataset.getWhenResourceMissingTypeValue();
 	}
 
+	@Override
 	public boolean isFloatColumnFooter()
 	{
 		return true;
 	}
 
+	@Override
 	public boolean isIgnorePagination()
 	{
 		return false;
 	}
 
+	@Override
 	public boolean isSummaryNewPage()
 	{
 		return false;
 	}
 
+	@Override
 	public boolean isSummaryWithPageHeaderAndFooter()
 	{
 		return false;
 	}
 
+	@Override
 	public boolean isTitleNewPage()
 	{
 		return false;
 	}
 
+	@Override
 	public void removeProperty(String name)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public void setProperty(String name, String value)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public void setWhenNoDataType(WhenNoDataTypeEnum whenNoDataType)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public void setWhenResourceMissingType(
 			WhenResourceMissingTypeEnum whenResourceMissingType)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public JRStyle getDefaultStyle()
 	{
 		return parentReport.getDefaultStyle();
 	}
 
+	@Override
+	public StyleResolver getStyleResolver()
+	{
+		return parentReport.getStyleResolver();
+	}
+
+	@Override
 	public JRPropertiesHolder getParentProperties()
 	{
 		return null;
 	}
 
+	@Override
 	public JRPropertiesMap getPropertiesMap()
 	{
 		return mainDataset.getPropertiesMap();
 	}
 
+	@Override
 	public boolean hasProperties()
 	{
 		return mainDataset.hasProperties();
