@@ -40,6 +40,8 @@ import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.TimeZone;
 
+import org.apache.commons.collections.map.LinkedMap;
+
 import net.sf.jasperreports.crosstabs.CrosstabColumnCell;
 import net.sf.jasperreports.crosstabs.CrosstabDeepVisitor;
 import net.sf.jasperreports.crosstabs.JRCellContents;
@@ -75,11 +77,8 @@ import net.sf.jasperreports.engine.util.ElementsVisitorUtils;
 import net.sf.jasperreports.engine.util.FileResolver;
 import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRCloneUtils;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.Pair;
 
-import org.apache.commons.collections.map.LinkedMap;
-
 /**
  * Design-time {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab} implementation.
  * 
@@ -153,6 +152,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	{
 		private static final long serialVersionUID = JRConstants.SERIAL_VERSION_UID;
 
+		@Override
 		public void propertyChange(PropertyChangeEvent evt)
 		{
 			measureClassChanged((JRDesignCrosstabMeasure) evt.getSource(), (String) evt.getNewValue());
@@ -252,11 +252,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	/**
 	 * The ID of the crosstab is only generated at compile time.
 	 */
+	@Override
 	public int getId()
 	{
 		return 0;
 	}
 
+	@Override
 	public JRCrosstabDataset getDataset()
 	{
 		return dataset;
@@ -273,6 +275,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return dataset;
 	}
 
+	@Override
 	public JRCrosstabRowGroup[] getRowGroups()
 	{
 		JRCrosstabRowGroup[] groups = new JRCrosstabRowGroup[rowGroups.size()];
@@ -280,6 +283,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return groups;
 	}
 
+	@Override
 	public JRCrosstabColumnGroup[] getColumnGroups()
 	{
 		JRCrosstabColumnGroup[] groups = new JRCrosstabColumnGroup[columnGroups.size()];
@@ -287,6 +291,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return groups;
 	}
 
+	@Override
 	public JRCrosstabMeasure[] getMeasures()
 	{
 		JRCrosstabMeasure[] measureArray = new JRCrosstabMeasure[measures.size()];
@@ -294,14 +299,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return measureArray;
 	}
 
+	@Override
 	public void collectExpressions(JRExpressionCollector collector)
 	{
 		collector.collect(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void visit(JRVisitor visitor)
 	{
 		visitor.visitCrosstab(this);
@@ -382,8 +386,12 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 					(Object[])null);
 		}
 		
-		rowGroupsMap.put(groupName, Integer.valueOf(rowGroups.size()));
 		rowGroups.add(index, group);
+		for (ListIterator<JRCrosstabRowGroup> it = rowGroups.listIterator(index); it.hasNext();)
+		{
+			JRCrosstabRowGroup rowGroup = it.next();
+			rowGroupsMap.put(rowGroup.getName(), it.previousIndex());
+		}
 		
 		addRowGroupVars(group);
 		
@@ -465,8 +473,12 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 					(Object[])null);
 		}
 		
-		columnGroupsMap.put(groupName, Integer.valueOf(columnGroups.size()));
 		columnGroups.add(index, group);
+		for (ListIterator<JRCrosstabColumnGroup> it = columnGroups.listIterator(index); it.hasNext();)
+		{
+			JRCrosstabColumnGroup columnGroup = it.next();
+			columnGroupsMap.put(columnGroup.getName(), it.previousIndex());
+		}
 		
 		addColGroupVars(group);
 		
@@ -545,8 +557,12 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		
 		measure.addPropertyChangeListener(JRDesignCrosstabMeasure.PROPERTY_VALUE_CLASS, measureClassChangeListener);
 		
-		measuresMap.put(measureName, Integer.valueOf(measures.size()));
 		measures.add(index, measure);
+		for (ListIterator<JRCrosstabMeasure> it = measures.listIterator(index); it.hasNext();)
+		{
+			JRCrosstabMeasure itMeasure = it.next();
+			measuresMap.put(itMeasure.getName(), it.previousIndex());
+		}
 		
 		addMeasureVars(measure);
 		
@@ -597,7 +613,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	
 	public static String getTotalVariableName(JRCrosstabMeasure measure, JRCrosstabRowGroup rowGroup, JRCrosstabColumnGroup colGroup)
 	{
-		StringBuffer name = new StringBuffer();
+		StringBuilder name = new StringBuilder();
 		name.append(measure.getName());
 		if (rowGroup != null)
 		{
@@ -823,6 +839,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return removeMeasure(measure.getName());
 	}
 
+	@Override
 	public boolean isRepeatColumnHeaders()
 	{
 		return repeatColumnHeaders;
@@ -842,6 +859,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		getEventSupport().firePropertyChange(PROPERTY_REPEAT_COLUMN_HEADERS, old, this.repeatColumnHeaders);
 	}
 
+	@Override
 	public boolean isRepeatRowHeaders()
 	{
 		return repeatRowHeaders;
@@ -861,6 +879,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		getEventSupport().firePropertyChange(PROPERTY_REPEAT_ROW_HEADERS, old, this.repeatRowHeaders);
 	}
 
+	@Override
 	public JRCrosstabCell[][] getCells()
 	{
 		return crossCells;
@@ -973,6 +992,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 	
 
+	@Override
 	public JRCrosstabParameter[] getParameters()
 	{
 		JRCrosstabParameter[] parameters = new JRCrosstabParameter[parametersList.size()];
@@ -1002,6 +1022,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return parametersMap;
 	}
 
+	@Override
 	public JRExpression getParametersMapExpression()
 	{
 		return parametersMapExpression;
@@ -1139,6 +1160,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	 * @see JRCrosstab#VARIABLE_ROW_COUNT
 	 * @see JRCrosstab#VARIABLE_COLUMN_COUNT
 	 */
+	@Override
 	public JRVariable[] getVariables()
 	{
 		JRVariable[] variables = new JRVariable[variablesList.size()];
@@ -1147,6 +1169,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 	
 
+	@Override
 	public int getColumnBreakOffset()
 	{
 		return columnBreakOffset;
@@ -1501,6 +1524,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		}
 	}
 
+	@Override
 	public JRCellContents getWhenNoDataCell()
 	{
 		return whenNoDataCell;
@@ -1522,17 +1546,20 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 
 	
+	@Override
 	public JRElement getElementByKey(String elementKey)
 	{
 		return JRBaseCrosstab.getElementByKey(this, elementKey);
 	}
 	
 	
+	@Override
 	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+		return getStyleResolver().getMode(this, ModeEnum.TRANSPARENT);
 	}
 
+	@Override
 	public CrosstabColumnCell getTitleCell()
 	{
 		return titleCell;
@@ -1549,6 +1576,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		getEventSupport().firePropertyChange(PROPERTY_TITLE_CELL, old, this.titleCell);
 	}
 
+	@Override
 	public JRCellContents getHeaderCell()
 	{
 		return headerCell;
@@ -1618,17 +1646,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 	}
 	
 	
-	/**
-	 *
-	 */
+	@Override
 	public RunDirectionEnum getRunDirectionValue()
 	{
 		return this.runDirectionValue;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setRunDirection(RunDirectionEnum runDirectionValue)
 	{
 		RunDirectionEnum old = this.runDirectionValue;
@@ -1674,9 +1698,7 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		}
 	}
 	
-	/**
-	 * 
-	 */
+	@Override
 	public Object clone() 
 	{
 		JRDesignCrosstab clone = (JRDesignCrosstab)super.clone();
@@ -1864,11 +1886,13 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 		return measuresMap;
 	}
 
+	@Override
 	public Boolean getIgnoreWidth()
 	{
 		return ignoreWidth;
 	}
 
+	@Override
 	public void setIgnoreWidth(Boolean ignoreWidth)
 	{
 		Object old = this.ignoreWidth;
@@ -1877,16 +1901,19 @@ public class JRDesignCrosstab extends JRDesignElement implements JRCrosstab
 				old, this.ignoreWidth);
 	}
 
+	@Override
 	public void setIgnoreWidth(boolean ignoreWidth)
 	{
 		setIgnoreWidth(Boolean.valueOf(ignoreWidth));
 	}
 
+	@Override
 	public Color getDefaultLineColor()
 	{
 		return getForecolor();
 	}
 
+	@Override
 	public JRLineBox getLineBox()
 	{
 		return lineBox;
