@@ -176,6 +176,7 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 	}
 
 	
+	@Override
 	public MeasureValue[] getMeasureTotals(BucketMap bucketMap, Bucket bucket)
 	{
 		Object bucketValue = bucketMap.get(bucket);
@@ -204,16 +205,35 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 			
 			vals.add(subList.key);
 			
+			if (!subList.key.isTotal())
+			{
+				fillHeaders(dimension, headers, level + 1, col, subList, vals, totalsMap);
+			}
+			
 			int depthSpan = subList.key.isTotal() ? buckets[dimension].length - level : 1;
 			Bucket[] values = new Bucket[buckets[dimension].length];
 			vals.toArray(values);
 			
 			MeasureValue[][] totals = retrieveHeaderTotals(dimension, values, totalsMap);
-			headers[level][col] = new HeaderCell(values, subList.span, depthSpan, totals);
 			
-			if (!subList.key.isTotal())
+			if (subList.key.isTotal() 
+					|| buckets[dimension][level].isMergeHeaderCells()
+					|| level >= buckets[dimension].length - 1)
 			{
-				fillHeaders(dimension, headers, level + 1, col, subList, vals, totalsMap);
+				// a single merged header
+				headers[level][col] = new HeaderCell(values, subList.span, depthSpan, totals);
+			}
+			else
+			{
+				// creating one header for each header on the next level
+				for (int c = col; c < col + subList.span; ++c)
+				{
+					HeaderCell subheader = headers[level + 1][c];
+					if (subheader != null)
+					{
+						headers[level][c] = new HeaderCell(values, subheader.getLevelSpan(), depthSpan, totals);
+					}
+				}
 			}
 			
 			col += subList.span;
@@ -511,6 +531,7 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 			}
 		}
 		
+		@Override
 		public String toString()
 		{
 			return key + "/" + span + ": " + super.toString();
@@ -529,11 +550,13 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 			list = new LinkedList<CollectedList>();
 		}
 
+		@Override
 		public Iterator<CollectedList> iterator()
 		{
 			return list.iterator();
 		}
 
+		@Override
 		protected void addSublist(CollectedList sublist)
 		{
 			if (sublist.key.isTotal() && totalPosition == CrosstabTotalPositionEnum.START)
@@ -560,11 +583,13 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 			list = new TreeSet<CollectedList>(comparator);
 		}
 
+		@Override
 		public Iterator<CollectedList> iterator()
 		{
 			return list.iterator();
 		}
 
+		@Override
 		protected void addSublist(CollectedList sublist)
 		{
 			list.add(sublist);
@@ -584,6 +609,7 @@ public class CrosstabBucketingService extends BucketingService implements Bucket
 					== CrosstabTotalPositionEnum.START;
 		}
 
+		@Override
 		public int compare(CollectedList l1, CollectedList l2)
 		{
 			if (l1 == l2)
