@@ -68,6 +68,7 @@ import net.sf.jasperreports.export.PropertiesDefaultsConfigurationFactory;
 import net.sf.jasperreports.export.PropertiesNoDefaultsConfigurationFactory;
 import net.sf.jasperreports.export.ReportExportConfiguration;
 import net.sf.jasperreports.export.SimpleExporterInputItem;
+import net.sf.jasperreports.renderers.util.RendererUtil;
 
 
 /**
@@ -110,58 +111,69 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 		/**
 		 * @deprecated Replaced by {@link #getExporterRef()}.
 		 */
+		@Override
 		public JRExporter getExporter()
 		{
 			return JRAbstractExporter.this;
 		}
 
+		@Override
 		public Exporter getExporterRef()
 		{
 			return JRAbstractExporter.this;
 		}
 
+		@Override
 		public JasperReportsContext getJasperReportsContext()
 		{
-			return jasperReportsContext;
+			return JRAbstractExporter.this.getJasperReportsContext();
 		}
 		
+		@Override
 		public JasperPrint getExportedReport()
 		{
 			return jasperPrint;
 		}
 
+		@Override
 		@SuppressWarnings("deprecation")
 		public Map<JRExporterParameter,Object> getExportParameters()
 		{
 			return parameters;
 		}
 
+		@Override
 		public int getOffsetX()
 		{
 			return JRAbstractExporter.this.getOffsetX();
 		}
 
+		@Override
 		public int getOffsetY()
 		{
 			return JRAbstractExporter.this.getOffsetY();
 		}
 
+		@Override
 		@SuppressWarnings("deprecation")
 		public String getExportPropertiesPrefix()
 		{
 			return JRAbstractExporter.this.getExporterPropertiesPrefix();
 		}
 		
+		@Override
 		public Object getValue(String key)
 		{
 			return values.get(key);
 		}
 		
+		@Override
 		public void setValue(String key, Object value)
 		{
 			values.put(key, value);
 		}
 
+		@Override
 		public Map<String, Object> getValues()
 		{
 			return values;
@@ -178,10 +190,12 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 */
 	protected JasperReportsContext jasperReportsContext;
 	protected JRPropertiesUtil propertiesUtil;
+	protected RendererUtil rendererUtil;
 	protected JRStyledTextAttributeSelector allSelector;
 	protected JRStyledTextAttributeSelector noBackcolorSelector;
 	protected JRStyledTextAttributeSelector noneSelector;
 	protected JRStyledTextUtil styledTextUtil;
+	protected FontUtil fontUtil;
 	
 	/**
 	 *
@@ -240,15 +254,6 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	protected E exporterContext;
 	
 	
-	/**
-	 * @deprecated Replaced by {@link #JRAbstractExporter(JasperReportsContext)}.
-	 */
-	protected JRAbstractExporter()
-	{
-		this(DefaultJasperReportsContext.getInstance());
-	}
-	
-	
 	/**
 	 *
 	 */
@@ -304,6 +309,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 * @deprecated Replaced by {@link #setExporterInput(ExporterInput)}, {@link #setConfiguration(ExporterConfiguration)},
 	 * {@link #setConfiguration(ReportExportConfiguration)} and {@link #setExporterOutput(ExporterOutput)}
 	 */
+	@Override
 	public void setParameter(JRExporterParameter parameter, Object value)
 	{
 		checkApi(true);
@@ -319,6 +325,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 * @deprecated Replaced by {@link #setExporterInput(ExporterInput)}, {@link #setConfiguration(ExporterConfiguration)},
 	 * {@link #setConfiguration(ReportExportConfiguration)} and {@link #setExporterOutput(ExporterOutput)}.
 	 */
+	@Override
 	public Object getParameter(JRExporterParameter parameter)
 	{
 		return parameters.get(parameter);
@@ -329,6 +336,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 * @deprecated Replaced by {@link #setExporterInput(ExporterInput)}, {@link #setConfiguration(ExporterConfiguration)},
 	 * {@link #setConfiguration(ReportExportConfiguration)} and {@link #setExporterOutput(ExporterOutput)}
 	 */
+	@Override
 	public void setParameters(Map<JRExporterParameter,Object> parameters)
 	{
 		checkApi(true);
@@ -344,6 +352,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 * @deprecated Replaced by {@link #setExporterInput(ExporterInput)}, {@link #setConfiguration(ExporterConfiguration)},
 	 * {@link #setConfiguration(ReportExportConfiguration)} and {@link #setExporterOutput(ExporterOutput)}
 	 */
+	@Override
 	public Map<JRExporterParameter,Object> getParameters()
 	{
 		return parameters;
@@ -358,9 +367,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setExporterInput(ExporterInput exporterInput)
 	{
 		checkApi(false);
@@ -378,9 +385,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setExporterOutput(O exporterOutput)
 	{
 		checkApi(false);
@@ -389,9 +394,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setConfiguration(RC configuration)
 	{
 		checkApi(false);
@@ -400,9 +403,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setConfiguration(C configuration)
 	{
 		checkApi(false);
@@ -427,25 +428,23 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	{
 		this.jasperReportsContext = jasperReportsContext;
 		this.propertiesUtil = JRPropertiesUtil.getInstance(jasperReportsContext);
+		this.rendererUtil = RendererUtil.getInstance(jasperReportsContext);
 		this.allSelector = JRStyledTextAttributeSelector.getAllSelector(jasperReportsContext);
 		this.noBackcolorSelector = JRStyledTextAttributeSelector.getNoBackcolorSelector(jasperReportsContext);
 		this.noneSelector = JRStyledTextAttributeSelector.getNoneSelector(jasperReportsContext);
 		this.styledTextUtil = JRStyledTextUtil.getInstance(jasperReportsContext);
+		this.fontUtil = FontUtil.getInstance(jasperReportsContext);
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setReportContext(ReportContext reportContext)
 	{
 		this.reportContext = reportContext;
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public ReportContext getReportContext()
 	{
 		return reportContext;
@@ -464,6 +463,13 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	/**
 	 *
 	 */
+	public RendererUtil getRendererUtil()
+	{
+		return rendererUtil;
+	}
+
+	
+	@Override
 	public abstract void exportReport() throws JRException;
 
 
@@ -727,8 +733,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 	 */
 	protected void initReport()
 	{
-		String localeCode = jasperPrint.getLocaleCode();
-		JRStyledTextParser.setLocale(localeCode == null ? null : JRDataUtils.getLocale(localeCode));
+		JRStyledTextParser.setLocale(getLocale());
 
 		setOffset();
 		
@@ -916,7 +921,7 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 		return formatFactoryClass;
 	}
 
-	protected Locale getLocale()
+	public Locale getLocale()
 	{
 		String localeCode = jasperPrint.getLocaleCode();
 		return localeCode == null ? null : JRDataUtils.getLocale(localeCode);
@@ -1013,12 +1018,76 @@ public abstract class JRAbstractExporter<RC extends ReportExportConfiguration, C
 
 	protected TextValue getDateCellValue(JRPrintText text, String textStr) throws ParseException
 	{
-		return new DateTextValue(textStr, (Date)text.getValue(), text.getPattern());
+		if (textStr != null && text.getValue() == null)
+		{
+			TextValue textValue;
+			String pattern = text.getPattern();
+			if (pattern == null || pattern.trim().length() == 0)//FIXMENOW there might be formatters that do not use pattern, in which case this test would skip them
+			{
+				textValue = getTextValueString(text, textStr);
+			}
+			else
+			{
+				DateFormat dateFormat = getDateFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text), getTextTimeZone(text));
+				
+				Date value = null;
+				if (textStr != null && textStr.length() > 0)
+				{
+					value = dateFormat.parse(textStr);
+				}
+				textValue = new DateTextValue(textStr, value, text.getPattern());
+			}
+			return textValue;
+		}
+		else
+		{
+			return new DateTextValue(textStr, (Date)text.getValue(), text.getPattern());
+		}
 	}
 
 	protected TextValue getNumberCellValue(JRPrintText text, String textStr) throws ParseException, ClassNotFoundException
 	{
-		return new NumberTextValue(textStr, (Number)text.getValue(), text.getPattern());
+		if (textStr != null && text.getValue() == null)
+		{
+			TextValue textValue;
+			String pattern = text.getPattern();
+			if (pattern == null || pattern.trim().length() == 0)//FIXMENOW there might be formatters that do not use pattern, in which case this test would skip them
+			{
+				if (textStr != null && textStr.length() > 0)
+				{
+					Number value = defaultParseNumber(textStr, JRClassLoader.loadClassForRealName(text.getValueClassName()));
+
+					if (value != null)
+					{
+						textValue = new NumberTextValue(textStr, value, text.getPattern());
+					}
+					else
+					{
+						textValue = getTextValueString(text, textStr);
+					}
+				}
+				else
+				{
+					textValue = new NumberTextValue(textStr, null, text.getPattern());
+				}
+			}
+			else
+			{
+				NumberFormat numberFormat = getNumberFormat(getTextFormatFactoryClass(text), pattern, getTextLocale(text));
+				
+				Number value = null;
+				if (textStr != null && textStr.length() > 0)
+				{
+					value = numberFormat.parse(textStr);
+				}
+				textValue = new NumberTextValue(textStr, value, text.getPattern());
+			}
+			return textValue;
+		}
+		else
+		{
+			return new NumberTextValue(textStr, (Number)text.getValue(), text.getPattern());
+		}
 	}
 
 	protected Number defaultParseNumber(String textStr, Class<?> valueClass)
