@@ -216,9 +216,7 @@ public class JRCsvDataSource extends JRAbstractTextDataSource// implements JRDat
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean next() throws JRException
 	{
 		try {
@@ -241,9 +239,7 @@ public class JRCsvDataSource extends JRAbstractTextDataSource// implements JRDat
 		}
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Object getFieldValue(JRField jrField) throws JRException
 	{
 		String fieldName = jrField.getName();
@@ -566,7 +562,7 @@ public class JRCsvDataSource extends JRAbstractTextDataSource// implements JRDat
 	 */
 	private String getRow() throws IOException
 	{
-		StringBuffer row = new StringBuffer();
+		StringBuilder row = new StringBuilder();
 		char c;
 
 		while (true) 
@@ -774,7 +770,7 @@ public class JRCsvDataSource extends JRAbstractTextDataSource// implements JRDat
 
 	private String replaceAll(String string, String substring, String replacement)
 	{
-		StringBuffer result = new StringBuffer();
+		StringBuilder result = new StringBuilder();
 		int index = string.indexOf(substring);
 		int oldIndex = 0;
 		while (index >= 0) {
