@@ -143,7 +143,7 @@ public class JRClassGenerator
 
 	protected JRCompilationSourceCode generateClass() throws JRException
 	{
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 
 		generateClassStart(sb);
 
@@ -179,7 +179,7 @@ public class JRClassGenerator
 	}
 
 
-	private void generateInitMethod(StringBuffer sb)
+	private void generateInitMethod(StringBuilder sb)
 	{
 		sb.append("\n");
 		sb.append("\n");
@@ -204,7 +204,7 @@ public class JRClassGenerator
 	}
 
 
-	protected final void generateClassStart(StringBuffer sb)
+	protected final void generateClassStart(StringBuilder sb)
 	{
 		sb.append("/*\n");
 		sb.append(" * Generated by JasperReports - ");
@@ -251,7 +251,7 @@ public class JRClassGenerator
 	}
 
 
-	protected final void generateDeclarations(StringBuffer sb)
+	protected final void generateDeclarations(StringBuilder sb)
 	{
 		if (parametersMap != null && parametersMap.size() > 0)
 		{
@@ -287,7 +287,7 @@ public class JRClassGenerator
 	}
 
 
-	protected final void generateInitParamsMethod(StringBuffer sb) throws JRException
+	protected final void generateInitParamsMethod(StringBuilder sb) throws JRException
 	{
 		Iterator<String> parIt = null;
 		if (parametersMap != null && parametersMap.size() > 0) 
@@ -303,7 +303,7 @@ public class JRClassGenerator
 	}		
 
 
-	protected final void generateInitFieldsMethod(StringBuffer sb) throws JRException
+	protected final void generateInitFieldsMethod(StringBuilder sb) throws JRException
 	{
 		Iterator<String> fieldIt = null;
 		if (fieldsMap != null && fieldsMap.size() > 0) 
@@ -319,7 +319,7 @@ public class JRClassGenerator
 	}
 
 
-	protected final void generateInitVarsMethod(StringBuffer sb) throws JRException
+	protected final void generateInitVarsMethod(StringBuilder sb) throws JRException
 	{
 		Iterator<JRVariable> varIt = null;
 		if (variables != null && variables.length > 0) 
@@ -338,7 +338,7 @@ public class JRClassGenerator
 	/**
 	 *
 	 */
-	private void generateInitParamsMethod(StringBuffer sb, Iterator<String> it, int index) throws JRException
+	private void generateInitParamsMethod(StringBuilder sb, Iterator<String> it, int index) throws JRException
 	{
 		sb.append("    /**\n");
 		sb.append("     *\n");
@@ -379,7 +379,7 @@ public class JRClassGenerator
 	/**
 	 *
 	 */
-	private void generateInitFieldsMethod(StringBuffer sb, Iterator<String> it, int index) throws JRException
+	private void generateInitFieldsMethod(StringBuilder sb, Iterator<String> it, int index) throws JRException
 	{
 		sb.append("    /**\n");
 		sb.append("     *\n");
@@ -420,7 +420,7 @@ public class JRClassGenerator
 	/**
 	 *
 	 */
-	private void generateInitVarsMethod(StringBuffer sb, Iterator<JRVariable> it, int index) throws JRException
+	private void generateInitVarsMethod(StringBuilder sb, Iterator<JRVariable> it, int index) throws JRException
 	{
 		sb.append("    /**\n");
 		sb.append("     *\n");
@@ -460,7 +460,7 @@ public class JRClassGenerator
 
 	protected final String generateMethod(byte evaluationType, List<JRExpression> expressionsList) throws JRException
 	{
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 
 		if (expressionsList.size() > 0)
 		{
@@ -492,22 +492,22 @@ public class JRClassGenerator
 	private String generateMethod(Iterator<JRExpression> it, byte evaluationType) throws JRException
 	{
 		int methodIndex = 0;
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 
 		writeMethodStart(sb, evaluationType, methodIndex);
 		++methodIndex;
 
-		StringBuffer expressionBuffer = new StringBuffer();
+		StringBuilder expressionBuilder = new StringBuilder();
 		int methodExpressionIndex = 0;
-		int methodBufferStartPosition = sb.length();
+		int methodBuilderStartPosition = sb.length();
 		while (it.hasNext())
 		{
 			JRExpression expression = it.next();
 			
-			expressionBuffer.setLength(0);
-			writeExpression(expressionBuffer, expression, evaluationType);
+			expressionBuilder.setLength(0);
+			writeExpression(expressionBuilder, expression, evaluationType);
 			if (methodExpressionIndex >= EXPR_MAX_COUNT_PER_METHOD
-					|| (methodExpressionIndex > 0 && sb.length() - methodBufferStartPosition > maxMethodSize))
+					|| (methodExpressionIndex > 0 && sb.length() - methodBuilderStartPosition > maxMethodSize))
 			{
 				// end the current method
 				writeMethodEnd(sb, evaluationType, methodIndex);
@@ -516,10 +516,10 @@ public class JRClassGenerator
 				writeMethodStart(sb, evaluationType, methodIndex);
 				++methodIndex;
 				methodExpressionIndex = 0;
-				methodBufferStartPosition = sb.length();
+				methodBuilderStartPosition = sb.length();
 			}
 			
-			sb.append(expressionBuffer);
+			sb.append(expressionBuilder);
 			++methodExpressionIndex;
 		}
 		
@@ -528,7 +528,7 @@ public class JRClassGenerator
 		return sb.toString();
 	}
 
-	protected void writeMethodStart(StringBuffer sb, byte evaluationType, int methodIndex)
+	protected void writeMethodStart(StringBuilder sb, byte evaluationType, int methodIndex)
 	{
 		sb.append("    /**\n");
 		sb.append("     *\n");
@@ -552,7 +552,7 @@ public class JRClassGenerator
 		sb.append("        {\n");
 	}
 
-	protected void writeExpression(StringBuffer sb, JRExpression expression, byte evaluationType)
+	protected void writeExpression(StringBuilder sb, JRExpression expression, byte evaluationType)
 	{
 		sb.append("            case "); 
 		sb.append(sourceTask.getExpressionId(expression)); 
@@ -567,7 +567,7 @@ public class JRClassGenerator
 		sb.append("            }\n");
 	}
 	
-	protected void writeMethodEnd(StringBuffer sb, byte evaluationType, Integer nextMethodIndex)
+	protected void writeMethodEnd(StringBuilder sb, byte evaluationType, Integer nextMethodIndex)
 	{
 		sb.append("           default :\n");
 		sb.append("           {\n");
@@ -601,7 +601,7 @@ public class JRClassGenerator
 		JRField jrField = null;
 		JRVariable jrVariable = null;
 
-		StringBuffer sb = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 
 		JRExpressionChunk[] chunks = expression.getChunks();
 		JRExpressionChunk chunk = null;
@@ -686,7 +686,7 @@ public class JRClassGenerator
 	}
 
 
-	protected void appendExpressionText(JRExpression expression, StringBuffer sb, String chunkText)
+	protected void appendExpressionText(JRExpression expression, StringBuilder sb, String chunkText)
 	{
 		for (StringTokenizer tokenizer = new StringTokenizer(chunkText, "\n", true);
 				tokenizer.hasMoreTokens();)
@@ -700,7 +700,7 @@ public class JRClassGenerator
 		}
 	}
 
-	protected void appendExpressionComment(StringBuffer sb, JRExpression expression)
+	protected void appendExpressionComment(StringBuilder sb, JRExpression expression)
 	{
 		sb.append(" //");
 		sb.append(SOURCE_EXPRESSION_ID_START);
@@ -765,8 +765,8 @@ public class JRClassGenerator
 	{
 		int firstImportIndex = sourceCode.indexOf("\nimport ");
 		int lastBracketIndex = sourceCode.lastIndexOf("}");
-		StringBuffer importBuffer = new StringBuffer();
-		StringBuffer methodBuffer = new StringBuffer();
+		StringBuilder importBuilder = new StringBuilder();
+		StringBuilder methodBuilder = new StringBuilder();
 
 		for (Method method : missingMethods)
 		{
@@ -780,34 +780,34 @@ public class JRClassGenerator
 					if (classMethod.getName().equals(method.getName()) 
 							&& Modifier.isPublic(classMethod.getModifiers()))
 					{
-						addMethod(methodBuffer, classMethod);
+						addMethod(methodBuilder, classMethod);
 					}
 				}
 			}
 			else if (Modifier.isStatic(method.getModifiers()))
 			{
-				importBuffer.append("\nimport static " + methodClass.getName() + "." + method.getName() + ";");
+				importBuilder.append("\nimport static " + methodClass.getName() + "." + method.getName() + ";");
 			}
 		}
 
-		StringBuffer buffer = new StringBuffer();
-		buffer.append(sourceCode.substring(0,  firstImportIndex));
-		buffer.append(importBuffer);
-		buffer.append(sourceCode.substring(firstImportIndex, lastBracketIndex));
-		buffer.append(methodBuffer);
-		buffer.append(sourceCode.substring(lastBracketIndex));
+		StringBuilder sb = new StringBuilder();
+		sb.append(sourceCode.substring(0,  firstImportIndex));
+		sb.append(importBuilder);
+		sb.append(sourceCode.substring(firstImportIndex, lastBracketIndex));
+		sb.append(methodBuilder);
+		sb.append(sourceCode.substring(lastBracketIndex));
 
-		sourceCode = buffer.toString();
+		sourceCode = sb.toString();
 		
 		return parseSourceLines(sourceCode);
 	}
 
 
-	protected void addMethod(StringBuffer methodBuffer, Method method)
+	protected void addMethod(StringBuilder methodBuilder, Method method)
 	{
 		Class<?>[] paramTypes = method.getParameterTypes();
-		StringBuffer methodSignature = new StringBuffer();
-		StringBuffer methodCall = new StringBuffer();
+		StringBuilder methodSignature = new StringBuilder();
+		StringBuilder methodCall = new StringBuilder();
 
 		for (int j = 0; j < paramTypes.length; j++)
 		{
@@ -832,15 +832,15 @@ public class JRClassGenerator
 			methodSignature.append(" arg" + j);
 		}
 
-		methodBuffer.append("    /**\n");
-		methodBuffer.append("     *\n"); 
-		methodBuffer.append("     */\n");
-		methodBuffer.append("    public " + method.getReturnType().getName() + " " + method.getName() + "(" + methodSignature.toString() + ")" + "\n");
-		methodBuffer.append("    {\n");
-		methodBuffer.append("        return getFunctionSupport(" + method.getDeclaringClass().getName() + ".class)." + method.getName() + "(" + methodCall + ");\n");
-		methodBuffer.append("    }\n");
-		methodBuffer.append("\n");
-		methodBuffer.append("\n");
+		methodBuilder.append("    /**\n");
+		methodBuilder.append("     *\n"); 
+		methodBuilder.append("     */\n");
+		methodBuilder.append("    public " + method.getReturnType().getName() + " " + method.getName() + "(" + methodSignature.toString() + ")" + "\n");
+		methodBuilder.append("    {\n");
+		methodBuilder.append("        return getFunctionSupport(" + method.getDeclaringClass().getName() + ".class)." + method.getName() + "(" + methodCall + ");\n");
+		methodBuilder.append("    }\n");
+		methodBuilder.append("\n");
+		methodBuilder.append("\n");
 	}
 
 	
