@@ -39,16 +39,6 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
-import net.sf.jasperreports.engine.JRException;
-import net.sf.jasperreports.engine.JRPropertiesUtil;
-import net.sf.jasperreports.engine.JRReport;
-import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JasperReportsContext;
-import net.sf.jasperreports.engine.util.JRClassLoader;
-import net.sf.jasperreports.engine.util.JRLoader;
-import net.sf.jasperreports.functions.FunctionsUtil;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.eclipse.jdt.core.compiler.IProblem;
@@ -67,6 +57,15 @@ import org.eclipse.jdt.internal.compiler.env.NameEnvironmentAnswer;
 import org.eclipse.jdt.internal.compiler.impl.CompilerOptions;
 import org.eclipse.jdt.internal.compiler.problem.DefaultProblemFactory;
 
+import net.sf.jasperreports.engine.JRException;
+import net.sf.jasperreports.engine.JRPropertiesUtil;
+import net.sf.jasperreports.engine.JRReport;
+import net.sf.jasperreports.engine.JRRuntimeException;
+import net.sf.jasperreports.engine.JasperReportsContext;
+import net.sf.jasperreports.engine.util.JRClassLoader;
+import net.sf.jasperreports.engine.util.JRLoader;
+import net.sf.jasperreports.functions.FunctionsUtil;
+
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
  */
@@ -138,18 +137,7 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 	}	
 	
 
-	/**
-	 * @deprecated Replaced by {@link #JRJdtCompiler(JasperReportsContext)}.
-	 */
-	public JRJdtCompiler()
-	{
-		this(DefaultJasperReportsContext.getInstance());
-	}	
-
-	
-	/**
-	 *
-	 */
+	@Override
 	protected String compileUnits(final JRCompilationUnit[] units, String classpath, File tempDirFile)
 	{
 		final INameEnvironment env = getNameEnvironment(units);
@@ -186,9 +174,10 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 	{
 		final INameEnvironment env = new INameEnvironment() 
 		{
+			@Override
 			public NameEnvironmentAnswer findType(char[][] compoundTypeName) 
 			{
-				StringBuffer result = new StringBuffer();
+				StringBuilder result = new StringBuilder();
 				String sep = "";
 				for (int i = 0; i < compoundTypeName.length; i++) {
 					result.append(sep);
@@ -198,9 +187,10 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 				return findType(result.toString());
 			}
 
+			@Override
 			public NameEnvironmentAnswer findType(char[] typeName, char[][] packageName) 
 			{
-				StringBuffer result = new StringBuffer();
+				StringBuilder result = new StringBuilder();
 				String sep = "";
 				for (int i = 0; i < packageName.length; i++) {
 					result.append(sep);
@@ -364,9 +354,10 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 				return isPackage;
 			}
 
+			@Override
 			public boolean isPackage(char[][] parentPackageName, char[] packageName) 
 			{
-				StringBuffer result = new StringBuffer();
+				StringBuilder result = new StringBuilder();
 				String sep = "";
 				if (parentPackageName != null) 
 				{
@@ -389,6 +380,7 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 				return isPackage(result.toString());
 			}
 
+			@Override
 			public void cleanup() 
 			{
 			}
@@ -499,6 +491,7 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 	}
 
 	
+	@Override
 	protected void checkLanguage(String language) throws JRException
 	{		
 		if (!JRReport.LANGUAGE_JAVA.equals(language))
@@ -527,18 +520,21 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 	}
 
 	
+	@Override
 	protected JRCompilationSourceCode generateSourceCode(JRSourceCompileTask sourceTask) throws JRException
 	{
 		return JRClassGenerator.generateClass(sourceTask);
 	}
 
 	
+	@Override
 	protected String getSourceFileName(String unitName)
 	{
 		return unitName + ".java";
 	}
 
 
+	@Override
 	protected String getCompilerClass()
 	{
 		return JRJavacCompiler.class.getName();
@@ -568,6 +564,7 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 			reset();
 		}
 			
+		@Override
 		public void acceptResult(CompilationResult result) 
 		{
 			String className = ((CompilationUnit) result.getCompilationUnit()).className;
@@ -642,7 +639,7 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 		 */
 		public String getFormattedProblems() 
 		{
-			StringBuffer problemBuffer = new StringBuffer();
+			StringBuilder problemBuilder = new StringBuilder();
 			
 			for (int u = 0; u < units.length; u++) 
 			{
@@ -656,9 +653,9 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 					{
 						IProblem problem = problems[i];
 			
-						problemBuffer.append(i + 1);
-						problemBuffer.append(". ");
-						problemBuffer.append(problem.getMessage());
+						problemBuilder.append(i + 1);
+						problemBuilder.append(". ");
+						problemBuilder.append(problem.getMessage());
 			
 						if (
 							problem.getSourceStart() >= 0
@@ -672,42 +669,42 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 								problemEndIndex = sourceCode.length();
 							}
 							
-							problemBuffer.append("\n");
-							problemBuffer.append(
+							problemBuilder.append("\n");
+							problemBuilder.append(
 								sourceCode.substring(
 									problemStartIndex,
 									problemEndIndex
 									)
 								);
-							problemBuffer.append("\n");
+							problemBuilder.append("\n");
 							for(int j = problemStartIndex; j < problem.getSourceStart(); j++)
 							{
-								problemBuffer.append(" ");
+								problemBuilder.append(" ");
 							}
 							if (problem.getSourceStart() == problem.getSourceEnd())
 							{
-								problemBuffer.append("^");
+								problemBuilder.append("^");
 							}
 							else
 							{
-								problemBuffer.append("<");
+								problemBuilder.append("<");
 								for(int j = problem.getSourceStart() + 1; j < problem.getSourceEnd(); j++)
 								{
-									problemBuffer.append("-");
+									problemBuilder.append("-");
 								}
-								problemBuffer.append(">");
+								problemBuilder.append(">");
 							}
 			
-							problemBuffer.append("\n");
+							problemBuilder.append("\n");
 						}
 					}
 					
-					problemBuffer.append(problems.length);
-					problemBuffer.append(" errors\n");
+					problemBuilder.append(problems.length);
+					problemBuilder.append(" errors\n");
 				}
 			}
 			
-			return problemBuffer.length() > 0 ? problemBuffer.toString() : null;
+			return problemBuilder.length() > 0 ? problemBuilder.toString() : null;
 		}
 
 		/**
@@ -820,26 +817,31 @@ public class JRJdtCompiler extends JRAbstractJavaCompiler
 			this.className = className;
 		}
 
+		@Override
 		public char[] getFileName() 
 		{
 			return className.toCharArray();
 		}
 
+		@Override
 		public char[] getContents() 
 		{
 			return srcCode.toCharArray();
 		}
 
+		@Override
 		public char[] getMainTypeName() 
 		{
 			return className.toCharArray();
 		}
 
+		@Override
 		public char[][] getPackageName() 
 		{
 			return new char[0][0];
 		}
 
+		@Override
 		public boolean ignoreOptionalProblems() 
 		{
 			return false;
