@@ -31,6 +31,9 @@ import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.charts.JRCategoryDataset;
 import net.sf.jasperreports.charts.JRCategorySeries;
 import net.sf.jasperreports.charts.JRGanttDataset;
@@ -61,6 +64,7 @@ import net.sf.jasperreports.crosstabs.design.JRDesignCrosstab;
 import net.sf.jasperreports.crosstabs.fill.JRPercentageCalculator;
 import net.sf.jasperreports.crosstabs.fill.JRPercentageCalculatorFactory;
 import net.sf.jasperreports.crosstabs.type.CrosstabPercentageEnum;
+import net.sf.jasperreports.crosstabs.type.CrosstabTotalPositionEnum;
 import net.sf.jasperreports.engine.CommonReturnValue;
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.ExpressionReturnValue;
@@ -136,9 +140,6 @@ import net.sf.jasperreports.engine.util.FormatFactory;
 import net.sf.jasperreports.engine.util.JRClassLoader;
 import net.sf.jasperreports.engine.util.JRQueryExecuterUtils;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 
 /**
  * A report verifier.
@@ -260,23 +261,6 @@ public class JRVerifier
 	private final boolean allowElementNegativeX;
 	private final boolean allowElementNegativeY;
 
-	/**
-	 * @deprecated Replaced by {@link #JRVerifier(JasperReportsContext, JasperDesign, JRExpressionCollector)}.
-	 */
-	protected JRVerifier(JasperDesign jasperDesign)
-	{
-		this(DefaultJasperReportsContext.getInstance(), jasperDesign, null);
-	}
-
-
-	/**
-	 * @deprecated Replaced by {@link #JRVerifier(JasperReportsContext, JasperDesign, JRExpressionCollector)}.
-	 */
-	protected JRVerifier(JasperDesign jasperDesign, JRExpressionCollector expressionCollector)
-	{
-		this(DefaultJasperReportsContext.getInstance(), jasperDesign, expressionCollector);
-	}
-
 	/**
 	 * 
 	 */
@@ -1345,7 +1329,7 @@ public class JRVerifier
 						&& element2.getY() < element1.getY() + element1.getHeight()))
 		{
 			// we have an overlap
-			StringBuffer message = new StringBuffer();
+			StringBuilder message = new StringBuilder();
 			message.append("Element ");
 			if (element2.getKey() != null)
 			{
@@ -1755,6 +1739,11 @@ public class JRVerifier
 			for (int i = 0; i < rowGroups.length; i++)
 			{
 				verifyCrosstabRowGroup(rowGroups[i]);
+				
+				if (i + 1 < rowGroups.length)
+				{
+					verifyCrosstabNextGroup(rowGroups[i], rowGroups[i + 1]);
+				}
 			}
 		}
 
@@ -1768,6 +1757,11 @@ public class JRVerifier
 			for (int i = 0; i < colGroups.length; i++)
 			{
 				verifyCrosstabColumnGroup(colGroups[i]);
+				
+				if (i + 1 < colGroups.length)
+				{
+					verifyCrosstabNextGroup(colGroups[i], colGroups[i + 1]);
+				}
 			}
 		}
 
@@ -1791,6 +1785,15 @@ public class JRVerifier
 		verifyExpressions(crosstab);
 	}
 
+	protected void verifyCrosstabNextGroup(JRCrosstabGroup group, JRCrosstabGroup nextGroup)
+	{
+		if (Boolean.FALSE.equals(group.getMergeHeaderCells())
+				&& nextGroup.getTotalPositionValue() != CrosstabTotalPositionEnum.NONE)
+		{
+			addBrokenRule("Row crosstab group has repeating header cells but the next group has a total row",
+					group);
+		}
+	}
 
 	private void verifyParameters(JRDesignCrosstab crosstab)
 	{
