@@ -51,6 +51,7 @@ import net.sf.jasperreports.engine.JRSection;
 import net.sf.jasperreports.engine.JRSortField;
 import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRVariable;
+import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.base.JRBaseReport;
 import net.sf.jasperreports.engine.design.events.PropagationChangeListener;
 import net.sf.jasperreports.engine.type.BandTypeEnum;
@@ -220,10 +221,15 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Constructs a JasperDesign object and fills it with the default variables and parameters.
 	 */
-	@SuppressWarnings("deprecation")
 	public JasperDesign()
 	{
-		setMainDataset(new JRDesignDataset(true));
+		this(DefaultJasperReportsContext.getInstance());
+	}
+
+	@SuppressWarnings("deprecation")
+	public JasperDesign(JasperReportsContext context)
+	{
+		setMainDataset(new JRDesignDataset(context, true));
 		
 		detailSection = new JRDesignSection(new JROrigin(BandTypeEnum.DETAIL));
 	}
@@ -643,6 +649,7 @@ public class JasperDesign extends JRBaseReport
 	/**
 	 * Gets an array of report level styles. These styles can be referenced by report elements.
 	 */
+	@Override
 	public JRStyle[] getStyles()
 	{
 		JRStyle[] stylesArray = new JRStyle[stylesList.size()];
@@ -1018,6 +1025,7 @@ public class JasperDesign extends JRBaseReport
 	}
 
 
+	@Override
 	public JRDataset[] getDatasets()
 	{
 		JRDataset[] datasetArray = new JRDataset[datasetList.size()];
@@ -1165,6 +1173,7 @@ public class JasperDesign extends JRBaseReport
 		final List<JRCrosstab> crosstabs = new ArrayList<JRCrosstab>();
 		JRElementsVisitor.visitReport(this, new JRVisitorSupport()
 		{
+			@Override
 			public void visitCrosstab(JRCrosstab crosstab)
 			{
 				crosstabs.add(crosstab);
@@ -1255,6 +1264,7 @@ public class JasperDesign extends JRBaseReport
 		return false;
 	}
 
+	@Override
 	public JRReportTemplate[] getTemplates()
 	{
 		return templateList.toArray(new JRReportTemplate[templateList.size()]);
