@@ -32,16 +32,13 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPrintText;
-import net.sf.jasperreports.engine.JRStyledTextAttributeSelector;
 import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.TabStop;
 import net.sf.jasperreports.engine.type.HorizontalTextAlignEnum;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
-import net.sf.jasperreports.engine.util.JRStyledTextUtil;
 import net.sf.jasperreports.engine.util.ParagraphUtil;
 
 
@@ -53,7 +50,6 @@ public abstract class AbstractTextRenderer
 	public static final FontRenderContext LINE_BREAK_FONT_RENDER_CONTEXT = new FontRenderContext(null, true, true);
 
 	protected final JasperReportsContext jasperReportsContext;
-	protected final JRStyledTextAttributeSelector noBackcolorSelector;
 	protected JRPrintText text;
 	protected JRStyledText styledText;
 	protected String allText;
@@ -97,24 +93,11 @@ public abstract class AbstractTextRenderer
 		)
 	{
 		this.jasperReportsContext = jasperReportsContext;
-		this.noBackcolorSelector = JRStyledTextAttributeSelector.getNoBackcolorSelector(jasperReportsContext);
 		this.isMinimizePrinterJobSize = isMinimizePrinterJobSize;
 		this.ignoreMissingFont = ignoreMissingFont;
 	}
 	
 	
-	/**
-	 * @deprecated Replaced by {@link #AbstractTextRenderer(JasperReportsContext, boolean, boolean)}. 
-	 */
-	public AbstractTextRenderer(
-		boolean isMinimizePrinterJobSize,
-		boolean ignoreMissingFont
-		)
-	{
-		this(DefaultJasperReportsContext.getInstance(), isMinimizePrinterJobSize, ignoreMissingFont);
-	}
-	
-	
 	/**
 	 *
 	 */
@@ -172,15 +155,9 @@ public abstract class AbstractTextRenderer
 	/**
 	 * 
 	 */
-	public void initialize(JRPrintText text, int offsetX, int offsetY)
+	public void initialize(JRPrintText text, JRStyledText styledText, int offsetX, int offsetY)
 	{
-		styledText = JRStyledTextUtil.getInstance(jasperReportsContext).getStyledText(text, noBackcolorSelector);
-		
-		if (styledText == null)
-		{
-			return;
-		}
-
+		this.styledText = styledText;
 		allText = styledText.getText();
 		
 		x = text.getX() + offsetX;
@@ -241,9 +218,9 @@ public abstract class AbstractTextRenderer
 		verticalAlignOffset = 0f;
 		switch (text.getVerticalTextAlign())
 		{
-			case TOP :
+			case BOTTOM :
 			{
-				verticalAlignOffset = 0f;
+				verticalAlignOffset = height - topPadding - bottomPadding - text.getTextHeight();
 				break;
 			}
 			case MIDDLE :
@@ -251,11 +228,8 @@ public abstract class AbstractTextRenderer
 				verticalAlignOffset = (height - topPadding - bottomPadding - text.getTextHeight()) / 2f;
 				break;
 			}
-			case BOTTOM :
-			{
-				verticalAlignOffset = height - topPadding - bottomPadding - text.getTextHeight();
-				break;
-			}
+			case TOP :
+			case JUSTIFIED :
 			default :
 			{
 				verticalAlignOffset = 0f;
