@@ -37,6 +37,8 @@ import java.awt.Dimension;
 import java.awt.Rectangle;
 import java.awt.font.TextAttribute;
 import java.awt.geom.Dimension2D;
+import java.io.ByteArrayInputStream;
+import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.Writer;
 import java.text.AttributedCharacterIterator;
@@ -49,13 +51,15 @@ import java.util.ListIterator;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+import org.w3c.tools.codec.Base64Encoder;
+
 import net.sf.jasperreports.crosstabs.JRCellContents;
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.ImageMapRenderable;
 import net.sf.jasperreports.engine.JRException;
-import net.sf.jasperreports.engine.JRExporterParameter;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
-import net.sf.jasperreports.engine.JRImageRenderer;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintElement;
@@ -73,36 +77,34 @@ import net.sf.jasperreports.engine.JRPrintPage;
 import net.sf.jasperreports.engine.JRPrintRectangle;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.PrintPageFormat;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
 import net.sf.jasperreports.engine.base.JRBasePrintFrame;
-import net.sf.jasperreports.engine.fonts.FontFamily;
-import net.sf.jasperreports.engine.fonts.FontInfo;
-import net.sf.jasperreports.engine.fonts.FontUtil;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
 import net.sf.jasperreports.engine.type.LineSpacingEnum;
 import net.sf.jasperreports.engine.type.LineStyleEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
-import net.sf.jasperreports.engine.type.RenderableTypeEnum;
 import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.util.JRColorUtil;
+import net.sf.jasperreports.engine.util.JRImageLoader;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRTextAttribute;
+import net.sf.jasperreports.engine.util.JRTypeSniffer;
 import net.sf.jasperreports.engine.util.Pair;
 import net.sf.jasperreports.export.ExportInterruptedException;
 import net.sf.jasperreports.export.ExporterInputItem;
 import net.sf.jasperreports.export.HtmlReportConfiguration;
-import net.sf.jasperreports.export.parameters.ParametersHtmlExporterOutput;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.renderers.AreaHyperlinksRenderable;
+import net.sf.jasperreports.renderers.DataRenderable;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.RenderersCache;
+import net.sf.jasperreports.renderers.ResourceRenderer;
+import net.sf.jasperreports.renderers.util.RendererUtil;
 
 
 /**
@@ -148,11 +150,13 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 
 	protected class ExporterContext extends BaseExporterContext implements JRHtmlExporterContext
 	{
+		@Override
 		public String getExportPropertiesPrefix()
 		{
 			return HTML_EXPORTER_PROPERTIES_PREFIX;
 		}
 
+		@Override
 		public String getHyperlinkURL(JRPrintHyperlink link)
 		{
 			return JRHtmlExporter.this.getHyperlinkURL(link);
@@ -165,8 +169,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	protected Writer writer;
 	protected Map<String,String> rendererToImagePathMap;
 	protected Map<Pair<String, Rectangle>,String> imageMaps;
-	
-	protected Map<String, HtmlFont> fontsToProcess;
+	protected RenderersCache renderersCache;
 	
 	protected int reportIndex;
 	protected int pageIndex;
@@ -206,33 +209,27 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<JRHtmlExporterConfiguration> getConfigurationInterface()
 	{
 		return JRHtmlExporterConfiguration.class;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<JRHtmlReportConfiguration> getItemConfigurationInterface()
 	{
 		return JRHtmlReportConfiguration.class;
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	protected void ensureOutput()
 	{
 		if (exporterOutput == null)
 		{
 			exporterOutput = 
-				new ParametersHtmlExporterOutput(
+				new net.sf.jasperreports.export.parameters.ParametersHtmlExporterOutput(
 					getJasperReportsContext(),
 					getParameters(),
 					getCurrentJasperPrint()
@@ -250,9 +247,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void exportReport() throws JRException
 	{
 		/*   */
@@ -292,14 +287,16 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 
 		rendererToImagePathMap = new HashMap<String,String>();
 		imageMaps = new HashMap<Pair<String, Rectangle>,String>();
+		renderersCache = new RenderersCache(getJasperReportsContext());
 
-		fontsToProcess = new HashMap<String, HtmlFont>();
+		fontsToProcess = new HashMap<String, HtmlFontFamily>();
 
 		if (getCurrentConfiguration().isUsingImagesToAlign())
 		{
 			emptyCellStringProvider =
 				new StringProvider()
 				{
+					@Override
 					public String getStringForCollapsedTD(int width, int height)
 					{
 						HtmlResourceHandler imageHandler = 
@@ -309,6 +306,8 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 						String pxUri = imageHandler == null ? null : imageHandler.getResourcePath("px");
 						return "><img alt=\"\" src=\"" + pxUri + "\" style=\"width: " + toSizeUnit(width) + "; height: " + toSizeUnit(height) + ";\"/>";
 					}
+
+					@Override
 					public String getStringForEmptyTD()
 					{
 						HtmlResourceHandler imageHandler = 
@@ -319,6 +318,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 						return "<img alt=\"\" src=\"" + pxUri + "\" border=\"0\"/>";
 					}
 					
+					@Override
 					public String getReportTableStyle()
 					{
 						return null;
@@ -330,15 +330,19 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			emptyCellStringProvider =
 				new StringProvider()
 				{
+					@Override
 					public String getStringForCollapsedTD(int width, int height)
 					{
 						return " style=\"width: " + toSizeUnit(width) + "; height: " + toSizeUnit(height) + ";\">";
 					}
+
+					@Override
 					public String getStringForEmptyTD()
 					{
 						return "";
 					}
 					
+					@Override
 					public String getReportTableStyle()
 					{
 						// required for lines and rectangles, but doesn't work in IE
@@ -461,20 +465,20 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 				getExporterOutput().getFontHandler() == null
 				? getFontHandler()
 				: getExporterOutput().getFontHandler();
-			for (HtmlFont htmlFont : fontsToProcess.values())
+			for (HtmlFontFamily htmlFontFamily : fontsToProcess.values())
 			{
-				writer.write("<link class=\"jrWebFont\" rel=\"stylesheet\" href=\"" + fontHandler.getResourcePath(htmlFont.getId()) + "\">\n");
+				writer.write("<link class=\"jrWebFont\" rel=\"stylesheet\" href=\"" + fontHandler.getResourcePath(htmlFontFamily.getId()) + "\">\n");
 			}
 		}
 		
 //		if (!isOutputResourcesToDir)
 		{
-			writer.write("<![if IE]>\n");
+			writer.write("<!--[if IE]>\n");
 			writer.write("<script>\n");
 			writer.write("var links = document.querySelectorAll('link.jrWebFont');\n");
 			writer.write("setTimeout(function(){ if (links) { for (var i = 0; i < links.length; i++) { links.item(i).href = links.item(i).href; } } }, 0);\n");
 			writer.write("</script>\n");
-			writer.write("<![endif]>\n");
+			writer.write("<![endif]-->\n");
 		}
 
 		if (htmlFooter == null)
@@ -714,14 +718,14 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			writer.write(" colspan=\"" + cell.getColSpan() + "\"");
 		}
 
-		StringBuffer styleBuffer = new StringBuffer();
-		appendBackcolorStyle(cell, styleBuffer);
-		appendBorderStyle(cell.getBox(), styleBuffer);
+		StringBuilder styleBuilder = new StringBuilder();
+		appendBackcolorStyle(cell, styleBuilder);
+		appendBorderStyle(cell.getBox(), styleBuilder);
 
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 
@@ -737,9 +741,9 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		writeCellStart(gridCell);
 
-		StringBuffer styleBuffer = new StringBuffer();
+		StringBuilder styleBuilder = new StringBuilder();
 
-		appendBackcolorStyle(gridCell, styleBuffer);
+		appendBackcolorStyle(gridCell, styleBuilder);
 		
 		String side = null;
 		float ratio = line.getWidth() / line.getHeight();
@@ -767,15 +771,15 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 		}
 
 		appendPen(
-			styleBuffer,
+			styleBuilder,
 			line.getLinePen(),
 			side
 			);
 
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 
@@ -864,20 +868,20 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		writeCellStart(gridCell);
 
-		StringBuffer styleBuffer = new StringBuffer();
+		StringBuilder styleBuilder = new StringBuilder();
 
-		appendBackcolorStyle(gridCell, styleBuffer);
+		appendBackcolorStyle(gridCell, styleBuilder);
 		
 		appendPen(
-			styleBuffer,
+			styleBuilder,
 			element.getLinePen(),
 			null
 			);
 
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 
@@ -957,51 +961,6 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 		Color backcolor
 		) throws IOException
 	{
-		boolean isBold = TextAttribute.WEIGHT_BOLD.equals(attributes.get(TextAttribute.WEIGHT));
-		boolean isItalic = TextAttribute.POSTURE_OBLIQUE.equals(attributes.get(TextAttribute.POSTURE));
-
-		String fontFamilyAttr = (String)attributes.get(TextAttribute.FAMILY);
-		String fontFamily = fontFamilyAttr;
-
-		FontInfo fontInfo = FontUtil.getInstance(jasperReportsContext).getFontInfo(fontFamilyAttr, locale);
-		if (fontInfo != null)
-		{
-			//fontName found in font extensions
-			FontFamily family = fontInfo.getFontFamily();
-			String exportFont = family.getExportFont(getExporterKey());
-			if (exportFont == null)
-			{
-				HtmlResourceHandler fontHandler = 
-					getExporterOutput().getFontHandler() == null
-					? getFontHandler()
-					: getExporterOutput().getFontHandler();
-				HtmlResourceHandler resourceHandler = 
-					getExporterOutput().getResourceHandler() == null
-					? getResourceHandler()
-					: getExporterOutput().getResourceHandler();
-				if (fontHandler != null && resourceHandler != null)
-				{
-					HtmlFont htmlFont = HtmlFont.getInstance(locale, fontInfo, isBold, isItalic);
-					
-					if (htmlFont != null)
-					{
-						if (!fontsToProcess.containsKey(htmlFont.getId()))
-						{
-							fontsToProcess.put(htmlFont.getId(), htmlFont);
-
-							HtmlFontUtil.handleFont(resourceHandler, htmlFont);
-						}
-						
-						fontFamily = htmlFont.getShortId();
-					}
-				}
-			}
-			else
-			{
-				fontFamily = exportFont;
-			}
-		}
-		
 		boolean localHyperlink = false;
 		JRPrintHyperlink hyperlink = (JRPrintHyperlink)attributes.get(JRTextAttribute.HYPERLINK);
 		if (!hyperlinkStarted && hyperlink != null)
@@ -1010,6 +969,13 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			localHyperlink = true;
 		}
 		
+		boolean isBold = TextAttribute.WEIGHT_BOLD.equals(attributes.get(TextAttribute.WEIGHT));
+		boolean isItalic = TextAttribute.POSTURE_OBLIQUE.equals(attributes.get(TextAttribute.POSTURE));
+
+		String fontFamily = resolveFontFamily(attributes, locale);
+
+		// do not put single quotes around family name here because the value might already contain quotes, 
+		// especially if it is coming from font extension export configuration
 		writer.write("<span style=\"font-family: ");
 		writer.write(fontFamily);
 		writer.write("; ");
@@ -1170,7 +1136,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			writer.write(" dir=\"rtl\"");
 		}
 
-		StringBuffer styleBuffer = new StringBuffer();
+		StringBuilder styleBuilder = new StringBuilder();
 
 		String verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
 
@@ -1187,6 +1153,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 				break;
 			}
 			case TOP :
+			case JUSTIFIED :
 			default :
 			{
 				verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
@@ -1195,14 +1162,14 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 
 		if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
 		{
-			styleBuffer.append(" vertical-align: ");
-			styleBuffer.append(verticalAlignment);
-			styleBuffer.append(";");
+			styleBuilder.append(" vertical-align: ");
+			styleBuilder.append(verticalAlignment);
+			styleBuilder.append(";");
 		}
 
-		appendBackcolorStyle(gridCell, styleBuffer);
-		appendBorderStyle(gridCell.getBox(), styleBuffer);
-		appendPaddingStyle(text.getLineBox(), styleBuffer);
+		appendBackcolorStyle(gridCell, styleBuilder);
+		appendBorderStyle(gridCell.getBox(), styleBuilder);
+		appendPaddingStyle(text.getLineBox(), styleBuilder);
 
 		String horizontalAlignment = CSS_TEXT_ALIGN_LEFT;
 
@@ -1239,9 +1206,9 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 					&& !horizontalAlignment.equals(CSS_TEXT_ALIGN_RIGHT))
 				)
 			{
-				styleBuffer.append("text-align: ");
-				styleBuffer.append(horizontalAlignment);
-				styleBuffer.append(";");
+				styleBuilder.append("text-align: ");
+				styleBuilder.append(horizontalAlignment);
+				styleBuilder.append(";");
 			}
 		}
 
@@ -1249,21 +1216,21 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 		
 		if (isWrapBreakWord)
 		{
-			styleBuffer.append("width: " + toSizeUnit(gridCell.getWidth()) + "; ");
-			styleBuffer.append("word-wrap: break-word; ");
+			styleBuilder.append("width: " + toSizeUnit(gridCell.getWidth()) + "; ");
+			styleBuilder.append("word-wrap: break-word; ");
 		}
 		
 		if (text.getLineBreakOffsets() != null)
 		{
 			//if we have line breaks saved in the text, set nowrap so that
 			//the text only wraps at the explicit positions
-			styleBuffer.append("white-space: nowrap; ");
+			styleBuilder.append("white-space: nowrap; ");
 		}
 		
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 		
@@ -1490,7 +1457,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	}
 
 
-	protected boolean appendBorderStyle(JRLineBox box, StringBuffer styleBuffer)
+	protected boolean appendBorderStyle(JRLineBox box, StringBuilder styleBuilder)
 	{
 		boolean addedToStyle = false;
 
@@ -1533,28 +1500,28 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 					tpc.equals(box.getRightPen().getLineColor())) 
 			{
 				addedToStyle |= appendPen(
-						styleBuffer,
+						styleBuilder,
 						box.getTopPen(),
 						null
 						);
 			} else {
 				addedToStyle |= appendPen(
-					styleBuffer,
+					styleBuilder,
 					box.getTopPen(),
 					"top"
 					);
 				addedToStyle |= appendPen(
-					styleBuffer,
+					styleBuilder,
 					box.getLeftPen(),
 					"left"
 					);
 				addedToStyle |= appendPen(
-					styleBuffer,
+					styleBuilder,
 					box.getBottomPen(),
 					"bottom"
 					);
 				addedToStyle |= appendPen(
-					styleBuffer,
+					styleBuilder,
 					box.getRightPen(),
 					"right"
 					);
@@ -1565,7 +1532,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	}
 
 
-	protected boolean appendPaddingStyle(JRLineBox box, StringBuffer styleBuffer)
+	protected boolean appendPaddingStyle(JRLineBox box, StringBuilder styleBuilder)
 	{
 		boolean addedToStyle = false;
 		
@@ -1580,29 +1547,29 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			if (tp == lp && tp == bp && tp == rp)
 			{
 				addedToStyle |= appendPadding(
-						styleBuffer,
+						styleBuilder,
 						tp,
 						null
 						);
 			} else 
 			{
 				addedToStyle |= appendPadding(
-						styleBuffer,
+						styleBuilder,
 						box.getTopPadding(),
 						"top"
 						);
 				addedToStyle |= appendPadding(
-						styleBuffer,
+						styleBuilder,
 						box.getLeftPadding(),
 						"left"
 						);
 				addedToStyle |= appendPadding(
-						styleBuffer,
+						styleBuilder,
 						box.getBottomPadding(),
 						"bottom"
 						);
 				addedToStyle |= appendPadding(
-						styleBuffer,
+						styleBuilder,
 						box.getRightPadding(),
 						"right"
 						);
@@ -1613,14 +1580,14 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	}
 
 
-	protected Color appendBackcolorStyle(JRExporterGridCell gridCell, StringBuffer styleBuffer)
+	protected Color appendBackcolorStyle(JRExporterGridCell gridCell, StringBuilder styleBuilder)
 	{
 		Color cellBackcolor = gridCell.getCellBackcolor();
 		if (cellBackcolor != null && (backcolor == null || cellBackcolor.getRGB() != backcolor.getRGB()))
 		{
-			styleBuffer.append("background-color: ");
-			styleBuffer.append(JRColorUtil.getCssColor(cellBackcolor));
-			styleBuffer.append("; ");
+			styleBuilder.append("background-color: ");
+			styleBuilder.append(JRColorUtil.getCssColor(cellBackcolor));
+			styleBuilder.append("; ");
 
 			return cellBackcolor;
 		}
@@ -1636,7 +1603,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		writeCellStart(gridCell);
 
-		StringBuffer styleBuffer = new StringBuffer();
+		StringBuilder styleBuilder = new StringBuilder();
 
 		String horizontalAlignment = CSS_TEXT_ALIGN_LEFT;
 
@@ -1661,9 +1628,9 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 
 		if (!horizontalAlignment.equals(CSS_TEXT_ALIGN_LEFT))
 		{
-			styleBuffer.append("text-align: ");
-			styleBuffer.append(horizontalAlignment);
-			styleBuffer.append(";");
+			styleBuilder.append("text-align: ");
+			styleBuilder.append(horizontalAlignment);
+			styleBuilder.append(";");
 		}
 
 		String verticalAlignment = HTML_VERTICAL_ALIGN_TOP;
@@ -1689,29 +1656,29 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 
 		if (!verticalAlignment.equals(HTML_VERTICAL_ALIGN_TOP))
 		{
-			styleBuffer.append(" vertical-align: ");
-			styleBuffer.append(verticalAlignment);
-			styleBuffer.append(";");
+			styleBuilder.append(" vertical-align: ");
+			styleBuilder.append(verticalAlignment);
+			styleBuilder.append(";");
 		}
 
-		appendBackcolorStyle(gridCell, styleBuffer);
+		appendBackcolorStyle(gridCell, styleBuilder);
 		
-		boolean addedToStyle = appendBorderStyle(gridCell.getBox(), styleBuffer);
+		boolean addedToStyle = appendBorderStyle(gridCell.getBox(), styleBuilder);
 		if (!addedToStyle)
 		{
 			appendPen(
-				styleBuffer,
+				styleBuilder,
 				image.getLinePen(),
 				null
 				);
 		}
 
-		appendPaddingStyle(image.getLineBox(), styleBuffer);
+		appendPaddingStyle(image.getLineBox(), styleBuilder);
 
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 
@@ -1724,18 +1691,20 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			writer.write("\"/>");
 		}
 		
-		Renderable renderer = image.getRenderable();
-		Renderable originalRenderer = renderer;
-		boolean imageMapRenderer = renderer != null 
-				&& renderer instanceof ImageMapRenderable
+		Renderable renderer = image.getRenderer();
+
+		boolean isLazy = RendererUtil.isLazy(renderer);
+		
+		boolean isUsingImagesToAlign = getCurrentConfiguration().isUsingImagesToAlign();
+		if (renderer != null || isUsingImagesToAlign)
+		{
+			boolean hasAreaHyperlinks =  
+				renderer instanceof ImageMapRenderable
 				&& ((ImageMapRenderable) renderer).hasImageAreaHyperlinks();
 
-		boolean hasHyperlinks = false;
+			boolean hasHyperlinks = false;
 
-		boolean isUsingImagesToAlign = getCurrentConfiguration().isUsingImagesToAlign();
-		if(renderer != null || isUsingImagesToAlign)
-		{
-			if (imageMapRenderer)
+			if (hasAreaHyperlinks)
 			{
 				hasHyperlinks = true;
 				hyperlinkStarted = false;
@@ -1750,72 +1719,130 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			String imageMapName = null;
 			List<JRPrintImageAreaHyperlink> imageMapAreas = null;
 	
+			int availableImageWidth = image.getWidth() - image.getLineBox().getLeftPadding().intValue() - image.getLineBox().getRightPadding().intValue();
+			if (availableImageWidth < 0)
+			{
+				availableImageWidth = 0;
+			}
+		
+			int availableImageHeight = image.getHeight() - image.getLineBox().getTopPadding().intValue() - image.getLineBox().getBottomPadding().intValue();
+			if (availableImageHeight < 0)
+			{
+				availableImageHeight = 0;
+			}
+		
 			ScaleImageEnum scaleImage = image.getScaleImageValue();
 			
 			if (renderer != null)
 			{
-				if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
+				if (isLazy)
 				{
-					imagePath = rendererToImagePathMap.get(renderer.getId());
+					// we do not cache imagePath for lazy images because the short location string is already cached inside the render itself
+					imagePath = RendererUtil.getResourceLocation(renderer);
 				}
 				else
 				{
-					if (image.isLazy())
+					if (renderer instanceof ResourceRenderer)
 					{
-						imagePath = ((JRImageRenderer)renderer).getImageLocation();
+						renderer = renderersCache.getLoadedRenderer((ResourceRenderer)renderer);
+					}
+
+					boolean isEmbedImage = isEmbedImage(image);
+					
+					if (
+						!isEmbedImage //we do not cache imagePath for embedded images because it is too big
+						&& renderer instanceof DataRenderable //we do not cache imagePath for non-data renderers because they render width different width/height each time
+						&& rendererToImagePathMap.containsKey(renderer.getId())
+						)
+					{
+						imagePath = rendererToImagePathMap.get(renderer.getId());
 					}
 					else
 					{
-						HtmlResourceHandler imageHandler = 
-							getImageHandler() == null 
-							? getExporterOutput().getImageHandler() 
-							: getImageHandler();
-						if (imageHandler != null)
+						if (isEmbedImage)
 						{
-							JRPrintElementIndex imageIndex = getElementIndex(gridCell);
-							String imageName = getImageName(imageIndex);
+							DataRenderable dataRenderer = 
+								getRendererUtil().getDataRenderable(
+									renderer,
+									new Dimension(availableImageWidth, availableImageHeight),
+									ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
+									);
 
-							if (renderer.getTypeValue() == RenderableTypeEnum.SVG)
-							{
-								renderer =
-									new JRWrappingSvgRenderer(
-										renderer,
-										new Dimension(image.getWidth(), image.getHeight()),
-										ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
-										);
-							}
-
-							byte[] imageData = renderer.getImageData(jasperReportsContext);
+							byte[] imageData = dataRenderer.getData(jasperReportsContext);
 
+							String imageMimeType = 
+								getRendererUtil().isSvgData(imageData)
+								? "image/svg+xml"
+								: JRTypeSniffer.getImageTypeValue(imageData).getMimeType();
+							
+							ByteArrayInputStream bais = new ByteArrayInputStream(imageData);
+							ByteArrayOutputStream baos = new ByteArrayOutputStream();
+							
+							Base64Encoder encoder = new Base64Encoder(bais, baos);
+							encoder.process();
+							
+							String encoding = getExporterOutput().getEncoding();
+							
+							imagePath = "data:" + imageMimeType + ";base64," + new String(baos.toByteArray(), encoding);
+							//don't cache the base64 encoded image as imagePath because they are too big
+						}
+						else
+						{
+							HtmlResourceHandler imageHandler = 
+								getImageHandler() == null 
+								? getExporterOutput().getImageHandler() 
+								: getImageHandler();
 							if (imageHandler != null)
 							{
+								DataRenderable dataRenderer = 
+									getRendererUtil().getDataRenderable(
+										renderer,
+										new Dimension(availableImageWidth, availableImageHeight),
+										ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
+										);
+
+								byte[] imageData = dataRenderer.getData(jasperReportsContext);
+
+								String fileExtension = 
+									getRendererUtil().isSvgData(imageData)
+									? RendererUtil.SVG_FILE_EXTENSION
+									: JRTypeSniffer.getImageTypeValue(imageData).getFileExtension();
+
+								String imageName = getImageName(getElementIndex(gridCell), fileExtension);
+
 								imageHandler.handleResource(imageName, imageData);
 
 								imagePath = imageHandler.getResourcePath(imageName);
+
+								if (dataRenderer == renderer)
+								{
+									//cache imagePath only for true ImageRenderable instances because the wrapping ones render with different width/height each time
+									rendererToImagePathMap.put(renderer.getId(), imagePath);
+								}
 							}
+							//does not make sense to cache null imagePath, in the absence of an image handler
 						}
 					}
-	
-					rendererToImagePathMap.put(renderer.getId(), imagePath);
-				}
-				
-				if (imageMapRenderer)
-				{
-					Rectangle renderingArea = new Rectangle(image.getWidth(), image.getHeight());
 					
-					if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
+					if (hasAreaHyperlinks)
 					{
-						imageMapName = imageMaps.get(new Pair<String, Rectangle>(renderer.getId(), renderingArea));
-					}
-	
-					if (imageMapName == null)
-					{
-						imageMapName = "map_" + getElementIndex(gridCell).toString();
-						imageMapAreas = ((ImageMapRenderable) originalRenderer).getImageAreaHyperlinks(renderingArea);//FIXMECHART
+						Rectangle renderingArea = new Rectangle(image.getWidth(), image.getHeight());
 						
-						if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
+						if (renderer instanceof DataRenderable)
 						{
-							imageMaps.put(new Pair<String, Rectangle>(renderer.getId(), renderingArea), imageMapName);
+							imageMapName = imageMaps.get(new Pair<String, Rectangle>(renderer.getId(), renderingArea));
+						}
+		
+						if (imageMapName == null)
+						{
+							Renderable originalRenderer = image.getRenderer();
+							imageMapName = "map_" + getElementIndex(gridCell).toString();
+							imageMapAreas = ((AreaHyperlinksRenderable) originalRenderer).getImageAreaHyperlinks(renderingArea);//FIXMECHART
+							
+							if (renderer instanceof DataRenderable)
+							{
+								imageMaps.put(new Pair<String, Rectangle>(renderer.getId(), renderingArea), imageMapName);
+							}
 						}
 					}
 				}
@@ -1834,26 +1861,14 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			}
 			writer.write("\"");
 		
-			int imageWidth = image.getWidth() - image.getLineBox().getLeftPadding().intValue() - image.getLineBox().getRightPadding().intValue();
-			if (imageWidth < 0)
-			{
-				imageWidth = 0;
-			}
-		
-			int imageHeight = image.getHeight() - image.getLineBox().getTopPadding().intValue() - image.getLineBox().getBottomPadding().intValue();
-			if (imageHeight < 0)
-			{
-				imageHeight = 0;
-			}
-		
 			switch (scaleImage)
 			{
 				case FILL_FRAME :
 				{
 					writer.write(" style=\"width: ");
-					writer.write(toSizeUnit(imageWidth));
+					writer.write(toSizeUnit(availableImageWidth));
 					writer.write("; height: ");
-					writer.write(toSizeUnit(imageHeight));
+					writer.write(toSizeUnit(availableImageHeight));
 					writer.write("\"");
 		
 					break;
@@ -1862,37 +1877,43 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 				case RETAIN_SHAPE :
 				default :
 				{
-					double normalWidth = imageWidth;
-					double normalHeight = imageHeight;
+					double normalWidth = availableImageWidth;
+					double normalHeight = availableImageHeight;
 		
-					if (!image.isLazy())
+					if (!isLazy)
 					{
 						// Image load might fail. 
 						Renderable tmpRenderer = 
-							RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
-						Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension(jasperReportsContext);
-						// If renderer was replaced, ignore image dimension.
-						if (tmpRenderer == renderer && dimension != null)
+							net.sf.jasperreports.engine.RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(
+								renderersCache,
+								renderer, 
+								image.getOnErrorTypeValue()
+								);
+						if (tmpRenderer instanceof DimensionRenderable)
 						{
-							normalWidth = dimension.getWidth();
-							normalHeight = dimension.getHeight();
+							Dimension2D dimension = ((DimensionRenderable)tmpRenderer).getDimension(jasperReportsContext);
+							if (dimension != null)
+							{
+								normalWidth = dimension.getWidth();
+								normalHeight = dimension.getHeight();
+							}
 						}
 					}
 		
-					if (imageHeight > 0)
+					if (availableImageHeight > 0)
 					{
 						double ratio = normalWidth / normalHeight;
 		
-						if( ratio > (double)imageWidth / (double)imageHeight )
+						if( ratio > (double)availableImageWidth / (double)availableImageHeight )
 						{
 							writer.write(" style=\"width: ");
-							writer.write(toSizeUnit(imageWidth));
+							writer.write(toSizeUnit(availableImageWidth));
 							writer.write("\"");
 						}
 						else
 						{
 							writer.write(" style=\"height: ");
-							writer.write(toSizeUnit(imageHeight));
+							writer.write(toSizeUnit(availableImageHeight));
 							writer.write("\"");
 						}
 					}
@@ -1975,7 +1996,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		if (coords != null && coords.length > 0)
 		{
-			StringBuffer coordsEnum = new StringBuffer(coords.length * 4);
+			StringBuilder coordsEnum = new StringBuilder(coords.length * 4);
 			coordsEnum.append(toZoom(coords[0]));
 			for (int i = 1; i < coords.length; i++)
 			{
@@ -2022,7 +2043,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	protected void loadPxImage() throws JRException
 	{
 		Renderable pxRenderer =
-			RenderableUtil.getInstance(jasperReportsContext).getRenderable("net/sf/jasperreports/engine/images/pixel.GIF");
+			net.sf.jasperreports.engine.RenderableUtil.getInstance(jasperReportsContext).getRenderable(JRImageLoader.PIXEL_IMAGE_RESOURCE);
 
 		String imageName = "px";
 		String imagePath = null;
@@ -2033,15 +2054,11 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 			: getImageHandler();
 		if (imageHandler != null)
 		{
-			byte[] imageData = pxRenderer.getImageData(jasperReportsContext);
+			byte[] imageData = ((DataRenderable)pxRenderer).getData(jasperReportsContext);
 			
-			if (imageHandler != null)
-			{
-				imageHandler.handleResource(imageName, imageData);
-
-				imagePath = imageHandler.getResourcePath(imageName);
-			}
+			imageHandler.handleResource(imageName, imageData);
 
+			imagePath = imageHandler.getResourcePath(imageName);
 		}
 
 		rendererToImagePathMap.put(pxRenderer.getId(), imagePath);
@@ -2071,7 +2088,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	/**
 	 *
 	 */
-	private boolean appendPadding(StringBuffer sb, Integer padding, String side)
+	private boolean appendPadding(StringBuilder sb, Integer padding, String side)
 	{
 		boolean addedToStyle = false;
 		
@@ -2097,7 +2114,7 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	/**
 	 *
 	 */
-	private boolean appendPen(StringBuffer sb, JRPen pen, String side)
+	private boolean appendPen(StringBuilder sb, JRPen pen, String side)
 	{
 		boolean addedToStyle = false;
 		
@@ -2163,15 +2180,15 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		writeCellStart(gridCell);
 
-		StringBuffer styleBuffer = new StringBuffer();
-		Color frameBackcolor = appendBackcolorStyle(gridCell, styleBuffer);
-		appendBorderStyle(gridCell.getBox(), styleBuffer);
+		StringBuilder styleBuilder = new StringBuilder();
+		Color frameBackcolor = appendBackcolorStyle(gridCell, styleBuilder);
+		appendBorderStyle(gridCell.getBox(), styleBuilder);
 		//no padding style for frames, because padding is in the grid
 
-		if (styleBuffer.length() > 0)
+		if (styleBuilder.length() > 0)
 		{
 			writer.write(" style=\"");
-			writer.write(styleBuffer.toString());
+			writer.write(styleBuilder.toString());
 			writer.write("\"");
 		}
 
@@ -2232,13 +2249,13 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 		{
 			writeCellStart(gridCell);
 
-			StringBuffer styleBuffer = new StringBuffer();
-			appendBackcolorStyle(gridCell, styleBuffer);
-			appendBorderStyle(gridCell.getBox(), styleBuffer);
-			if (styleBuffer.length() > 0)
+			StringBuilder styleBuilder = new StringBuilder();
+			appendBackcolorStyle(gridCell, styleBuilder);
+			appendBorderStyle(gridCell.getBox(), styleBuilder);
+			if (styleBuilder.length() > 0)
 			{
 				writer.write(" style=\"");
-				writer.write(styleBuffer.toString());
+				writer.write(styleBuilder.toString());
 				writer.write("\"");
 			}
 
@@ -2254,16 +2271,18 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 		}
 	}
 
-	public Map<JRExporterParameter,Object> getExportParameters()
+	public Map<net.sf.jasperreports.engine.JRExporterParameter,Object> getExportParameters()
 	{
 		return parameters;
 	}
 
+	@Override
 	public String getExporterPropertiesPrefix()
 	{
 		return HTML_EXPORTER_PROPERTIES_PREFIX;
 	}
 	
+	@Override
 	public String getExporterKey()
 	{
 		return HTML_EXPORTER_KEY;
@@ -2321,27 +2340,6 @@ public class JRHtmlExporter extends AbstractHtmlExporter<JRHtmlReportConfigurati
 	{
 		return (int)toZoom((float)size);
 	}
-
-
-	protected JRStyledText getStyledText(JRPrintText textElement,
-			boolean setBackcolor)
-	{
-		JRStyledText styledText = super.getStyledText(textElement, setBackcolor);
-		
-		if (styledText != null)
-		{
-			short[] lineBreakOffsets = textElement.getLineBreakOffsets();
-			if (lineBreakOffsets != null && lineBreakOffsets.length > 0)
-			{
-				//insert new lines at the line break positions saved at fill time
-				//cloning the text first
-				styledText = styledText.cloneText();
-				styledText.insert("\n", lineBreakOffsets);
-			}
-		}
-		
-		return styledText;
-	}
 	
 }
 
