@@ -45,6 +45,9 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.JRAbstractExporter;
 import net.sf.jasperreports.engine.JRException;
@@ -63,32 +66,30 @@ import net.sf.jasperreports.engine.JRPrintPage;
 import net.sf.jasperreports.engine.JRPrintRectangle;
 import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesUtil;
-import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperReportsContext;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
 import net.sf.jasperreports.engine.TabStop;
 import net.sf.jasperreports.engine.base.JRBaseFont;
 import net.sf.jasperreports.engine.base.JRBasePrintText;
-import net.sf.jasperreports.engine.fonts.FontFamily;
-import net.sf.jasperreports.engine.fonts.FontInfo;
-import net.sf.jasperreports.engine.fonts.FontUtil;
 import net.sf.jasperreports.engine.type.ImageTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.type.OrientationEnum;
-import net.sf.jasperreports.engine.type.RenderableTypeEnum;
 import net.sf.jasperreports.engine.type.RunDirectionEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.util.FileBufferedWriter;
+import net.sf.jasperreports.engine.util.ImageUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
+import net.sf.jasperreports.engine.util.JRTypeSniffer;
 import net.sf.jasperreports.export.ExportInterruptedException;
 import net.sf.jasperreports.export.ExporterInputItem;
 import net.sf.jasperreports.export.RtfExporterConfiguration;
 import net.sf.jasperreports.export.RtfReportConfiguration;
 import net.sf.jasperreports.export.WriterExporterOutput;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.renderers.DataRenderable;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.RenderersCache;
+import net.sf.jasperreports.renderers.ResourceRenderer;
 
 /**
  * Exports a JasperReports document to RTF format. 
@@ -151,6 +152,8 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	// z order of the graphical objects in .rtf file
 	private int zorder = 1;
 
+	protected RenderersCache renderersCache;
+	
 	protected class ExporterContext extends BaseExporterContext implements JRRtfExporterContext
 	{
 	}
@@ -176,27 +179,21 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<RtfExporterConfiguration> getConfigurationInterface()
 	{
 		return RtfExporterConfiguration.class;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<RtfReportConfiguration> getItemConfigurationInterface()
 	{
 		return RtfReportConfiguration.class;
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	@SuppressWarnings("deprecation")
 	protected void ensureOutput()
 	{
@@ -212,9 +209,7 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	}
 	
 
-	/**
-	 * Export report in .rtf format
-	 */
+	@Override
 	public void exportReport() throws JRException
 	{
 		/*   */
@@ -262,6 +257,8 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	protected void initReport()
 	{
 		super.initReport();
+		
+		renderersCache = new RenderersCache(getJasperReportsContext());
 	}
 	
 
@@ -278,12 +275,12 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 
 		List<ExporterInputItem> items = exporterInput.getItems();
 
-		for(reportIndex = 0; reportIndex < items.size(); reportIndex++ )
+		for (reportIndex = 0; reportIndex < items.size(); reportIndex++ )
 		{
 			ExporterInputItem item = items.get(reportIndex);
 
 			setCurrentExporterInputItem(item);
-			
+
 			List<JRPrintPage> pages = jasperPrint.getPages();
 			if (pages != null && pages.size() > 0)
 			{
@@ -399,19 +396,7 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	 */
 	private int getFontIndex(JRFont font, Locale locale) throws IOException
 	{
-		String fontName = font.getFontName();
-
-		FontInfo fontInfo = FontUtil.getInstance(jasperReportsContext).getFontInfo(fontName, locale);
-		if (fontInfo != null)
-		{
-			//fontName found in font extensions
-			FontFamily family = fontInfo.getFontFamily();
-			String exportFont = family.getExportFont(getExporterKey());
-			if (exportFont != null)
-			{
-				fontName = exportFont;
-			}
-		}
+		String fontName = fontUtil.getExportFontFamily(font.getFontName(), locale, getExporterKey());
 
 		int fontIndex = fonts.indexOf(fontName);
 
@@ -716,8 +701,9 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 			{
 				switch (text.getVerticalTextAlign())
 				{
-					case TOP:
+					case BOTTOM:
 					{
+						leftPadding = Math.max(leftPadding, width - rightPadding - textHeight);
 						break;
 					}
 					case MIDDLE:
@@ -725,10 +711,10 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 						leftPadding = Math.max(leftPadding, (width - rightPadding - textHeight) / 2);
 						break;
 					}
-					case BOTTOM:
+					case TOP:
+					case JUSTIFIED:
+					default:
 					{
-						leftPadding = Math.max(leftPadding, width - rightPadding - textHeight);
-						break;
 					}
 				}
 				rotation = "{\\sp{\\sn txflTextFlow}{\\sv 2}}";
@@ -738,8 +724,9 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 			{
 				switch (text.getVerticalTextAlign())
 				{
-					case TOP:
+					case BOTTOM:
 					{
+						rightPadding = Math.max(rightPadding, width - leftPadding - textHeight);
 						break;
 					}
 					case MIDDLE:
@@ -747,10 +734,10 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 						rightPadding = Math.max(rightPadding, (width - leftPadding - textHeight) / 2);
 						break;
 					}
-					case BOTTOM:
+					case TOP:
+					case JUSTIFIED:
+					default:
 					{
-						rightPadding = Math.max(rightPadding, width - leftPadding - textHeight);
-						break;
 					}
 				}
 				rotation = "{\\sp{\\sn txflTextFlow}{\\sv 3}}";
@@ -771,8 +758,9 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 						break;
 					}
 					case BOTTOM:
+					case JUSTIFIED:
+					default:
 					{
-						break;
 					}
 				}
 				rotation = "";
@@ -783,8 +771,9 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 			{
 				switch (text.getVerticalTextAlign())
 				{
-					case TOP:
+					case BOTTOM:
 					{
+						topPadding = Math.max(topPadding, height - bottomPadding - textHeight);
 						break;
 					}
 					case MIDDLE:
@@ -792,10 +781,10 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 						topPadding = Math.max(topPadding, (height - bottomPadding - textHeight) / 2);
 						break;
 					}
-					case BOTTOM:
+					case TOP:
+					case JUSTIFIED:
+					default:
 					{
-						topPadding = Math.max(topPadding, height - bottomPadding - textHeight);
-						break;
 					}
 				}
 				rotation = "";
@@ -1027,7 +1016,7 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 	 */
 	private String handleUnicodeText(String sourceText)
 	{
-		StringBuffer unicodeText = new StringBuffer();
+		StringBuilder unicodeText = new StringBuilder();
 		
 		for(int i = 0; i < sourceText.length(); i++ )
 		{
@@ -1073,126 +1062,129 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 		int availableImageHeight = printImage.getHeight() - topPadding - bottomPadding;
 		availableImageHeight = availableImageHeight < 0 ? 0 : availableImageHeight;
 
-		Renderable renderer = printImage.getRenderable();
+		Renderable renderer = printImage.getRenderer();
 
 		if (
-			renderer != null &&
-			availableImageWidth > 0 &&
-			availableImageHeight > 0
+			renderer != null 
+			&& availableImageWidth > 0 
+			&& availableImageHeight > 0
 			)
 		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
+			InternalImageProcessor imageProcessor = 
+				new InternalImageProcessor(
+					printImage, 
+					printImage.getScaleImageValue() != ScaleImageEnum.FILL_FRAME,
+					availableImageWidth,
+					availableImageHeight
+					);
+				
+			InternalImageProcessorResult imageProcessorResult = null;
+			
+			try
 			{
-				// Image renderers are all asked for their image data at some point.
-				// Better to test and replace the renderer now, in case of lazy load error.
-				renderer = RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForImageData(renderer, printImage.getOnErrorTypeValue());
+				imageProcessorResult = imageProcessor.process(renderer);
 			}
-		}
-		else
-		{
-			renderer = null;
-		}
-
-		if (renderer != null)
-		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.SVG)
+			catch (Exception e)
 			{
-				renderer =
-					new JRWrappingSvgRenderer(
-						renderer,
-						new Dimension(printImage.getWidth(), printImage.getHeight()),
-						ModeEnum.OPAQUE == printImage.getModeValue() ? printImage.getBackcolor() : null
-						);
-			}
-
-			int normalWidth = availableImageWidth;
-			int normalHeight = availableImageHeight;
-
-			// Image load might fail.
-			Renderable tmpRenderer =
-				RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(renderer, printImage.getOnErrorTypeValue());
-			Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension(jasperReportsContext);
-			// If renderer was replaced, ignore image dimension.
-			if (tmpRenderer == renderer && dimension != null)
-			{
-				normalWidth = (int) dimension.getWidth();
-				normalHeight = (int) dimension.getHeight();
-			}
-
-			int imageWidth = 0;
-			int imageHeight = 0;
-			int xoffset = 0;
-			int yoffset = 0;
-			int cropTop = 0;
-			int cropLeft = 0;
-			int cropBottom = 0;
-			int cropRight = 0;
-
-			switch (printImage.getScaleImageValue())
-			{
-				case CLIP:
+				Renderable onErrorRenderer = getRendererUtil().handleImageError(e, printImage.getOnErrorTypeValue());
+				if (onErrorRenderer != null)
 				{
-					switch (printImage.getHorizontalImageAlign())
-					{
-						case RIGHT :
-						{
-							cropLeft = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth;
-							cropRight = 0;
-							break;
-						}
-						case CENTER :
-						{
-							cropLeft = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth / 2;
-							cropRight = cropLeft;
-							break;
-						}
-						case LEFT :
-						default :
-						{
-							cropLeft = 0;
-							cropRight = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth;
-							break;
-						}
-					}
-					switch (printImage.getVerticalImageAlign())
-					{
-						case TOP :
-						{
-							cropTop = 0;
-							cropBottom = 65536 * (- availableImageHeight + normalHeight) / normalHeight;
-							break;
-						}
-						case MIDDLE :
-						{
-							cropTop = 65536 * (- availableImageHeight + normalHeight) / normalHeight / 2;
-							cropBottom = cropTop;
-							break;
-						}
-						case BOTTOM :
-						default :
-						{
-							cropTop = 65536 * (- availableImageHeight + normalHeight) / normalHeight;
-							cropBottom = 0;
-							break;
-						}
-					}
-					imageWidth = availableImageWidth;
-					imageHeight = availableImageHeight;
-					break;
+					imageProcessorResult = imageProcessor.process(onErrorRenderer);
 				}
-				case FILL_FRAME:
+			}
+			
+			if (imageProcessorResult != null)//FIXMERTF draw image background for null images, like the other exporters do
+			{
+				int imageWidth = 0;
+				int imageHeight = 0;
+				int xoffset = 0;
+				int yoffset = 0;
+				int cropTop = 0;
+				int cropLeft = 0;
+				int cropBottom = 0;
+				int cropRight = 0;
+
+				switch (printImage.getScaleImageValue())
 				{
-					normalWidth = availableImageWidth;
-					normalHeight = availableImageHeight;
-					imageWidth = availableImageWidth;
-					imageHeight = availableImageHeight;
-					break;
-				}
-				case RETAIN_SHAPE:
-				default:
-				{
-					if (printImage.getHeight() > 0)
+					case CLIP:
 					{
+						int normalWidth = availableImageWidth;
+						int normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = (int) dimension.getWidth();
+							normalHeight = (int) dimension.getHeight();
+						}
+
+						switch (printImage.getHorizontalImageAlign())
+						{
+							case RIGHT :
+							{
+								cropLeft = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth;
+								cropRight = 0;
+								break;
+							}
+							case CENTER :
+							{
+								cropLeft = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth / 2;
+								cropRight = cropLeft;
+								break;
+							}
+							case LEFT :
+							default :
+							{
+								cropLeft = 0;
+								cropRight = 65536 * (- availableImageWidth + normalWidth) / availableImageWidth;
+								break;
+							}
+						}
+						switch (printImage.getVerticalImageAlign())
+						{
+							case TOP :
+							{
+								cropTop = 0;
+								cropBottom = 65536 * (- availableImageHeight + normalHeight) / normalHeight;
+								break;
+							}
+							case MIDDLE :
+							{
+								cropTop = 65536 * (- availableImageHeight + normalHeight) / normalHeight / 2;
+								cropBottom = cropTop;
+								break;
+							}
+							case BOTTOM :
+							default :
+							{
+								cropTop = 65536 * (- availableImageHeight + normalHeight) / normalHeight;
+								cropBottom = 0;
+								break;
+							}
+						}
+						imageWidth = availableImageWidth;
+						imageHeight = availableImageHeight;
+						break;
+					}
+					case FILL_FRAME:
+					{
+						imageWidth = availableImageWidth;
+						imageHeight = availableImageHeight;
+						break;
+					}
+					case RETAIN_SHAPE:
+					default:
+					{
+						int normalWidth = availableImageWidth;
+						int normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = (int) dimension.getWidth();
+							normalHeight = (int) dimension.getHeight();
+						}
+
 						double ratio = (double) normalWidth / (double) normalHeight;
 
 						if (ratio > (double) availableImageWidth / (double) availableImageHeight)
@@ -1206,89 +1198,89 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 							normalHeight = availableImageHeight;
 						}
 
-						xoffset = (int) (getXAlignFactor(printImage) * (availableImageWidth - normalWidth));
-						yoffset = (int) (getYAlignFactor(printImage) * (availableImageHeight - normalHeight));
+						xoffset = (int) (ImageUtil.getXAlignFactor(printImage) * (availableImageWidth - normalWidth));
+						yoffset = (int) (ImageUtil.getYAlignFactor(printImage) * (availableImageHeight - normalHeight));
 						imageWidth = normalWidth;
 						imageHeight = normalHeight;
+
+						break;
 					}
-
-					break;
 				}
-			}
 
-			startElement(printImage);
-			exportPen(printImage.getForecolor());//FIXMEBORDER should we have lineColor here, if at all needed?
-			finishElement();
-			boolean startedHyperlink = exportHyperlink(printImage);
+				startElement(printImage);
+				exportPen(printImage.getForecolor());//FIXMEBORDER should we have lineColor here, if at all needed?
+				finishElement();
+				boolean startedHyperlink = exportHyperlink(printImage);
 
-			contentWriter.write("{\\shp{\\*\\shpinst\\shpbxpage\\shpbypage\\shpwr5\\shpfhdr0\\shpfblwtxt0\\shpz");
-			contentWriter.write(String.valueOf(zorder++));
-			contentWriter.write("\\shpleft");
-			contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getX() + leftPadding + xoffset + getOffsetX())));
-			contentWriter.write("\\shpright");
-			contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getX() + leftPadding + xoffset + getOffsetX() + imageWidth)));
-			contentWriter.write("\\shptop");
-			contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getY() + topPadding + yoffset + getOffsetY())));
-			contentWriter.write("\\shpbottom");
-			contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getY() + topPadding + yoffset + getOffsetY() + imageHeight)));
-			contentWriter.write("{\\sp{\\sn shapeType}{\\sv 75}}");
-			contentWriter.write("{\\sp{\\sn fFilled}{\\sv 0}}");
-			contentWriter.write("{\\sp{\\sn fLockAspectRatio}{\\sv 0}}");
+				contentWriter.write("{\\shp{\\*\\shpinst\\shpbxpage\\shpbypage\\shpwr5\\shpfhdr0\\shpfblwtxt0\\shpz");
+				contentWriter.write(String.valueOf(zorder++));
+				contentWriter.write("\\shpleft");
+				contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getX() + leftPadding + xoffset + getOffsetX())));
+				contentWriter.write("\\shpright");
+				contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getX() + leftPadding + xoffset + getOffsetX() + imageWidth)));
+				contentWriter.write("\\shptop");
+				contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getY() + topPadding + yoffset + getOffsetY())));
+				contentWriter.write("\\shpbottom");
+				contentWriter.write(String.valueOf(LengthUtil.twip(printImage.getY() + topPadding + yoffset + getOffsetY() + imageHeight)));
+				contentWriter.write("{\\sp{\\sn shapeType}{\\sv 75}}");
+				contentWriter.write("{\\sp{\\sn fFilled}{\\sv 0}}");
+				contentWriter.write("{\\sp{\\sn fLockAspectRatio}{\\sv 0}}");
 
-			contentWriter.write("{\\sp{\\sn cropFromTop}{\\sv ");
-			contentWriter.write(String.valueOf(cropTop));
-			contentWriter.write("}}");
-			contentWriter.write("{\\sp{\\sn cropFromLeft}{\\sv ");
-			contentWriter.write(String.valueOf(cropLeft));
-			contentWriter.write("}}");
-			contentWriter.write("{\\sp{\\sn cropFromBottom}{\\sv ");
-			contentWriter.write(String.valueOf(cropBottom));
-			contentWriter.write("}}");
-			contentWriter.write("{\\sp{\\sn cropFromRight}{\\sv ");
-			contentWriter.write(String.valueOf(cropRight));
-			contentWriter.write("}}");
-			
-			writeShapeHyperlink(printImage);
+				contentWriter.write("{\\sp{\\sn cropFromTop}{\\sv ");
+				contentWriter.write(String.valueOf(cropTop));
+				contentWriter.write("}}");
+				contentWriter.write("{\\sp{\\sn cropFromLeft}{\\sv ");
+				contentWriter.write(String.valueOf(cropLeft));
+				contentWriter.write("}}");
+				contentWriter.write("{\\sp{\\sn cropFromBottom}{\\sv ");
+				contentWriter.write(String.valueOf(cropBottom));
+				contentWriter.write("}}");
+				contentWriter.write("{\\sp{\\sn cropFromRight}{\\sv ");
+				contentWriter.write(String.valueOf(cropRight));
+				contentWriter.write("}}");
+				
+				writeShapeHyperlink(printImage);
 
-			if(printImage.getAnchorName() != null)
-			{
-				writeAnchor(printImage.getAnchorName());
-			}
-			
-			contentWriter.write("{\\sp{\\sn pib}{\\sv {\\pict");
-			if (renderer.getImageTypeValue() == ImageTypeEnum.JPEG)
-			{
-				contentWriter.write("\\jpegblip");
-			}
-			else
-			{
-				contentWriter.write("\\pngblip");
-			}
-			contentWriter.write("\n");
-
-			ByteArrayInputStream bais = new ByteArrayInputStream(renderer.getImageData(jasperReportsContext));
-
-			int count = 0;
-			int current = 0;
-			while ((current = bais.read()) != -1)
-			{
-				String helperStr = Integer.toHexString(current);
-				if (helperStr.length() < 2)
+				if(printImage.getAnchorName() != null)
 				{
-					helperStr = "0" + helperStr;
+					writeAnchor(printImage.getAnchorName());
 				}
-				contentWriter.write(helperStr);
-				count++;
-				if (count == 64)
+				
+				contentWriter.write("{\\sp{\\sn pib}{\\sv {\\pict");
+				if (imageProcessorResult.imageType == ImageTypeEnum.JPEG)
 				{
-					contentWriter.write("\n");
-					count = 0;
+					contentWriter.write("\\jpegblip");
 				}
-			}
+				else
+				{
+					contentWriter.write("\\pngblip");
+				}
+				contentWriter.write("\n");
 
-			contentWriter.write("\n}}}");
-			contentWriter.write("}}\n");
-			endHyperlink(startedHyperlink);
+				ByteArrayInputStream bais = new ByteArrayInputStream(imageProcessorResult.imageData);
+
+				int count = 0;
+				int current = 0;
+				while ((current = bais.read()) != -1)
+				{
+					String helperStr = Integer.toHexString(current);
+					if (helperStr.length() < 2)
+					{
+						helperStr = "0" + helperStr;
+					}
+					contentWriter.write(helperStr);
+					count++;
+					if (count == 64)
+					{
+						contentWriter.write("\n");
+						count = 0;
+					}
+				}
+
+				contentWriter.write("\n}}}");
+				contentWriter.write("}}\n");
+				endHyperlink(startedHyperlink);
+			}
 		}
 
 		int x = printImage.getX() + getOffsetX();
@@ -1314,6 +1306,73 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 		}
 	}
 
+	private class InternalImageProcessor
+	{
+		private final JRPrintElement imageElement;
+		private final boolean needDimension; 
+		private final int availableImageWidth; 
+		private final int availableImageHeight; 
+
+		protected InternalImageProcessor(
+			JRPrintElement imageElement,
+			boolean needDimension,
+			int availableImageWidth,
+			int availableImageHeight
+			)
+		{
+			this.imageElement = imageElement;
+			this.needDimension = needDimension;
+			this.availableImageWidth = availableImageWidth;
+			this.availableImageHeight = availableImageHeight;
+		}
+		
+		private InternalImageProcessorResult process(Renderable renderer) throws JRException
+		{
+			if (renderer instanceof ResourceRenderer)
+			{
+				renderer = renderersCache.getLoadedRenderer((ResourceRenderer)renderer);
+			}
+			
+			Dimension2D dimension = null;
+			if (needDimension)
+			{
+				DimensionRenderable dimensionRenderer = renderersCache.getDimensionRenderable(renderer);
+				dimension = dimensionRenderer == null ? null :  dimensionRenderer.getDimension(jasperReportsContext);
+			}
+			
+			DataRenderable imageRenderer = 
+				getRendererUtil().getImageDataRenderable(
+					renderersCache,
+					renderer,
+					new Dimension(availableImageWidth, availableImageHeight),
+					ModeEnum.OPAQUE == imageElement.getModeValue() ? imageElement.getBackcolor() : null
+					);
+
+			byte[] imageData = imageRenderer.getData(jasperReportsContext);
+			
+			return 
+				new InternalImageProcessorResult(
+					imageData, 
+					dimension, 
+					JRTypeSniffer.getImageTypeValue(imageData)
+					);
+		}
+	}
+
+	private class InternalImageProcessorResult
+	{
+		protected final byte[] imageData;
+		protected final Dimension2D dimension;
+		protected final ImageTypeEnum imageType;
+		
+		protected InternalImageProcessorResult(byte[] imageData, Dimension2D dimension, ImageTypeEnum imageType)
+		{
+			this.imageData = imageData;
+			this.dimension = dimension;
+			this.imageType = imageType;
+		}
+	}
+
 	/**
 	 *
 	 * @param frame
@@ -1731,67 +1790,13 @@ public class JRRtfExporter extends JRAbstractExporter<RtfReportConfiguration, Rt
 		contentWriter.write("}");
 	}
 
-	private float getXAlignFactor(JRPrintImage image)
-	{
-		float xalignFactor = 0f;
-		switch (image.getHorizontalImageAlign())
-		{
-			case RIGHT :
-			{
-				xalignFactor = 1f;
-				break;
-			}
-			case CENTER :
-			{
-				xalignFactor = 0.5f;
-				break;
-			}
-			case LEFT :
-			default :
-			{
-				xalignFactor = 0f;
-				break;
-			}
-		}
-		return xalignFactor;
-	}
-
-	private float getYAlignFactor(JRPrintImage image)
-	{
-		float yalignFactor = 0f;
-		switch (image.getVerticalImageAlign())
-		{
-			case BOTTOM :
-			{
-				yalignFactor = 1f;
-				break;
-			}
-			case MIDDLE :
-			{
-				yalignFactor = 0.5f;
-				break;
-			}
-			case TOP :
-			default :
-			{
-				yalignFactor = 0f;
-				break;
-			}
-		}
-		return yalignFactor;
-	}
-
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterKey()
 	{
 		return RTF_EXPORTER_KEY;
 	}
 	
-	/**
-	 * 
-	 */
+	@Override
 	public String getExporterPropertiesPrefix()
 	{
 		return RTF_EXPORTER_PROPERTIES_PREFIX;
