@@ -29,6 +29,7 @@
 
 package net.sf.jasperreports.engine.export;
 
+import java.io.IOException;
 import java.io.OutputStream;
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -53,9 +54,6 @@ import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesUtil;
 import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.base.JRBasePrintText;
-import net.sf.jasperreports.engine.type.HorizontalTextAlignEnum;
-import net.sf.jasperreports.engine.type.RotationEnum;
-import net.sf.jasperreports.engine.type.VerticalTextAlignEnum;
 import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.export.ExportInterruptedException;
@@ -177,10 +175,11 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 	}
 	
 	@Override
-	protected void exportReportToStream(OutputStream os) throws JRException
+	protected void exportReportToStream(OutputStream os) throws JRException, IOException
 	{
 		openWorkbook(os);
 		sheetNamesMap = new HashMap<String,Integer>();
+		boolean pageExported = false;
 
 		List<ExporterInputItem> items = exporterInput.getItems();
 
@@ -220,8 +219,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 
 						pageFormat = jasperPrint.getPageFormat(pageIndex);
 
-						SheetInfo sheetInfo = new SheetInfo();
-						sheetInfo.sheetName = getSheetName(null);
+						SheetInfo sheetInfo = getSheetInfo(configuration, null);
 						createSheet(sheetInfo);
 
 						// we need to count all sheets generated for all exported documents
@@ -230,7 +228,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 						rowIndex = 0;
 						resetAutoFilters();
 						
-						setFreezePane(gridRowFreezeIndex, gridColumnFreezeIndex);
+						setFreezePane(sheetInfo.rowFreezeIndex, sheetInfo.columnFreezeIndex);
 						
 						/*   */
 						exportPage(page);
@@ -241,8 +239,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 					pageFormat = jasperPrint.getPageFormat(startPageIndex);
 					
 					// Create the sheet before looping.
-					SheetInfo sheetInfo = new SheetInfo();
-					sheetInfo.sheetName = getSheetName(jasperPrint.getName());
+					SheetInfo sheetInfo = getSheetInfo(configuration, jasperPrint.getName());
 					createSheet(sheetInfo);
 
 					// we need to count all sheets generated for all exported documents
@@ -250,7 +247,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 					sheetNamesIndex++;
 					resetAutoFilters();
 					
-					setFreezePane(gridRowFreezeIndex, gridColumnFreezeIndex);
+					setFreezePane(sheetInfo.rowFreezeIndex, sheetInfo.columnFreezeIndex);
 					
 					if (filter instanceof ResetableExporterFilter)
 					{
@@ -268,7 +265,13 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 					}
 					
 				}
+				pageExported = true;
 			}
+			else if(reportIndex == items.size() -1 && !pageExported)
+			{
+				exportEmptyReport();
+			}
+			
 			sheetsBeforeCurrentReport = configuration.isOnePagePerSheet() ? sheetIndex : sheetsBeforeCurrentReport + 1;
 		}
 
@@ -330,7 +333,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 			String rowFreeze = getPropertiesUtil().getProperty(element, JRXlsAbstractExporter.PROPERTY_FREEZE_ROW_EDGE);
 			
 			int rowFreezeIndex = rowFreeze == null 
-				? 0 
+				? -1 
 				: (EdgeEnum.BOTTOM.getName().equals(rowFreeze) 
 						? rowIndex + 1
 						: rowIndex
@@ -339,7 +342,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 			String columnFreeze = getPropertiesUtil().getProperty(element, JRXlsAbstractExporter.PROPERTY_FREEZE_COLUMN_EDGE);
 				
 			int columnFreezeIndex = columnFreeze == null 
-				? 0 
+				? -1 
 				: (EdgeEnum.RIGHT.getName().equals(columnFreeze) 
 						? columnNamesMap.get(currentColumnName) + 1
 						: columnNamesMap.get(currentColumnName)
@@ -347,7 +350,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 
 			if(rowFreezeIndex > 0 || columnFreezeIndex > 0)
 			{
-				setFreezePane(rowFreezeIndex, columnFreezeIndex, rowFreezeIndex > 0, columnFreezeIndex > 0);
+				setFreezePane(rowFreezeIndex, columnFreezeIndex);
 			}
 			
 		}
@@ -389,150 +392,13 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 	}
 	
 	
-	/**
-	 *
-	 */
+	@Override
 	protected JRStyledText getStyledText(JRPrintText textElement)
 	{
 		return textElement.getFullStyledText(noneSelector);
 	}
 
-	/**
-	 *
-	 */
-	protected static TextAlignHolder getTextAlignHolder(JRPrintText textElement)
-	{
-		HorizontalTextAlignEnum horizontalAlignment;
-		VerticalTextAlignEnum verticalAlignment;
-		RotationEnum rotation = textElement.getRotationValue();
-
-		switch (textElement.getRotationValue())
-		{
-			case LEFT :
-			{
-				switch (textElement.getHorizontalTextAlign())
-				{
-					case LEFT :
-					{
-						verticalAlignment = VerticalTextAlignEnum.BOTTOM;
-						break;
-					}
-					case CENTER :
-					{
-						verticalAlignment = VerticalTextAlignEnum.MIDDLE;
-						break;
-					}
-					case RIGHT :
-					{
-						verticalAlignment = VerticalTextAlignEnum.TOP;
-						break;
-					}
-					case JUSTIFIED :
-					{
-						verticalAlignment = VerticalTextAlignEnum.JUSTIFIED;
-						break;
-					}
-					default :
-					{
-						verticalAlignment = VerticalTextAlignEnum.BOTTOM;
-					}
-				}
-
-				switch (textElement.getVerticalTextAlign())
-				{
-					case TOP :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.LEFT;
-						break;
-					}
-					case MIDDLE :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.CENTER;
-						break;
-					}
-					case BOTTOM :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.RIGHT;
-						break;
-					}
-					default :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.LEFT;
-					}
-				}
-
-				break;
-			}
-			case RIGHT :
-			{
-				switch (textElement.getHorizontalTextAlign())
-				{
-					case LEFT :
-					{
-						verticalAlignment = VerticalTextAlignEnum.TOP;
-						break;
-					}
-					case CENTER :
-					{
-						verticalAlignment = VerticalTextAlignEnum.MIDDLE;
-						break;
-					}
-					case RIGHT :
-					{
-						verticalAlignment = VerticalTextAlignEnum.BOTTOM;
-						break;
-					}
-					case JUSTIFIED :
-					{
-						verticalAlignment = VerticalTextAlignEnum.JUSTIFIED;
-						break;
-					}
-					default :
-					{
-						verticalAlignment = VerticalTextAlignEnum.TOP;
-					}
-				}
-
-				switch (textElement.getVerticalTextAlign())
-				{
-					case TOP :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.RIGHT;
-						break;
-					}
-					case MIDDLE :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.CENTER;
-						break;
-					}
-					case BOTTOM :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.LEFT;
-						break;
-					}
-					default :
-					{
-						horizontalAlignment = HorizontalTextAlignEnum.RIGHT;
-					}
-				}
-
-				break;
-			}
-			case UPSIDE_DOWN:
-			case NONE :
-			default :
-			{
-				horizontalAlignment = textElement.getHorizontalTextAlign();
-				verticalAlignment = textElement.getVerticalTextAlign();
-			}
-		}
-
-		return new TextAlignHolder(horizontalAlignment, verticalAlignment, rotation);
-	}
-
-	/**
-	 *
-	 */
+	@Override
 	protected int getImageBorderCorrection(JRPen pen)
 	{
 		float lineWidth = pen.getLineWidth().floatValue();
@@ -594,9 +460,24 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 		return name;
 	}
 
-	/**
-	 * 
-	 */
+	private SheetInfo getSheetInfo(XlsMetadataReportConfiguration configuration, String name)
+	{
+		SheetInfo sheetInfo = new SheetInfo();
+		sheetInfo.sheetName = getSheetName(name);
+		sheetInfo.rowFreezeIndex = configuration.getFreezeRow() == null ? -1 : configuration.getFreezeRow(); 
+		sheetInfo.columnFreezeIndex = configuration.getFreezeColumn() == null ? -1 : getColumnIndex(configuration.getFreezeColumn()); 
+		sheetInfo.ignoreCellBackground = configuration.isIgnoreCellBackground();
+		sheetInfo.ignoreCellBorder = configuration.isIgnoreCellBorder();
+		sheetInfo.whitePageBackground = configuration.isWhitePageBackground();
+		sheetInfo.sheetFirstPageIndex = pageIndex;
+		sheetInfo.sheetFirstPageNumber = configuration.getFirstPageNumber();		
+		sheetInfo.sheetPageScale = configuration.getPageScale();		
+		sheetInfo.sheetShowGridlines = configuration.isShowGridLines() ;
+		sheetInfo.tabColor = configuration.getSheetTabColor();
+		return sheetInfo;
+	}
+
+	@Override
 	protected String getFormula(JRPrintText text)
 	{
 		String formula = text.getPropertiesMap().getProperty(JRXlsAbstractExporter.PROPERTY_CELL_FORMULA);
@@ -631,34 +512,42 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 		return indexOfLastFilledColumn < columnNames.indexOf(currentColumnName);
 	}
 	
+	@Override
 	protected void exportText(JRPrintText text, JRExporterGridCell cell, int colIndex, int rowIndex) throws JRException
 	{
 	}
 
+	@Override
 	public void exportImage(JRPrintImage image, JRExporterGridCell cell, int colIndex, int rowIndex, int emptyCols, int yCutsRow, JRGridLayout layout) throws JRException
 	{
 	}
 
+	@Override
 	protected void exportRectangle(JRPrintGraphicElement element, JRExporterGridCell cell, int colIndex, int rowIndex) throws JRException
 	{
 	}
 
+	@Override
 	protected void exportLine(JRPrintLine line, JRExporterGridCell cell, int colIndex, int rowIndex) throws JRException
 	{
 	}
 
+	@Override
 	protected void exportFrame(JRPrintFrame frame, JRExporterGridCell cell, int colIndex, int rowIndex) throws JRException
 	{
 	}
 
+	@Override
 	protected void exportGenericElement(JRGenericPrintElement element, JRExporterGridCell cell, int colIndex, int rowIndex, int emptyCols, int yCutsRow, JRGridLayout layout) throws JRException
 	{
 	}
 	
+	@Override
 	protected void addBlankCell(JRExporterGridCell gridCell, int colIndex, int rowIndex) throws JRException
 	{
 	}
 
+	@Override
 	protected void addOccupiedCell(OccupiedGridCell occupiedGridCell, int colIndex, int rowIndex) throws JRException
 	{
 	}
@@ -667,10 +556,13 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 //	{
 //	}
 	
+	@Override
 	protected abstract ExporterNature getNature();
 
+	@Override
 	protected abstract void openWorkbook(OutputStream os) throws JRException;
 
+	@Override
 	protected void createSheet(CutsInfo xCuts, SheetInfo sheetInfo)
 	{
 		createSheet(sheetInfo);
@@ -678,6 +570,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 
 	protected abstract void createSheet(SheetInfo sheetInfo);
 
+	@Override
 	protected abstract void closeWorkbook(OutputStream os) throws JRException;
 
 	protected void setColumnWidth(int col, int width)
@@ -685,6 +578,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 		setColumnWidth(col, width, false);
 	}
 
+	@Override
 	protected abstract void setColumnWidth(int col, int width, boolean autoFit);
 
 	protected void setRowHeight(int rowIndex, int lastRowHeight) throws JRException
@@ -692,6 +586,7 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 		setRowHeight(rowIndex, lastRowHeight, null, null);
 	}
 
+	@Override
 	protected abstract void setRowHeight(int rowIndex, int lastRowHeight, Cut yCut, XlsRowLevelInfo levelInfo) throws JRException;
 
 	protected abstract void exportText(JRPrintText textElement) throws JRException;
@@ -710,5 +605,4 @@ public abstract class JRXlsAbstractMetadataExporter<RC extends XlsMetadataReport
 	
 	protected abstract void writeReportHeader() throws JRException;
 
-
 }
