@@ -38,6 +38,9 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.JRAbstractExporter;
 import net.sf.jasperreports.engine.JRException;
@@ -58,11 +61,8 @@ import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesUtil;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
-import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.PrintPageFormat;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.export.CutsInfo;
 import net.sf.jasperreports.engine.export.ElementGridCell;
@@ -81,23 +81,24 @@ import net.sf.jasperreports.engine.export.OccupiedGridCell;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
 import net.sf.jasperreports.engine.type.HorizontalTextAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
-import net.sf.jasperreports.engine.type.ImageTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
-import net.sf.jasperreports.engine.type.RenderableTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.util.JRStringUtil;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRTextAttribute;
+import net.sf.jasperreports.engine.util.JRTypeSniffer;
 import net.sf.jasperreports.export.DocxExporterConfiguration;
 import net.sf.jasperreports.export.DocxReportConfiguration;
 import net.sf.jasperreports.export.ExportInterruptedException;
 import net.sf.jasperreports.export.ExporterInputItem;
 import net.sf.jasperreports.export.OutputStreamExporterOutput;
 import net.sf.jasperreports.export.ReportExportConfiguration;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.renderers.DataRenderable;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.RenderersCache;
+import net.sf.jasperreports.renderers.ResourceRenderer;
 
 
 /**
@@ -174,6 +175,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	protected Writer docWriter;
 
 	protected Map<String, String> rendererToImagePathMap;
+	protected RenderersCache renderersCache;
 //	protected Map imageMaps;
 
 	protected int reportIndex;
@@ -211,6 +213,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 			this.tableHelper = tableHelper;
 		}
 		
+		@Override
 		public DocxTableHelper getTableHelper()
 		{
 			return tableHelper;
@@ -238,27 +241,21 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<DocxExporterConfiguration> getConfigurationInterface()
 	{
 		return DocxExporterConfiguration.class;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<DocxReportConfiguration> getItemConfigurationInterface()
 	{
 		return DocxReportConfiguration.class;
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	@SuppressWarnings("deprecation")
 	protected void ensureOutput()
 	{
@@ -274,9 +271,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	public void exportReport() throws JRException
 	{
 		/*   */
@@ -310,7 +305,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	{
 		super.initExport();
 
-		rendererToImagePathMap = new HashMap<String,String>();
+		rendererToImagePathMap = new HashMap<String,String>();//FIXMEIMAGE why this is reset at export and not report; are there any others?
 //		imageMaps = new HashMap();
 //		hyperlinksMap = new HashMap();
 	}
@@ -321,7 +316,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	{
 		super.initReport();
 		
-		if(jasperPrint.hasProperties() && jasperPrint.getPropertiesMap().containsProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS))
+		if (jasperPrint.hasProperties() && jasperPrint.getPropertiesMap().containsProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS))
 		{
 			// allows null values for the property
 			invalidCharReplacement = jasperPrint.getProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS);
@@ -339,6 +334,8 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 				filter, 
 				!configuration.isFramesAsNestedTables()
 				);
+
+		renderersCache = new RenderersCache(getJasperReportsContext());
 	}
 
 	
@@ -361,9 +358,8 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 
 		DocxStyleHelper styleHelper = 
 			new DocxStyleHelper(
-				jasperReportsContext,
-				docxZip.getStylesEntry().getWriter(), 
-				getExporterKey()
+				this,
+				docxZip.getStylesEntry().getWriter()
 				);
 		styleHelper.export(exporterInput);
 		styleHelper.close();
@@ -503,7 +499,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		
 		// an empty page is encountered; 
 		// if it's the first one in a series of consecutive empty pages, emptyPageState == false, otherwise emptyPageState == true
-		if(rowCount == 0 && (pageIndex < endPageIndex || !emptyPageState))
+		if (rowCount == 0 && (pageIndex < endPageIndex || !emptyPageState))
 		{
 			tableHelper = 
 					new DocxTableHelper(
@@ -511,7 +507,8 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 						docWriter, 
 						xCuts,
 						false,
-						pageFormat
+						pageFormat,
+						frameIndex
 						);
 			int maxReportIndex = exporterInput.getItems().size() - 1;
 			
@@ -531,7 +528,8 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 					docWriter, 
 					xCuts,
 					frameIndex == null && (reportIndex != 0 || pageIndex != startPageIndex),
-					pageFormat
+					pageFormat,
+					frameIndex
 					);
 
 		tableHelper.exportHeader();
@@ -596,14 +594,14 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 					OccupiedGridCell occupiedGridCell = (OccupiedGridCell)gridCell;
 					ElementGridCell elementGridCell = (ElementGridCell)occupiedGridCell.getOccupier();
 					tableHelper.exportOccupiedCells(elementGridCell, startPage, bookmarkIndex, pageAnchor);
-					if(startPage)
+					if (startPage)
 					{
 						// increment the bookmarkIndex for the first cell in the sheet, due to page anchor creation
 						bookmarkIndex++;
 					}
 					col += elementGridCell.getColSpan() - 1;
 				}
-				else if(gridCell.getType() == JRExporterGridCell.TYPE_ELEMENT_CELL)
+				else if (gridCell.getType() == JRExporterGridCell.TYPE_ELEMENT_CELL)
 				{
 					if (emptyCellColSpan > 0)
 					{
@@ -650,7 +648,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 					emptyCellColSpan++;
 					//emptyCellWidth += gridCell.getWidth();
 					tableHelper.exportEmptyCell(gridCell, 1, startPage, bookmarkIndex, pageAnchor);
-					if(startPage)
+					if (startPage)
 					{
 						// increment the bookmarkIndex for the first cell in the sheet, due to page anchor creation
 						bookmarkIndex++;
@@ -711,7 +709,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		
 		tableHelper.getCellHelper().exportHeader(line, gridCell);
 		tableHelper.getParagraphHelper().exportEmptyParagraph(startPage, bookmarkIndex, pageAnchor);
-		if(startPage)
+		if (startPage)
 		{
 			// increment the bookmarkIndex for the first cell in the sheet, due to page anchor creation
 			bookmarkIndex++;
@@ -735,7 +733,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		
 		tableHelper.getCellHelper().exportHeader(rectangle, gridCell);
 		tableHelper.getParagraphHelper().exportEmptyParagraph(startPage, bookmarkIndex, pageAnchor);
-		if(startPage)
+		if (startPage)
 		{
 			// increment the bookmarkIndex for the first cell in the sheet, due to page anchor creation
 			bookmarkIndex++;
@@ -759,7 +757,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		
 		tableHelper.getCellHelper().exportHeader(ellipse, gridCell);
 		tableHelper.getParagraphHelper().exportEmptyParagraph(startPage, bookmarkIndex, pageAnchor);
-		if(startPage)
+		if (startPage)
 		{
 			// increment the bookmarkIndex for the first cell in the sheet, due to page anchor creation
 			bookmarkIndex++;
@@ -795,7 +793,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		docHelper.write("     <w:p>\n");
 
 		tableHelper.getParagraphHelper().exportProps(text);
-		if(startPage)
+		if (startPage)
 		{
 			insertBookmark(pageAnchor, docHelper);
 		}
@@ -806,9 +804,9 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 
 		boolean startedHyperlink = startHyperlink(text, true);
 		boolean isNewLineAsParagraph = false;
-		if(HorizontalTextAlignEnum.JUSTIFIED.equals(text.getHorizontalTextAlign()))
+		if (HorizontalTextAlignEnum.JUSTIFIED.equals(text.getHorizontalTextAlign()))
 		{
-			if(text.hasProperties() && text.getPropertiesMap().containsProperty(DocxReportConfiguration.PROPERTY_NEW_LINE_AS_PARAGRAPH))
+			if (text.hasProperties() && text.getPropertiesMap().containsProperty(DocxReportConfiguration.PROPERTY_NEW_LINE_AS_PARAGRAPH))
 			{
 				isNewLineAsParagraph = getPropertiesUtil().getBooleanProperty(text, DocxReportConfiguration.PROPERTY_NEW_LINE_AS_PARAGRAPH, false);
 			}
@@ -821,7 +819,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		if (textLength > 0)
 		{
 			exportStyledText(
-				JRStyleResolver.getBaseStyle(text), 
+				getCurrentJasperPrint().getDefaultStyleProvider().getStyleResolver().getBaseStyle(text), 
 				styledText, 
 				getTextLocale(text),
 				getPropertiesUtil().getBooleanProperty(text, PROPERTY_HIDDEN_TEXT, false),
@@ -913,138 +911,155 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 
 		tableHelper.getCellHelper().exportHeader(image, gridCell);
 
-		docHelper.write("<w:p>");//FIXMEDOCX why is this here and not further down?
+		docHelper.write("<w:p>\n");//FIXMEDOCX why is this here and not further down?
+		tableHelper.getParagraphHelper().exportProps(image);
 
-		Renderable renderer = image.getRenderable();
+		Renderable renderer = image.getRenderer();
 
 		if (
-			renderer != null &&
-			availableImageWidth > 0 &&
-			availableImageHeight > 0
+			renderer != null
+			&& availableImageWidth > 0
+			&& availableImageHeight > 0
 			)
 		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
-			{
-				// Non-lazy image renderers are all asked for their image data at some point.
-				// Better to test and replace the renderer now, in case of lazy load error.
-				renderer = RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForImageData(renderer, image.getOnErrorTypeValue());
-			}
-		}
-		else
-		{
-			renderer = null;
-		}
-
-		if (renderer != null)
-		{
-			int width = availableImageWidth;
-			int height = availableImageHeight;
-
-			double normalWidth = availableImageWidth;
-			double normalHeight = availableImageHeight;
-
-			// Image load might fail.
-			Renderable tmpRenderer =
-				RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
-			Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension(jasperReportsContext);
-			// If renderer was replaced, ignore image dimension.
-			if (tmpRenderer == renderer && dimension != null)
-			{
-				normalWidth = dimension.getWidth();
-				normalHeight = dimension.getHeight();
-			}
-
-			double cropTop = 0;
-			double cropLeft = 0;
-			double cropBottom = 0;
-			double cropRight = 0;
+			InternalImageProcessor imageProcessor = 
+				new InternalImageProcessor(
+					image, 
+					image.getScaleImageValue() != ScaleImageEnum.FILL_FRAME, 
+					gridCell,
+					availableImageWidth,
+					availableImageHeight
+					);
+				
+			InternalImageProcessorResult imageProcessorResult = null;
 			
-			switch (image.getScaleImageValue())
+			try
 			{
-				case FILL_FRAME :
+				imageProcessorResult = imageProcessor.process(renderer);
+			}
+			catch (Exception e)
+			{
+				Renderable onErrorRenderer = getRendererUtil().handleImageError(e, image.getOnErrorTypeValue());
+				if (onErrorRenderer != null)
 				{
-					width = availableImageWidth;
-					height = availableImageHeight;
-					break;
+					imageProcessorResult = imageProcessor.process(onErrorRenderer);
 				}
-				case CLIP :
+			}
+			
+			if (imageProcessorResult != null)
+			{
+				int width = availableImageWidth;
+				int height = availableImageHeight;
+
+				double cropTop = 0;
+				double cropLeft = 0;
+				double cropBottom = 0;
+				double cropRight = 0;
+				
+				switch (image.getScaleImageValue())
 				{
-					if (normalWidth > availableImageWidth)
+					case FILL_FRAME :
 					{
-						switch (image.getHorizontalImageAlign())
-						{
-							case RIGHT :
-							{
-								cropLeft = 65536 * (normalWidth - availableImageWidth) / normalWidth;
-								cropRight = 0;
-								break;
-							}
-							case CENTER :
-							{
-								cropLeft = 65536 * (- availableImageWidth + normalWidth) / normalWidth / 2;
-								cropRight = cropLeft;
-								break;
-							}
-							case LEFT :
-							default :
-							{
-								cropLeft = 0;
-								cropRight = 65536 * (normalWidth - availableImageWidth) / normalWidth;
-								break;
-							}
-						}
 						width = availableImageWidth;
-						cropLeft = cropLeft / 0.75d;
-						cropRight = cropRight / 0.75d;
-					}
-					else
-					{
-						width = (int)normalWidth;
-					}
-
-					if (normalHeight > availableImageHeight)
-					{
-						switch (image.getVerticalImageAlign())
-						{
-							case TOP :
-							{
-								cropTop = 0;
-								cropBottom = 65536 * (normalHeight - availableImageHeight) / normalHeight;
-								break;
-							}
-							case MIDDLE :
-							{
-								cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight / 2;
-								cropBottom = cropTop;
-								break;
-							}
-							case BOTTOM :
-							default :
-							{
-								cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight;
-								cropBottom = 0;
-								break;
-							}
-						}
 						height = availableImageHeight;
-						cropTop = cropTop / 0.75d;
-						cropBottom = cropBottom / 0.75d;
+						break;
 					}
-					else
+					case CLIP :
 					{
-						height = (int)normalHeight;
-					}
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
 
-					break;
-				}
-				case RETAIN_SHAPE :
-				default :
-				{
-					if (availableImageHeight > 0)
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
+						if (normalWidth > availableImageWidth)
+						{
+							switch (image.getHorizontalImageAlign())
+							{
+								case RIGHT :
+								{
+									cropLeft = 65536 * (normalWidth - availableImageWidth) / normalWidth;
+									cropRight = 0;
+									break;
+								}
+								case CENTER :
+								{
+									cropLeft = 65536 * (- availableImageWidth + normalWidth) / normalWidth / 2;
+									cropRight = cropLeft;
+									break;
+								}
+								case LEFT :
+								default :
+								{
+									cropLeft = 0;
+									cropRight = 65536 * (normalWidth - availableImageWidth) / normalWidth;
+									break;
+								}
+							}
+							width = availableImageWidth;
+							cropLeft = cropLeft / 0.75d;
+							cropRight = cropRight / 0.75d;
+						}
+						else
+						{
+							width = (int)normalWidth;
+						}
+
+						if (normalHeight > availableImageHeight)
+						{
+							switch (image.getVerticalImageAlign())
+							{
+								case TOP :
+								{
+									cropTop = 0;
+									cropBottom = 65536 * (normalHeight - availableImageHeight) / normalHeight;
+									break;
+								}
+								case MIDDLE :
+								{
+									cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight / 2;
+									cropBottom = cropTop;
+									break;
+								}
+								case BOTTOM :
+								default :
+								{
+									cropTop = 65536 * (normalHeight - availableImageHeight) / normalHeight;
+									cropBottom = 0;
+									break;
+								}
+							}
+							height = availableImageHeight;
+							cropTop = cropTop / 0.75d;
+							cropBottom = cropBottom / 0.75d;
+						}
+						else
+						{
+							height = (int)normalHeight;
+						}
+
+						break;
+					}
+					case RETAIN_SHAPE :
+					default :
 					{
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
 						double ratio = normalWidth / normalHeight;
 
-						if( ratio > availableImageWidth / (double)availableImageHeight )
+						if (ratio > availableImageWidth / (double)availableImageHeight)
 						{
 							width = availableImageWidth;
 							height = (int)(width/ratio);
@@ -1057,156 +1072,104 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 						}
 					}
 				}
-			}
 
-			if(startPage)
-			{
-				insertBookmark(pageAnchor, docHelper);
-			}
-			if (image.getAnchorName() != null)
-			{
-				insertBookmark(image.getAnchorName(), docHelper);
-			}
-
-
-//			boolean startedHyperlink = startHyperlink(image,false);
-
-			docHelper.write("<w:r>\n"); 
-			docHelper.write("<w:drawing>\n");
-			docHelper.write("<wp:anchor distT=\"0\" distB=\"0\" distL=\"0\" distR=\"0\" simplePos=\"0\" relativeHeight=\"0\" behindDoc=\"0\" locked=\"1\" layoutInCell=\"1\" allowOverlap=\"1\">");
-			docHelper.write("<wp:simplePos x=\"0\" y=\"0\"/>");
-			docHelper.write("<wp:positionH relativeFrom=\"column\"><wp:align>" + DocxParagraphHelper.getHorizontalImageAlign(image.getHorizontalImageAlign()) + "</wp:align></wp:positionH>");
-			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:posOffset>0</wp:posOffset></wp:positionV>");
-//			docHelper.write("<wp:positionV relativeFrom=\"line\"><wp:align>" + CellHelper.getVerticalAlignment(new Byte(image.getVerticalAlignment())) + "</wp:align></wp:positionV>");
-			docHelper.write("<wp:extent cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
-			docHelper.write("<wp:wrapNone/>");
-			int imageId = image.hashCode() > 0 ? image.hashCode() : -image.hashCode();
-			String rId = IMAGE_LINK_PREFIX + getElementIndex(gridCell);
-			docHelper.write("<wp:docPr id=\"" + imageId + "\" name=\"Picture\">\n");
-			if(getHyperlinkURL(image) != null)
-			{
-				docHelper.write("<a:hlinkClick xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" r:id=\"" + rId + "\"/>\n");
-			}
-			docHelper.write("</wp:docPr>\n");
-			docHelper.write("<a:graphic>\n");
-			docHelper.write("<a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">\n");
-			docHelper.write("<pic:pic>\n");
-			docHelper.write("<pic:nvPicPr><pic:cNvPr id=\"" + imageId + "\" name=\"Picture\"/><pic:cNvPicPr/></pic:nvPicPr>\n");
-			docHelper.write("<pic:blipFill>\n");
-
-			String imagePath = null;
-
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
-			{
-				imagePath = rendererToImagePathMap.get(renderer.getId());
-			}
-			else
-			{
-//				if (isLazy)//FIXMEDOCX learn how to link images
-//				{
-//					imagePath = ((JRImageRenderer)renderer).getImageLocation();
-//				}
-//				else
-//				{
-					JRPrintElementIndex imageIndex = getElementIndex(gridCell);
-
-					if (renderer.getTypeValue() == RenderableTypeEnum.SVG)
-					{
-						renderer =
-							new JRWrappingSvgRenderer(
-								renderer,
-								new Dimension(image.getWidth(), image.getHeight()),
-								ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
-								);
-					}
-
-					String mimeType = renderer.getImageTypeValue().getMimeType();
-					if (mimeType == null)
-					{
-						mimeType = ImageTypeEnum.JPEG.getMimeType();
-					}
-					String extension = mimeType.substring(mimeType.lastIndexOf('/') + 1);
-					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + "." + extension;
-					
-					docxZip.addEntry(//FIXMEDOCX optimize with a different implementation of entry
-						new FileBufferedZipEntry(
-							"word/media/" + imageName,
-							renderer.getImageData(jasperReportsContext)
-							)
-						);
-					
-					relsHelper.exportImage(imageName);
-
-					imagePath = imageName;
-					//imagePath = "Pictures/" + imageName;
-//				}
-
-				rendererToImagePathMap.put(renderer.getId(), imagePath);
-			}
-
-			docHelper.write("<a:blip r:embed=\"" + imagePath + "\"/>");
-			docHelper.write("<a:srcRect");
-			if (cropLeft > 0)
-			{
-				docHelper.write(" l=\"" + (int)cropLeft + "\"");
-			}
-			if (cropTop > 0)
-			{
-				docHelper.write(" t=\"" + (int)cropTop + "\"");
-			}
-			if (cropRight > 0)
-			{
-				docHelper.write(" r=\"" + (int)cropRight + "\"");
-			}
-			if (cropBottom > 0)
-			{
-				docHelper.write(" b=\"" + (int)cropBottom + "\"");
-			}
-			docHelper.write("/>");
-			docHelper.write("<a:stretch><a:fillRect/></a:stretch>\n");
-			docHelper.write("</pic:blipFill>\n");
-			docHelper.write("<pic:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>");
-			docHelper.write("</a:xfrm><a:prstGeom prst=\"rect\"></a:prstGeom></pic:spPr>\n");
-			docHelper.write("</pic:pic>\n");
-			docHelper.write("</a:graphicData>\n");
-			docHelper.write("</a:graphic>\n");
-			docHelper.write("</wp:anchor>\n");
-			docHelper.write("</w:drawing>\n");
-			docHelper.write("</w:r>"); 
-
-			String url =  getHyperlinkURL(image);
-
-			if(url != null)
-			{
-				String targetMode = "";
-				switch(image.getHyperlinkTypeValue())
+				if (startPage)
 				{
-					case LOCAL_PAGE:
-					case LOCAL_ANCHOR:
+					insertBookmark(pageAnchor, docHelper);
+				}
+				if (image.getAnchorName() != null)
+				{
+					insertBookmark(image.getAnchorName(), docHelper);
+				}
+
+
+//				boolean startedHyperlink = startHyperlink(image,false);
+
+				docHelper.write("<w:r>\n"); 
+				docHelper.write("<w:rPr/>\n"); 
+				docHelper.write("<w:drawing>\n");
+				docHelper.write("<wp:inline distT=\"0\" distB=\"0\" distL=\"0\" distR=\"0\">\n");
+				docHelper.write("<wp:extent cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
+				docHelper.write("<wp:effectExtent l=\"0\" t=\"0\" r=\"0\" b=\"0\"/>\n");
+
+				int imageId = image.hashCode() > 0 ? image.hashCode() : -image.hashCode();
+				String rId = IMAGE_LINK_PREFIX + getElementIndex(gridCell);
+				docHelper.write("<wp:docPr id=\"" + imageId + "\" name=\"Picture\">\n");
+				if (getHyperlinkURL(image) != null)
+				{
+					docHelper.write("<a:hlinkClick xmlns:a=\"http://schemas.openxmlformats.org/drawingml/2006/main\" r:id=\"" + rId + "\"/>\n");
+				}
+				docHelper.write("</wp:docPr>\n");
+				docHelper.write("<a:graphic>\n");
+				docHelper.write("<a:graphicData uri=\"http://schemas.openxmlformats.org/drawingml/2006/picture\">\n");
+				docHelper.write("<pic:pic>\n");
+				docHelper.write("<pic:nvPicPr><pic:cNvPr id=\"" + imageId + "\" name=\"Picture\"/><pic:cNvPicPr/></pic:nvPicPr>\n");
+				docHelper.write("<pic:blipFill>\n");
+
+				docHelper.write("<a:blip r:embed=\"" + imageProcessorResult.imagePath + "\"/>");
+				docHelper.write("<a:srcRect");
+				if (cropLeft > 0)
+				{
+					docHelper.write(" l=\"" + (int)cropLeft + "\"");
+				}
+				if (cropTop > 0)
+				{
+					docHelper.write(" t=\"" + (int)cropTop + "\"");
+				}
+				if (cropRight > 0)
+				{
+					docHelper.write(" r=\"" + (int)cropRight + "\"");
+				}
+				if (cropBottom > 0)
+				{
+					docHelper.write(" b=\"" + (int)cropBottom + "\"");
+				}
+				docHelper.write("/>");
+				docHelper.write("<a:stretch><a:fillRect/></a:stretch>\n");
+				docHelper.write("</pic:blipFill>\n");
+				docHelper.write("<pic:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>");
+				docHelper.write("</a:xfrm><a:prstGeom prst=\"rect\"></a:prstGeom></pic:spPr>\n");
+				docHelper.write("</pic:pic>\n");
+				docHelper.write("</a:graphicData>\n");
+				docHelper.write("</a:graphic>\n");
+				docHelper.write("</wp:inline>\n");
+				docHelper.write("</w:drawing>\n");
+				docHelper.write("</w:r>"); 
+
+				String url =  getHyperlinkURL(image);
+
+				if (url != null)
+				{
+					String targetMode = "";
+					switch(image.getHyperlinkTypeValue())
 					{
-						relsHelper.exportImageLink(rId, "#"+url.replaceAll("\\W", ""), targetMode);
-						break;
-					}
-					
-					case REMOTE_PAGE:
-					case REMOTE_ANCHOR:
-					case REFERENCE:
-					{
-						targetMode = " TargetMode=\"External\"";
-						relsHelper.exportImageLink(rId, url, targetMode);
-						break;
-					}
-					default:
-					{
-						break;
+						case LOCAL_PAGE:
+						case LOCAL_ANCHOR:
+						{
+							relsHelper.exportImageLink(rId, "#"+url.replaceAll("\\W", ""), targetMode);
+							break;
+						}
+						
+						case REMOTE_PAGE:
+						case REMOTE_ANCHOR:
+						case REFERENCE:
+						{
+							targetMode = " TargetMode=\"External\"";
+							relsHelper.exportImageLink(rId, url, targetMode);
+							break;
+						}
+						default:
+						{
+							break;
+						}
 					}
 				}
+				
+//				if (startedHyperlink)
+//				{
+//					endHyperlink(false);
+//				}
 			}
-			
-//			if(startedHyperlink)
-//			{
-//				endHyperlink(false);
-//			}
 		}
 
 		docHelper.write("</w:p>");
@@ -1214,6 +1177,111 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		tableHelper.getCellHelper().exportFooter();
 	}
 
+	private class InternalImageProcessor
+	{
+		private final JRPrintElement imageElement;
+		private final boolean needDimension; 
+		private final JRExporterGridCell cell;
+		private final int availableImageWidth;
+		private final int availableImageHeight;
+
+		protected InternalImageProcessor(
+			JRPrintElement imageElement,
+			boolean needDimension, 
+			JRExporterGridCell cell,
+			int availableImageWidth,
+			int availableImageHeight
+			)
+		{
+			this.imageElement = imageElement;
+			this.needDimension = needDimension;
+			this.cell = cell;
+			this.availableImageWidth = availableImageWidth;
+			this.availableImageHeight = availableImageHeight;
+		}
+		
+		private InternalImageProcessorResult process(Renderable renderer) throws JRException
+		{
+			if (renderer instanceof ResourceRenderer)
+			{
+				renderer = renderersCache.getLoadedRenderer((ResourceRenderer)renderer);
+			}
+			
+			// check dimension first, to avoid caching renderers that might not be used eventually, due to their dimension errors 
+			Dimension2D dimension = null;
+			if (needDimension)
+			{
+				DimensionRenderable dimensionRenderer = renderersCache.getDimensionRenderable(renderer);
+				dimension = dimensionRenderer == null ? null :  dimensionRenderer.getDimension(jasperReportsContext);
+			}
+			
+			
+			String imagePath = null;
+
+//			if (image.isLazy()) //FIXMEDOCX learn how to link images				
+//			{
+//
+//			}
+//			else
+//			{
+				if (
+					renderer instanceof DataRenderable //we do not cache imagePath for non-data renderers because they render width different width/height each time
+					&& rendererToImagePathMap.containsKey(renderer.getId())
+					)
+				{
+					imagePath = rendererToImagePathMap.get(renderer.getId());
+				}
+				else
+				{
+					JRPrintElementIndex imageIndex = getElementIndex(cell);
+
+					DataRenderable imageRenderer = 
+						getRendererUtil().getImageDataRenderable(
+							renderersCache,
+							renderer,
+							new Dimension(availableImageWidth, availableImageHeight),
+							ModeEnum.OPAQUE == imageElement.getModeValue() ? imageElement.getBackcolor() : null
+							);
+
+					byte[] imageData = imageRenderer.getData(jasperReportsContext);
+					String fileExtension = JRTypeSniffer.getImageTypeValue(imageData).getFileExtension();
+					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + (fileExtension == null ? "" : ("." + fileExtension));
+					
+					docxZip.addEntry(//FIXMEDOCX optimize with a different implementation of entry
+						new FileBufferedZipEntry(
+							"word/media/" + imageName,
+							imageData
+							)
+						);
+					
+					relsHelper.exportImage(imageName);
+
+					imagePath = imageName;
+					//imagePath = "Pictures/" + imageName;
+
+					if (imageRenderer == renderer)
+					{
+						//cache imagePath only for true ImageRenderable instances because the wrapping ones render with different width/height each time
+						rendererToImagePathMap.put(renderer.getId(), imagePath);
+					}
+				}
+//			}
+
+			return new InternalImageProcessorResult(imagePath, dimension);
+		}
+	}
+
+	private class InternalImageProcessorResult
+	{
+		protected final String imagePath;
+		protected final Dimension2D dimension;
+		
+		protected InternalImageProcessorResult(String imagePath, Dimension2D dimension)
+		{
+			this.imagePath = imagePath;
+			this.dimension = dimension;
+		}
+	}
 
 	protected JRPrintElementIndex getElementIndex(JRExporterGridCell gridCell)
 	{
@@ -1261,7 +1329,7 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		int[] coords = area.getCoordinates();
 		if (coords != null && coords.length > 0)
 		{
-			StringBuffer coordsEnum = new StringBuffer(coords.length * 4);
+			StringBuilder coordsEnum = new StringBuilder(coords.length * 4);
 			coordsEnum.append(coords[0]);
 			for (int i = 1; i < coords.length; i++)
 			{
@@ -1404,57 +1472,6 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 	}
 
 
-//	private float getXAlignFactor(JRPrintImage image)
-//	{
-//		float xalignFactor = 0f;
-//		switch (image.getHorizontalAlignmentValue())
-//		{
-//			case RIGHT :
-//			{
-//				xalignFactor = 1f;
-//				break;
-//			}
-//			case CENTER :
-//			{
-//				xalignFactor = 0.5f;
-//				break;
-//			}
-//			case LEFT :
-//			default :
-//			{
-//				xalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return xalignFactor;
-//	}
-
-
-//	private float getYAlignFactor(JRPrintImage image)
-//	{
-//		float yalignFactor = 0f;
-//		switch (image.getVerticalAlignmentValue())
-//		{
-//			case BOTTOM :
-//			{
-//				yalignFactor = 1f;
-//				break;
-//			}
-//			case MIDDLE :
-//			{
-//				yalignFactor = 0.5f;
-//				break;
-//			}
-//			case TOP :
-//			default :
-//			{
-//				yalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return yalignFactor;
-//	}
-
 	protected boolean startHyperlink(JRPrintHyperlink link, boolean isText)
 	{
 		String href = getHyperlinkURL(link);
@@ -1619,25 +1636,19 @@ public class JRDocxExporter extends JRAbstractExporter<DocxReportConfiguration,
 		helper.write("\"/>");
 	}
 	
-	/**
-	 *
-	 */
+	@Override
 	protected void ensureInput()
 	{
 		super.ensureInput();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterKey()
 	{
 		return DOCX_EXPORTER_KEY;
 	}
 
-	/**
-	 * 
-	 */
+	@Override
 	public String getExporterPropertiesPrefix()
 	{
 		return DOCX_EXPORTER_PROPERTIES_PREFIX;
