@@ -37,11 +37,16 @@ import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.JRAbstractExporter;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRGenericElementType;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
+import net.sf.jasperreports.engine.JRLineBox;
+import net.sf.jasperreports.engine.JRPen;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintElementIndex;
 import net.sf.jasperreports.engine.JRPrintEllipse;
@@ -55,10 +60,8 @@ import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesUtil;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
-import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperReportsContext;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
+import net.sf.jasperreports.engine.base.JRBasePen;
 import net.sf.jasperreports.engine.export.GenericElementHandlerEnviroment;
 import net.sf.jasperreports.engine.export.HyperlinkUtil;
 import net.sf.jasperreports.engine.export.JRExportProgressMonitor;
@@ -67,20 +70,23 @@ import net.sf.jasperreports.engine.export.JRXmlExporter;
 import net.sf.jasperreports.engine.export.LengthUtil;
 import net.sf.jasperreports.engine.export.zip.ExportZipEntry;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
-import net.sf.jasperreports.engine.type.ImageTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
+import net.sf.jasperreports.engine.type.LineStyleEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
-import net.sf.jasperreports.engine.type.RenderableTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.util.JRColorUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
+import net.sf.jasperreports.engine.util.JRTypeSniffer;
 import net.sf.jasperreports.export.ExportInterruptedException;
 import net.sf.jasperreports.export.ExporterInputItem;
 import net.sf.jasperreports.export.OutputStreamExporterOutput;
 import net.sf.jasperreports.export.PptxExporterConfiguration;
 import net.sf.jasperreports.export.PptxReportConfiguration;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.renderers.DataRenderable;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.RenderersCache;
+import net.sf.jasperreports.renderers.ResourceRenderer;
 
 
 /**
@@ -145,6 +151,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 	protected Writer presentationWriter;
 
 	protected Map<String, String> rendererToImagePathMap;
+	protected RenderersCache renderersCache;
 //	protected Map imageMaps;
 //	protected Map hyperlinksMap;
 
@@ -168,6 +175,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		{
 		}
 		
+		@Override
 		public PptxSlideHelper getSlideHelper()
 		{
 			return slideHelper;
@@ -195,27 +203,21 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<PptxExporterConfiguration> getConfigurationInterface()
 	{
 		return PptxExporterConfiguration.class;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<PptxReportConfiguration> getItemConfigurationInterface()
 	{
 		return PptxReportConfiguration.class;
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	@SuppressWarnings("deprecation")
 	protected void ensureOutput()
 	{
@@ -231,9 +233,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	public void exportReport() throws JRException
 	{
 		/*   */
@@ -278,7 +278,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 	{
 		super.initReport();
 		
-		if(jasperPrint.hasProperties() && jasperPrint.getPropertiesMap().containsProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS))
+		if (jasperPrint.hasProperties() && jasperPrint.getPropertiesMap().containsProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS))
 		{
 			// allows null values for the property
 			invalidCharReplacement = jasperPrint.getProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS);
@@ -287,6 +287,8 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		{
 			invalidCharReplacement = getPropertiesUtil().getProperty(JRXmlExporter.PROPERTY_REPLACE_INVALID_CHARS, jasperPrint);
 		}
+
+		renderersCache = new RenderersCache(getJasperReportsContext());
 	}
 
 	
@@ -522,7 +524,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		slideHelper.write("    <p:nvPr/>\n");
 		slideHelper.write("  </p:nvSpPr>\n");
 		slideHelper.write("  <p:spPr>\n");
-		slideHelper.write("    <a:xfrm" + (line.getDirectionValue() == LineDirectionEnum.TOP_DOWN ? " flipV=\"1\"" : "") + ">\n");
+		slideHelper.write("    <a:xfrm" + (line.getDirectionValue() == LineDirectionEnum.BOTTOM_UP ? " flipV=\"1\"" : "") + ">\n");
 		slideHelper.write("      <a:off x=\"" + LengthUtil.emu(x) + "\" y=\"" + LengthUtil.emu(y) + "\"/>\n");
 		slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(width) + "\" cy=\"" + LengthUtil.emu(height) + "\"/>\n");
 		slideHelper.write("    </a:xfrm><a:prstGeom prst=\"line\"><a:avLst/></a:prstGeom>\n");
@@ -532,7 +534,12 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		}
 		if (line.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(line.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(line.getLinePen().getLineWidth()) + "\"");
+			if(LineStyleEnum.DOUBLE.equals(line.getLinePen().getLineStyleValue()))
+			{
+				slideHelper.write(" cmpd=\"dbl\"");
+			}
+			slideHelper.write(">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(line.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (line.getLinePen().getLineStyleValue())
@@ -604,7 +611,12 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		}
 		if (rectangle.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(rectangle.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(rectangle.getLinePen().getLineWidth()) + "\"");
+			if(LineStyleEnum.DOUBLE.equals(rectangle.getLinePen().getLineStyleValue()))
+			{
+				slideHelper.write(" cmpd=\"dbl\"");
+			}
+			slideHelper.write(">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(rectangle.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (rectangle.getLinePen().getLineStyleValue())
@@ -666,7 +678,12 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		}
 		if (ellipse.getLinePen().getLineWidth() > 0)
 		{
-			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(ellipse.getLinePen().getLineWidth()) + "\">\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(ellipse.getLinePen().getLineWidth()) + "\"");
+			if(LineStyleEnum.DOUBLE.equals(ellipse.getLinePen().getLineStyleValue()))
+			{
+				slideHelper.write(" cmpd=\"dbl\"");
+			}
+			slideHelper.write(">\n");
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(ellipse.getLinePen().getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
 			switch (ellipse.getLinePen().getLineStyleValue())
@@ -811,12 +828,18 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		{
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(text.getBackcolor()) + "\"/></a:solidFill>\n");
 		}
-		if (text.getLineBox().getPen().getLineWidth() > 0)
+		JRPen pen = getPptxPen(text.getLineBox());
+		if (pen != null)
 		{
-			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(text.getLineBox().getPen().getLineWidth()) + "\">\n");
-			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(text.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(pen.getLineWidth()) + "\"");
+			if(LineStyleEnum.DOUBLE.equals(pen.getLineStyleValue()))
+			{
+				slideHelper.write(" cmpd=\"dbl\"");
+			}
+			slideHelper.write(">\n");
+			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(pen.getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
-			switch (text.getLineBox().getPen().getLineStyleValue())
+			switch (pen.getLineStyleValue())
 			{
 				case DASHED :
 				{
@@ -852,15 +875,14 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 				"\" rtlCol=\"0\" anchor=\"");
 		switch (text.getVerticalTextAlign())
 		{
-			case TOP:
-				slideHelper.write("t");
+			case BOTTOM:
+				slideHelper.write("b");
 				break;
 			case MIDDLE:
 				slideHelper.write("ctr");
 				break;
-			case BOTTOM:
-				slideHelper.write("b");
-				break;
+			case TOP:
+			case JUSTIFIED:
 			default:
 				slideHelper.write("t");
 				break;
@@ -989,141 +1011,156 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		int availableImageHeight = image.getHeight() - topPadding - bottomPadding;
 		availableImageHeight = availableImageHeight < 0 ? 0 : availableImageHeight;
 
-		Renderable renderer = image.getRenderable();
+		Renderable renderer = image.getRenderer();
 
 		if (
-			renderer != null &&
-			availableImageWidth > 0 &&
-			availableImageHeight > 0
+			renderer != null
+			&& availableImageWidth > 0 
+			&& availableImageHeight > 0
 			)
 		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
-			{
-				// Non-lazy image renderers are all asked for their image data at some point.
-				// Better to test and replace the renderer now, in case of lazy load error.
-				renderer = RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForImageData(renderer, image.getOnErrorTypeValue());
-			}
-		}
-		else
-		{
-			renderer = null;
-		}
-
-		if (renderer != null)
-		{
-			int width = availableImageWidth;
-			int height = availableImageHeight;
-
-			double normalWidth = availableImageWidth;
-			double normalHeight = availableImageHeight;
-
-			// Image load might fail.
-			Renderable tmpRenderer =
-				RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
-			Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension(jasperReportsContext);
-			// If renderer was replaced, ignore image dimension.
-			if (tmpRenderer == renderer && dimension != null)
-			{
-				normalWidth = dimension.getWidth();
-				normalHeight = dimension.getHeight();
-			}
-
-			double cropTop = 0;
-			double cropLeft = 0;
-			double cropBottom = 0;
-			double cropRight = 0;
+			InternalImageProcessor imageProcessor = 
+				new InternalImageProcessor(
+					image, 
+					image.getScaleImageValue() != ScaleImageEnum.FILL_FRAME,
+					availableImageWidth,
+					availableImageHeight
+					);
+				
+			InternalImageProcessorResult imageProcessorResult = null;
 			
-			switch (image.getScaleImageValue())
+			try
 			{
-				case FILL_FRAME :
+				imageProcessorResult = imageProcessor.process(renderer);
+			}
+			catch (Exception e)
+			{
+				Renderable onErrorRenderer = getRendererUtil().handleImageError(e, image.getOnErrorTypeValue());
+				if (onErrorRenderer != null)
 				{
-					width = availableImageWidth;
-					height = availableImageHeight;
-//					cropTop = 100000 * topPadding / availableImageHeight;
-//					cropLeft = 100000 * leftPadding / availableImageWidth;
-//					cropBottom = 100000 * bottomPadding / availableImageHeight;
-//					cropRight = 100000 * rightPadding / availableImageWidth;
- 					break;
+					imageProcessorResult = imageProcessor.process(onErrorRenderer);
 				}
-				case CLIP :
-				{
-//					if (normalWidth > availableImageWidth)
-//					{
-						switch (image.getHorizontalImageAlign())
-						{
-							case RIGHT :
-							{
-								cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
-								cropRight = 0;
-//								cropRight = 100000 * rightPadding / availableImageWidth;
-								break;
-							}
-							case CENTER :
-							{
-								cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth / 2;
-								cropRight = cropLeft;
-								break;
-							}
-							case LEFT :
-							default :
-							{
-//								cropLeft = 100000 * leftPadding / availableImageWidth;
-								cropLeft = 0;
-								cropRight = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
-								break;
-							}
-						}
-//						width = availableImageWidth;
-////						cropLeft = cropLeft / 0.75d;
-////						cropRight = cropRight / 0.75d;
-//					}
-//					else
-//					{
-//						width = (int)normalWidth;
-//					}
+			}
+			
+			if (imageProcessorResult != null)//FIXMEPPTX render background for null images, like other exporters do 
+			{
+				int width = availableImageWidth;
+				int height = availableImageHeight;
 
-//					if (normalHeight > availableImageHeight)
-//					{
-						switch (image.getVerticalImageAlign())
-						{
-							case TOP :
-							{
-//								cropTop = 100000 * topPadding / availableImageHeight;
-								cropTop = 0;
-								cropBottom = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
-								break;
-							}
-							case MIDDLE :
-							{
-								cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight / 2;
-								cropBottom = cropTop;
-								break;
-							}
-							case BOTTOM :
-							default :
-							{
-								cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
-								cropBottom = 0;
-//								cropBottom = 100000 * bottomPadding / availableImageHeight;
-								break;
-							}
-						}
-//						height = availableImageHeight;
-//						cropTop = cropTop / 0.75d;
-//						cropBottom = cropBottom / 0.75d;
-//					}
-//					else
-//					{
-//						height = (int)normalHeight;
-//					}
-
-					break;
-				}
-				case RETAIN_SHAPE :
-				default :
+				double cropTop = 0;
+				double cropLeft = 0;
+				double cropBottom = 0;
+				double cropRight = 0;
+				
+				switch (image.getScaleImageValue())
 				{
-					if (availableImageHeight > 0)
+					case FILL_FRAME :
 					{
+						width = availableImageWidth;
+						height = availableImageHeight;
+//						cropTop = 100000 * topPadding / availableImageHeight;
+//						cropLeft = 100000 * leftPadding / availableImageWidth;
+//						cropBottom = 100000 * bottomPadding / availableImageHeight;
+//						cropRight = 100000 * rightPadding / availableImageWidth;
+	 					break;
+					}
+					case CLIP :
+					{
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
+//						if (normalWidth > availableImageWidth)
+//						{
+							switch (image.getHorizontalImageAlign())
+							{
+								case RIGHT :
+								{
+									cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
+									cropRight = 0;
+//									cropRight = 100000 * rightPadding / availableImageWidth;
+									break;
+								}
+								case CENTER :
+								{
+									cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth / 2;
+									cropRight = cropLeft;
+									break;
+								}
+								case LEFT :
+								default :
+								{
+//									cropLeft = 100000 * leftPadding / availableImageWidth;
+									cropLeft = 0;
+									cropRight = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
+									break;
+								}
+							}
+//							width = availableImageWidth;
+////							cropLeft = cropLeft / 0.75d;
+////							cropRight = cropRight / 0.75d;
+//						}
+//						else
+//						{
+//							width = (int)normalWidth;
+//						}
+
+//						if (normalHeight > availableImageHeight)
+//						{
+							switch (image.getVerticalImageAlign())
+							{
+								case TOP :
+								{
+//									cropTop = 100000 * topPadding / availableImageHeight;
+									cropTop = 0;
+									cropBottom = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
+									break;
+								}
+								case MIDDLE :
+								{
+									cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight / 2;
+									cropBottom = cropTop;
+									break;
+								}
+								case BOTTOM :
+								default :
+								{
+									cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
+									cropBottom = 0;
+//									cropBottom = 100000 * bottomPadding / availableImageHeight;
+									break;
+								}
+							}
+//							height = availableImageHeight;
+//							cropTop = cropTop / 0.75d;
+//							cropBottom = cropBottom / 0.75d;
+//						}
+//						else
+//						{
+//							height = (int)normalHeight;
+//						}
+
+						break;
+					}
+					case RETAIN_SHAPE :
+					default :
+					{
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
 						double ratio = normalWidth / normalHeight;
 
 						if( ratio > availableImageWidth / (double)availableImageHeight )
@@ -1184,57 +1221,202 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 						}
 					}
 				}
+
+//				insertPageAnchor();
+//				if (image.getAnchorName() != null)
+//				{
+//					tempBodyWriter.write("<text:bookmark text:name=\"");
+//					tempBodyWriter.write(image.getAnchorName());
+//					tempBodyWriter.write("\"/>");
+//				}
+
+
+//				boolean startedHyperlink = startHyperlink(image,false);
+
+				slideRelsHelper.exportImage(imageProcessorResult.imagePath);
+
+				slideHelper.write("<p:pic>\n");
+				slideHelper.write("  <p:nvPicPr>\n");
+				slideHelper.write("    <p:cNvPr id=\"" + toOOXMLId(image) + "\" name=\"Picture\">\n");
+
+				String href = getHyperlinkURL(image);
+				if (href != null)
+				{
+					slideHelper.exportHyperlink(href);
+				}
+				
+				slideHelper.write("    </p:cNvPr>\n");
+				slideHelper.write("    <p:cNvPicPr>\n");
+				slideHelper.write("      <a:picLocks noChangeAspect=\"1\"/>\n");
+				slideHelper.write("    </p:cNvPicPr>\n");
+				slideHelper.write("    <p:nvPr/>\n");
+				slideHelper.write("  </p:nvPicPr>\n");
+				slideHelper.write("<p:blipFill>\n");
+				slideHelper.write("<a:blip r:embed=\"" + imageProcessorResult.imagePath + "\"/>");
+				slideHelper.write("<a:srcRect");
+////				if (cropLeft > 0)
+////				{
+//					slideHelper.write(" l=\"" + (int)(100000 * leftPadding / image.getWidth()) + "\"");
+////				}
+////				if (cropTop > 0)
+////				{
+//					slideHelper.write(" t=\"" + (int)cropTop + "\"");
+////				}
+////				if (cropRight > 0)
+////				{
+//					slideHelper.write(" r=\"" + (int)cropRight + "\"");
+////				}
+////				if (cropBottom > 0)
+////				{
+//					slideHelper.write(" b=\"" + (int)cropBottom + "\"");
+////				}
+				slideHelper.write("/>");
+				slideHelper.write("<a:stretch><a:fillRect");
+//				if (cropLeft > 0)
+//				{
+					slideHelper.write(" l=\"" + (int)cropLeft + "\"");
+//				}
+//				if (cropTop > 0)
+//				{
+					slideHelper.write(" t=\"" + (int)cropTop + "\"");
+//				}
+//				if (cropRight > 0)
+//				{
+					slideHelper.write(" r=\"" + (int)cropRight + "\"");
+//				}
+//				if (cropBottom > 0)
+//				{
+					slideHelper.write(" b=\"" + (int)cropBottom + "\"");
+//				}
+				slideHelper.write("/></a:stretch>\n");
+				slideHelper.write("</p:blipFill>\n");
+				slideHelper.write("  <p:spPr>\n");
+				slideHelper.write("    <a:xfrm>\n");
+				slideHelper.write("      <a:off x=\"" + LengthUtil.emu(image.getX() + getOffsetX() + leftPadding) + "\" y=\"" + LengthUtil.emu(image.getY() + getOffsetY() + topPadding) + "\"/>\n");
+				slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(availableImageWidth) + "\" cy=\"" + LengthUtil.emu(availableImageHeight) + "\"/>\n");
+				slideHelper.write("    </a:xfrm><a:prstGeom prst=\"rect\"><a:avLst/></a:prstGeom>\n");
+				if (image.getModeValue() == ModeEnum.OPAQUE && image.getBackcolor() != null)
+				{
+					slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getBackcolor()) + "\"/></a:solidFill>\n");
+				}
+				JRPen pen = getPptxPen(image.getLineBox());
+				if (pen != null)
+				{
+					slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(pen.getLineWidth()) + "\"");
+					if(LineStyleEnum.DOUBLE.equals(pen.getLineStyleValue()))
+					{
+						slideHelper.write(" cmpd=\"dbl\"");
+					}
+					slideHelper.write(">\n");
+					slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(pen.getLineColor()) + "\"/></a:solidFill>\n");
+					slideHelper.write("<a:prstDash val=\"");
+					switch (pen.getLineStyleValue())
+					{
+						case DASHED :
+						{
+							slideHelper.write("dash");
+							break;
+						}
+						case DOTTED :
+						{
+							slideHelper.write("dot");
+							break;
+						}
+						case DOUBLE :
+						case SOLID :
+						default :
+						{
+							slideHelper.write("solid");
+							break;
+						}
+					}
+					slideHelper.write("\"/>\n");
+					slideHelper.write("  </a:ln>\n");
+				}
+				slideHelper.write("  </p:spPr>\n");
+				slideHelper.write("  </p:pic>\n");
+
+//				if(startedHyperlink)
+//				{
+//					endHyperlink(false);
+//				}
 			}
+		}
 
-//			insertPageAnchor();
-//			if (image.getAnchorName() != null)
-//			{
-//				tempBodyWriter.write("<text:bookmark text:name=\"");
-//				tempBodyWriter.write(image.getAnchorName());
-//				tempBodyWriter.write("\"/>");
-//			}
+//		docHelper.write("</w:p>");
+	}
 
+	private class InternalImageProcessor
+	{
+		private final JRPrintElement imageElement;
+		private final boolean needDimension; 
+		private final int availableImageWidth;
+		private final int availableImageHeight;
 
-//			boolean startedHyperlink = startHyperlink(image,false);
-
+		protected InternalImageProcessor(
+			JRPrintElement imageElement,
+			boolean needDimension,
+			int availableImageWidth,
+			int availableImageHeight
+			)
+		{
+			this.imageElement = imageElement;
+			this.needDimension = needDimension;
+			this.availableImageWidth = availableImageWidth;
+			this.availableImageHeight = availableImageHeight;
+		}
+		
+		private InternalImageProcessorResult process(Renderable renderer) throws JRException
+		{
+			if (renderer instanceof ResourceRenderer)
+			{
+				renderer = renderersCache.getLoadedRenderer((ResourceRenderer)renderer);
+			}
+			
+			// check dimension first, to avoid caching renderers that might not be used eventually, due to their dimension errors 
+			Dimension2D dimension = null;
+			if (needDimension)
+			{
+				DimensionRenderable dimensionRenderer = renderersCache.getDimensionRenderable(renderer);
+				dimension = dimensionRenderer == null ? null :  dimensionRenderer.getDimension(jasperReportsContext);
+			}
+			
+			
 			String imagePath = null;
 
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
-			{
-				imagePath = rendererToImagePathMap.get(renderer.getId());
-			}
-			else
-			{
-//				if (isLazy)//FIXMEDOCX learn how to link images
-//				{
-//					imagePath = ((JRImageRenderer)renderer).getImageLocation();
-//				}
-//				else
-//				{
+//			if (image.isLazy()) //FIXMEPPTX learn how to link images
+//			{
+//
+//			}
+//			else
+//			{
+				if (
+					renderer instanceof DataRenderable //we do not cache imagePath for non-data renderers because they render width different width/height each time
+					&& rendererToImagePathMap.containsKey(renderer.getId())
+					)
+				{
+					imagePath = rendererToImagePathMap.get(renderer.getId());
+				}
+				else
+				{
 					JRPrintElementIndex imageIndex = getElementIndex();
 
-					if (renderer.getTypeValue() == RenderableTypeEnum.SVG)
-					{
-						renderer =
-							new JRWrappingSvgRenderer(
+					DataRenderable imageRenderer = 
+							getRendererUtil().getImageDataRenderable(
+								renderersCache,
 								renderer,
-								new Dimension(image.getWidth(), image.getHeight()),
-								ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
+								new Dimension(availableImageWidth, availableImageHeight),
+								ModeEnum.OPAQUE == imageElement.getModeValue() ? imageElement.getBackcolor() : null
 								);
-					}
-					
-					String mimeType = renderer.getImageTypeValue().getMimeType();//FIXMEEXPORT this code for file extension is duplicated; is it now?
-					if (mimeType == null)
-					{
-						mimeType = ImageTypeEnum.JPEG.getMimeType();
-					}
-					String extension = mimeType.substring(mimeType.lastIndexOf('/') + 1);
-					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + "." + extension;
+
+					byte[] imageData = imageRenderer.getData(jasperReportsContext);
+					String fileExtension = JRTypeSniffer.getImageTypeValue(imageData).getFileExtension();
+					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + (fileExtension == null ? "" : ("." + fileExtension));
 
 					pptxZip.addEntry(//FIXMEPPTX optimize with a different implementation of entry
 						new FileBufferedZipEntry(
 							"ppt/media/" + imageName,
-							renderer.getImageData(jasperReportsContext)
+							imageData
 							)
 						);
 					
@@ -1242,133 +1424,47 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 					
 					imagePath = imageName;
 					//imagePath = "Pictures/" + imageName;
-//				}
 
-				rendererToImagePathMap.put(renderer.getId(), imagePath);
-			}
-
-			slideRelsHelper.exportImage(imagePath);
-
-			slideHelper.write("<p:pic>\n");
-			slideHelper.write("  <p:nvPicPr>\n");
-			slideHelper.write("    <p:cNvPr id=\"" + toOOXMLId(image) + "\" name=\"Picture\">\n");
-
-			String href = getHyperlinkURL(image);
-			if (href != null)
-			{
-				slideHelper.exportHyperlink(href);
-			}
-			
-			slideHelper.write("    </p:cNvPr>\n");
-			slideHelper.write("    <p:cNvPicPr>\n");
-			slideHelper.write("      <a:picLocks noChangeAspect=\"1\"/>\n");
-			slideHelper.write("    </p:cNvPicPr>\n");
-			slideHelper.write("    <p:nvPr/>\n");
-			slideHelper.write("  </p:nvPicPr>\n");
-			slideHelper.write("<p:blipFill>\n");
-			slideHelper.write("<a:blip r:embed=\"" + imagePath + "\"/>");
-			slideHelper.write("<a:srcRect");
-////			if (cropLeft > 0)
-////			{
-//				slideHelper.write(" l=\"" + (int)(100000 * leftPadding / image.getWidth()) + "\"");
-////			}
-////			if (cropTop > 0)
-////			{
-//				slideHelper.write(" t=\"" + (int)cropTop + "\"");
-////			}
-////			if (cropRight > 0)
-////			{
-//				slideHelper.write(" r=\"" + (int)cropRight + "\"");
-////			}
-////			if (cropBottom > 0)
-////			{
-//				slideHelper.write(" b=\"" + (int)cropBottom + "\"");
-////			}
-			slideHelper.write("/>");
-			slideHelper.write("<a:stretch><a:fillRect");
-//			if (cropLeft > 0)
-//			{
-				slideHelper.write(" l=\"" + (int)cropLeft + "\"");
-//			}
-//			if (cropTop > 0)
-//			{
-				slideHelper.write(" t=\"" + (int)cropTop + "\"");
-//			}
-//			if (cropRight > 0)
-//			{
-				slideHelper.write(" r=\"" + (int)cropRight + "\"");
-//			}
-//			if (cropBottom > 0)
-//			{
-				slideHelper.write(" b=\"" + (int)cropBottom + "\"");
-//			}
-			slideHelper.write("/></a:stretch>\n");
-			slideHelper.write("</p:blipFill>\n");
-			slideHelper.write("  <p:spPr>\n");
-			slideHelper.write("    <a:xfrm>\n");
-			slideHelper.write("      <a:off x=\"" + LengthUtil.emu(image.getX() + getOffsetX() + leftPadding) + "\" y=\"" + LengthUtil.emu(image.getY() + getOffsetY() + topPadding) + "\"/>\n");
-			slideHelper.write("      <a:ext cx=\"" + LengthUtil.emu(availableImageWidth) + "\" cy=\"" + LengthUtil.emu(availableImageHeight) + "\"/>\n");
-			slideHelper.write("    </a:xfrm><a:prstGeom prst=\"rect\"><a:avLst/></a:prstGeom>\n");
-			if (image.getModeValue() == ModeEnum.OPAQUE && image.getBackcolor() != null)
-			{
-				slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getBackcolor()) + "\"/></a:solidFill>\n");
-			}
-			if (image.getLineBox().getPen().getLineWidth() > 0)
-			{
-				slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(image.getLineBox().getPen().getLineWidth()) + "\">\n");
-				slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
-				slideHelper.write("<a:prstDash val=\"");
-				switch (image.getLineBox().getPen().getLineStyleValue())
-				{
-					case DASHED :
+					if (imageRenderer == renderer)
 					{
-						slideHelper.write("dash");
-						break;
-					}
-					case DOTTED :
-					{
-						slideHelper.write("dot");
-						break;
-					}
-					case DOUBLE :
-					case SOLID :
-					default :
-					{
-						slideHelper.write("solid");
-						break;
+						//cache imagePath only for true ImageRenderable instances because the wrapping ones render with different width/height each time
+						rendererToImagePathMap.put(renderer.getId(), imagePath);
 					}
 				}
-				slideHelper.write("\"/>\n");
-				slideHelper.write("  </a:ln>\n");
-			}
-			slideHelper.write("  </p:spPr>\n");
-			slideHelper.write("  </p:pic>\n");
-
-//			if(startedHyperlink)
-//			{
-//				endHyperlink(false);
 //			}
+			
+			return new InternalImageProcessorResult(imagePath, dimension);
 		}
+	}
 
-//		docHelper.write("</w:p>");
+	private class InternalImageProcessorResult
+	{
+		protected final String imagePath;
+		protected final Dimension2D dimension;
+		
+		protected InternalImageProcessorResult(String imagePath, Dimension2D dimension)
+		{
+			this.imagePath = imagePath;
+			this.dimension = dimension;
+		}
 	}
 
 
 	protected JRPrintElementIndex getElementIndex()
 	{
-		StringBuffer sbuffer = new StringBuffer();
+		StringBuilder sb = new StringBuilder();
 		for (int i = 0; i < frameIndexStack.size(); i++)
 		{
 			Integer frameIndex = frameIndexStack.get(i);
 
-			sbuffer.append(frameIndex).append("_");
+			sb.append(frameIndex).append("_");
 		}
 		
 		JRPrintElementIndex imageIndex =
 			new JRPrintElementIndex(
 					reportIndex,
 					pageIndex,
-					sbuffer.append(elementIndex).toString()
+					sb.append(elementIndex).toString()
 					);
 		return imageIndex;
 	}
@@ -1408,7 +1504,7 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		int[] coords = area.getCoordinates();
 		if (coords != null && coords.length > 0)
 		{
-			StringBuffer coordsEnum = new StringBuffer(coords.length * 4);
+			StringBuilder coordsEnum = new StringBuilder(coords.length * 4);
 			coordsEnum.append(coords[0]);
 			for (int i = 1; i < coords.length; i++)
 			{
@@ -1489,12 +1585,18 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		{
 			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(frame.getBackcolor()) + "\"/></a:solidFill>\n");
 		}
-		if (frame.getLineBox().getPen().getLineWidth() > 0)
+		JRPen pen = getPptxPen(frame.getLineBox());
+		if (pen != null)
 		{
-			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(frame.getLineBox().getPen().getLineWidth()) + "\">\n");
-			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(frame.getLineBox().getPen().getLineColor()) + "\"/></a:solidFill>\n");
+			slideHelper.write("  <a:ln w=\"" + LengthUtil.emu(pen.getLineWidth()) + "\"");
+			if(LineStyleEnum.DOUBLE.equals(pen.getLineStyleValue()))
+			{
+				slideHelper.write(" cmpd=\"dbl\"");
+			}
+			slideHelper.write(">\n");
+			slideHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(pen.getLineColor()) + "\"/></a:solidFill>\n");
 			slideHelper.write("<a:prstDash val=\"");
-			switch (frame.getLineBox().getPen().getLineStyleValue())
+			switch (pen.getLineStyleValue())
 			{
 				case DASHED :
 				{
@@ -1563,57 +1665,6 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 	}
 
 
-//	private float getXAlignFactor(JRPrintImage image)
-//	{
-//		float xalignFactor = 0f;
-//		switch (image.getHorizontalAlignmentValue())
-//		{
-//			case RIGHT :
-//			{
-//				xalignFactor = 1f;
-//				break;
-//			}
-//			case CENTER :
-//			{
-//				xalignFactor = 0.5f;
-//				break;
-//			}
-//			case LEFT :
-//			default :
-//			{
-//				xalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return xalignFactor;
-//	}
-
-
-//	private float getYAlignFactor(JRPrintImage image)
-//	{
-//		float yalignFactor = 0f;
-//		switch (image.getVerticalAlignmentValue())
-//		{
-//			case BOTTOM :
-//			{
-//				yalignFactor = 1f;
-//				break;
-//			}
-//			case MIDDLE :
-//			{
-//				yalignFactor = 0.5f;
-//				break;
-//			}
-//			case TOP :
-//			default :
-//			{
-//				yalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return yalignFactor;
-//	}
-
 //	protected boolean startHyperlink(JRPrintHyperlink link, boolean isText)
 //	{
 //		String href = getHyperlinkURL(link);
@@ -1786,17 +1837,13 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 //		}
 //	}
 	
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterKey()
 	{
 		return PPTX_EXPORTER_KEY;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterPropertiesPrefix()
 	{
 		return PPTX_EXPORTER_PROPERTIES_PREFIX;
@@ -1811,5 +1858,36 @@ public class JRPptxExporter extends JRAbstractExporter<PptxReportConfiguration,
 		// OOXML object ids are xsd:unsignedInt 
 		return Long.toString(hashCode & 0xFFFFFFFFL); 
 	}
+	
+	protected JRPen getPptxPen(JRLineBox box)
+	{
+		JRBasePen pen = null;
+		Float lineWidth = box.getPen().getLineWidth();
+		if(lineWidth == 0)
+		{
+			// PPTX does not support side borders
+			// in case side borders are defined for the report element, ensure that all 4 are declared and all of them come with the same settings
+			if(
+				((JRBasePen)box.getTopPen()).isIdentical(box.getLeftPen())
+				&& ((JRBasePen)box.getTopPen()).isIdentical(box.getBottomPen())
+				&& ((JRBasePen)box.getTopPen()).isIdentical(box.getRightPen())
+				&& box.getTopPen().getLineWidth() > 0
+				)
+			{
+				pen = new JRBasePen(box);
+				pen.setLineWidth(box.getTopPen().getLineWidth());
+				pen.setLineColor(box.getTopPen().getLineColor());
+				pen.setLineStyle(box.getTopPen().getLineStyleValue());
+			}
+		}
+		else
+		{
+			pen = new JRBasePen(box);
+			pen.setLineWidth(lineWidth);
+			pen.setLineColor(box.getPen().getLineColor());
+			pen.setLineStyle(box.getPen().getLineStyleValue());
+		}
+		return pen;
+	}
 }
 
