@@ -32,15 +32,16 @@ import java.io.UnsupportedEncodingException;
 import java.io.Writer;
 import java.net.URLEncoder;
 import java.text.AttributedCharacterIterator;
-import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashMap;
-import java.util.Iterator;
 import java.util.LinkedList;
 import java.util.List;
 import java.util.Locale;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.DefaultJasperReportsContext;
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRException;
@@ -48,6 +49,7 @@ import net.sf.jasperreports.engine.JRGenericElementType;
 import net.sf.jasperreports.engine.JRGenericPrintElement;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPen;
+import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintElementIndex;
 import net.sf.jasperreports.engine.JRPrintFrame;
 import net.sf.jasperreports.engine.JRPrintGraphicElement;
@@ -59,12 +61,9 @@ import net.sf.jasperreports.engine.JRPrintText;
 import net.sf.jasperreports.engine.JRPropertiesUtil;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRStyle;
-import net.sf.jasperreports.engine.JRWrappingSvgRenderer;
 import net.sf.jasperreports.engine.JasperPrint;
 import net.sf.jasperreports.engine.JasperReportsContext;
 import net.sf.jasperreports.engine.PrintPageFormat;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
 import net.sf.jasperreports.engine.base.JRBaseLineBox;
 import net.sf.jasperreports.engine.export.Cut;
 import net.sf.jasperreports.engine.export.CutsInfo;
@@ -88,21 +87,24 @@ import net.sf.jasperreports.engine.export.type.ImageAnchorTypeEnum;
 import net.sf.jasperreports.engine.export.zip.ExportZipEntry;
 import net.sf.jasperreports.engine.export.zip.FileBufferedZipEntry;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
-import net.sf.jasperreports.engine.type.ImageTypeEnum;
 import net.sf.jasperreports.engine.type.LineDirectionEnum;
 import net.sf.jasperreports.engine.type.ModeEnum;
-import net.sf.jasperreports.engine.type.RenderableTypeEnum;
+import net.sf.jasperreports.engine.type.ScaleImageEnum;
+import net.sf.jasperreports.engine.util.DefaultFormatFactory;
 import net.sf.jasperreports.engine.util.FileBufferedOutputStream;
 import net.sf.jasperreports.engine.util.JRDataUtils;
+import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
+import net.sf.jasperreports.engine.util.JRTypeSniffer;
 import net.sf.jasperreports.export.ExporterInput;
 import net.sf.jasperreports.export.ExporterInputItem;
 import net.sf.jasperreports.export.XlsReportConfiguration;
 import net.sf.jasperreports.export.XlsxExporterConfiguration;
 import net.sf.jasperreports.export.XlsxReportConfiguration;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.renderers.DataRenderable;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.ResourceRenderer;
 
 
 /**
@@ -160,13 +162,12 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	protected XlsxDrawingRelsHelper drawingRelsHelper;
 	protected XlsxStyleHelper styleHelper;
 	protected XlsxCellHelper cellHelper;//FIXMEXLSX maybe cell helper should be part of sheet helper, just like in table helper
-	protected StringBuffer definedNames;
+	protected StringBuilder definedNames;
 	protected String firstSheetName;
 	protected String currentSheetName;
 
 	protected Map<String, String> rendererToImagePathMap;
 //	protected Map imageMaps;
-	protected List<JRPrintElementIndex> imagesToProcess;
 //	protected Map hyperlinksMap;
 
 	protected int tableIndex;
@@ -216,18 +217,14 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<XlsxExporterConfiguration> getConfigurationInterface()
 	{
 		return XlsxExporterConfiguration.class;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected Class<XlsxReportConfiguration> getItemConfigurationInterface()
 	{
 		return XlsxReportConfiguration.class;
@@ -325,50 +322,6 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
-	/**
-	 *
-	 */
-	protected String getImagePath(Renderable renderer, boolean isLazy, JRExporterGridCell gridCell)
-	{
-		String imagePath = null;
-
-		if (renderer != null)
-		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE && rendererToImagePathMap.containsKey(renderer.getId()))
-			{
-				imagePath = rendererToImagePathMap.get(renderer.getId());
-			}
-			else
-			{
-//				if (isLazy)//FIXMEDOCX learn how to link images
-//				{
-//					imagePath = ((JRImageRenderer)renderer).getImageLocation();
-//				}
-//				else
-//				{
-					JRPrintElementIndex imageIndex = getElementIndex(gridCell);
-					imagesToProcess.add(imageIndex);
-
-					String mimeType = renderer.getImageTypeValue().getMimeType();//FIXMEPPTX this code for file extension is duplicated
-					if (mimeType == null)
-					{
-						mimeType = ImageTypeEnum.JPEG.getMimeType();
-					}
-					String extension = mimeType.substring(mimeType.lastIndexOf('/') + 1);
-
-					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + "." + extension;
-					imagePath = imageName;
-					//imagePath = "Pictures/" + imageName;
-//				}
-
-				rendererToImagePathMap.put(renderer.getId(), imagePath);
-			}
-		}
-
-		return imagePath;
-	}
-
-
 	protected JRPrintElementIndex getElementIndex(JRExporterGridCell gridCell)
 	{
 		JRPrintElementIndex imageIndex =
@@ -415,7 +368,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		int[] coords = area.getCoordinates();
 		if (coords != null && coords.length > 0)
 		{
-			StringBuffer coordsEnum = new StringBuffer(coords.length * 4);
+			StringBuilder coordsEnum = new StringBuilder(coords.length * 4);
 			coordsEnum.append(coords[0]);
 			for (int i = 1; i < coords.length; i++)
 			{
@@ -491,57 +444,6 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
-//	private float getXAlignFactor(JRPrintImage image)
-//	{
-//		float xalignFactor = 0f;
-//		switch (image.getHorizontalAlignmentValue())
-//		{
-//			case RIGHT :
-//			{
-//				xalignFactor = 1f;
-//				break;
-//			}
-//			case CENTER :
-//			{
-//				xalignFactor = 0.5f;
-//				break;
-//			}
-//			case LEFT :
-//			default :
-//			{
-//				xalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return xalignFactor;
-//	}
-
-
-//	private float getYAlignFactor(JRPrintImage image)
-//	{
-//		float yalignFactor = 0f;
-//		switch (image.getVerticalAlignmentValue())
-//		{
-//			case BOTTOM :
-//			{
-//				yalignFactor = 1f;
-//				break;
-//			}
-//			case MIDDLE :
-//			{
-//				yalignFactor = 0.5f;
-//				break;
-//			}
-//			case TOP :
-//			default :
-//			{
-//				yalignFactor = 0f;
-//				break;
-//			}
-//		}
-//		return yalignFactor;
-//	}
-
 //	protected boolean startHyperlink(JRPrintHyperlink link, boolean isText)
 //	{
 //		String href = getHyperlinkURL(link);
@@ -712,24 +614,26 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		if(!getCurrentItemConfiguration().isIgnoreAnchors() && startPage)
 		{
 			String anchorPage = JR_PAGE_ANCHOR_PREFIX + reportIndex + "_" + (sheetIndex - sheetsBeforeCurrentReport);
-			String ref = "'" + currentSheetName + "'!$A$1";		// + XlsxCellHelper.getColumIndexLetter(colIndex) + "$" + (rowIndex + 1);
+			String ref = "'" + JRStringUtil.xmlEncode(currentSheetName) + "'!$A$1";		// + XlsxCellHelper.getColumIndexLetter(colIndex) + "$" + (rowIndex + 1);
 			definedNames.append("<definedName name=\"" + getDefinedName(anchorPage) +"\">"+ ref +"</definedName>\n");
 			startPage = false;
 		}
 	}
 	
 
+	@Override
 	protected void addBlankCell(
 		JRExporterGridCell gridCell, 
 		int colIndex,
 		int rowIndex
 		) throws JRException 
 	{
-		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 		cellHelper.exportFooter();
 	}
 
 
+	@Override
 	protected void closeWorkbook(OutputStream os) throws JRException //FIXMEXLSX could throw IOException here, as other implementations do
 	{
 		styleHelper.export();
@@ -742,44 +646,6 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 
 			wbHelper.close();
 
-			if ((imagesToProcess != null && imagesToProcess.size() > 0))
-			{
-				for(Iterator<JRPrintElementIndex> it = imagesToProcess.iterator(); it.hasNext();)
-				{
-					JRPrintElementIndex imageIndex = it.next();
-
-					JRPrintImage image = getImage(exporterInput, imageIndex);
-					Renderable renderer = image.getRenderable();
-					if (renderer.getTypeValue() == RenderableTypeEnum.SVG)
-					{
-						renderer =
-							new JRWrappingSvgRenderer(
-								renderer,
-								new Dimension(image.getWidth(), image.getHeight()),
-								ModeEnum.OPAQUE == image.getModeValue() ? image.getBackcolor() : null
-								);
-					}
-
-					String mimeType = renderer.getImageTypeValue().getMimeType();
-					if (mimeType == null)
-					{
-						mimeType = ImageTypeEnum.JPEG.getMimeType();
-					}
-					String extension = mimeType.substring(mimeType.lastIndexOf('/') + 1);
-					
-					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + "." + extension;
-					
-					xlsxZip.addEntry(//FIXMEDOCX optimize with a different implementation of entry
-						new FileBufferedZipEntry(
-							"xl/media/" + imageName,
-							renderer.getImageData(jasperReportsContext)
-							)
-						);
-					
-//					drawingRelsHelper.exportImage(imageName);
-				}
-			}
-
 //			if ((hyperlinksMap != null && hyperlinksMap.size() > 0))
 //			{
 //				for(Iterator it = hyperlinksMap.keySet().iterator(); it.hasNext();)
@@ -811,6 +677,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	protected void createSheet(CutsInfo xCuts, SheetInfo sheetInfo)
 	{
 		startPage = true;
@@ -861,7 +728,14 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		{
 			showGridlines = sheetInfo.sheetShowGridlines;
 		}
-		sheetHelper.exportHeader(showGridlines, (sheetInfo.sheetPageScale == null ? 0 : sheetInfo.sheetPageScale), gridRowFreezeIndex, gridColumnFreezeIndex, jasperPrint);
+		sheetHelper.exportHeader(
+				showGridlines, 
+				(sheetInfo.sheetPageScale == null ? 0 : sheetInfo.sheetPageScale), 
+				sheetInfo.rowFreezeIndex, 
+				sheetInfo.columnFreezeIndex, 
+				maxColumnIndex,
+				jasperPrint, 
+				sheetInfo.tabColor);
 		sheetRelsHelper.exportHeader(sheetIndex + 1);
 		drawingHelper.exportHeader();
 		drawingRelsHelper.exportHeader();
@@ -922,6 +796,11 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 						);
 				}
 			}
+			if(sheetAutoFilter != null)
+			{
+				int index = Math.max(0, sheetIndex-1);
+				definedNames.append("<definedName name=\"_xlnm._FilterDatabase\" localSheetId=\"" + index + "\">'" + JRStringUtil.xmlEncode(currentSheetName) +"'!"+sheetAutoFilter+"</definedName>\n");
+			}
 			sheetHelper.close();
 
 			sheetRelsHelper.exportFooter();
@@ -936,6 +815,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	protected void exportFrame(
 		JRPrintFrame frame, 
 		JRExporterGridCell gridCell,
@@ -943,7 +823,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		int rowIndex
 		) throws JRException 
 	{
-		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 		sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
 
 //		boolean appendBackcolor =
@@ -978,6 +858,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	public void exportImage(
 		JRPrintImage image, 
 		JRExporterGridCell gridCell,
@@ -1003,129 +884,145 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		int availableImageHeight = image.getHeight() - topPadding - bottomPadding;
 		availableImageHeight = availableImageHeight < 0 ? 0 : availableImageHeight;
 
-		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 
-		Renderable renderer = image.getRenderable();
+		Renderable renderer = image.getRenderer();
 
 		if (
-			renderer != null &&
-			availableImageWidth > 0 &&
-			availableImageHeight > 0
+			renderer != null
+			&& availableImageWidth > 0 
+			&& availableImageHeight > 0
 			)
 		{
-			if (renderer.getTypeValue() == RenderableTypeEnum.IMAGE)
-			{
-				// Non-lazy image renderers are all asked for their image data at some point.
-				// Better to test and replace the renderer now, in case of lazy load error.
-				renderer = RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForImageData(renderer, image.getOnErrorTypeValue());
-			}
-		}
-		else
-		{
-			renderer = null;
-		}
-
-		if (renderer != null)
-		{
-			int width = availableImageWidth;
-			int height = availableImageHeight;
-
-			double normalWidth = availableImageWidth;
-			double normalHeight = availableImageHeight;
-
-			// Image load might fail.
-			Renderable tmpRenderer =
-				RenderableUtil.getInstance(jasperReportsContext).getOnErrorRendererForDimension(renderer, image.getOnErrorTypeValue());
-			Dimension2D dimension = tmpRenderer == null ? null : tmpRenderer.getDimension(jasperReportsContext);
-			// If renderer was replaced, ignore image dimension.
-			if (tmpRenderer == renderer && dimension != null)
-			{
-				normalWidth = dimension.getWidth();
-				normalHeight = dimension.getHeight();
-			}
-
-			double cropTop = 0;
-			double cropLeft = 0;
-			double cropBottom = 0;
-			double cropRight = 0;
+			InternalImageProcessor imageProcessor = 
+				new InternalImageProcessor(
+					image, 
+					image.getScaleImageValue() != ScaleImageEnum.FILL_FRAME, 
+					gridCell,
+					availableImageWidth,
+					availableImageHeight
+					);
+				
+			InternalImageProcessorResult imageProcessorResult = null;
 			
-			switch (image.getScaleImageValue())
+			try
 			{
-				case FILL_FRAME :
+				imageProcessorResult = imageProcessor.process(renderer);
+			}
+			catch (Exception e)
+			{
+				Renderable onErrorRenderer = getRendererUtil().handleImageError(e, image.getOnErrorTypeValue());
+				if (onErrorRenderer != null)
 				{
-					width = availableImageWidth;
-					height = availableImageHeight;
- 					break;
+					imageProcessorResult = imageProcessor.process(onErrorRenderer);
 				}
-				case CLIP :
-				{
-//					if (normalWidth > availableImageWidth)
-//					{
-						switch (image.getHorizontalImageAlign())
-						{
-							case RIGHT :
-							{
-								cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
-								cropRight = 0;
-								break;
-							}
-							case CENTER :
-							{
-								cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth / 2;
-								cropRight = cropLeft;
-								break;
-							}
-							case LEFT :
-							default :
-							{
-								cropLeft = 0;
-								cropRight = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
-								break;
-							}
-						}
-//					}
-//					else
-//					{
-//						width = (int)normalWidth;
-//					}
+			}
+			
+			if (imageProcessorResult != null)
+			{
+				int width = availableImageWidth;
+				int height = availableImageHeight;
 
-//					if (normalHeight > availableImageHeight)
-//					{
-						switch (image.getVerticalImageAlign())
-						{
-							case TOP :
-							{
-								cropTop = 0;
-								cropBottom = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
-								break;
-							}
-							case MIDDLE :
-							{
-								cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight / 2;
-								cropBottom = cropTop;
-								break;
-							}
-							case BOTTOM :
-							default :
-							{
-								cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
-								cropBottom = 0;
-								break;
-							}
-						}
-//					}
-//					else
-//					{
-//						height = (int)normalHeight;
-//					}
-
-					break;
-				}
-				case RETAIN_SHAPE :
-				default :
+				double cropTop = 0;
+				double cropLeft = 0;
+				double cropBottom = 0;
+				double cropRight = 0;
+				
+				switch (image.getScaleImageValue())
 				{
-					if (availableImageHeight > 0)//FIXMEXLSX this is useless. test is above. check all
+					case FILL_FRAME :
 					{
+						width = availableImageWidth;
+						height = availableImageHeight;
+	 					break;
+					}
+					case CLIP :
+					{
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
+//						if (normalWidth > availableImageWidth)
+//						{
+							switch (image.getHorizontalImageAlign())
+							{
+								case RIGHT :
+								{
+									cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
+									cropRight = 0;
+									break;
+								}
+								case CENTER :
+								{
+									cropLeft = 100000 * (availableImageWidth - normalWidth) / availableImageWidth / 2;
+									cropRight = cropLeft;
+									break;
+								}
+								case LEFT :
+								default :
+								{
+									cropLeft = 0;
+									cropRight = 100000 * (availableImageWidth - normalWidth) / availableImageWidth;
+									break;
+								}
+							}
+//						}
+//						else
+//						{
+//							width = (int)normalWidth;
+//						}
+
+//						if (normalHeight > availableImageHeight)
+//						{
+							switch (image.getVerticalImageAlign())
+							{
+								case TOP :
+								{
+									cropTop = 0;
+									cropBottom = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
+									break;
+								}
+								case MIDDLE :
+								{
+									cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight / 2;
+									cropBottom = cropTop;
+									break;
+								}
+								case BOTTOM :
+								default :
+								{
+									cropTop = 100000 * (availableImageHeight - normalHeight) / availableImageHeight;
+									cropBottom = 0;
+									break;
+								}
+							}
+//						}
+//						else
+//						{
+//							height = (int)normalHeight;
+//						}
+
+						break;
+					}
+					case RETAIN_SHAPE :
+					default :
+					{
+						double normalWidth = availableImageWidth;
+						double normalHeight = availableImageHeight;
+
+						Dimension2D dimension = imageProcessorResult.dimension;
+						if (dimension != null)
+						{
+							normalWidth = dimension.getWidth();
+							normalHeight = dimension.getHeight();
+						}
+
 						double ratio = normalWidth / normalHeight;
 
 						if( ratio > availableImageWidth / (double)availableImageHeight )
@@ -1186,107 +1083,106 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 						}
 					}
 				}
-			}
 
-			XlsReportConfiguration configuration = getCurrentItemConfiguration();
-			
-			if(!configuration.isIgnoreAnchors())
-			{
-				insertPageAnchor(colIndex,rowIndex);
-				if (image.getAnchorName() != null)
+				XlsReportConfiguration configuration = getCurrentItemConfiguration();
+				
+				if (!configuration.isIgnoreAnchors())
 				{
-					String ref = "'" + currentSheetName + "'!$" + JRXlsAbstractExporter.getColumIndexName(colIndex, maxColumnIndex) + "$" + (rowIndex + 1);
-					definedNames.append("<definedName name=\"" + getDefinedName(image.getAnchorName()) +"\">"+ ref +"</definedName>\n");
+					insertPageAnchor(colIndex,rowIndex);
+					if (image.getAnchorName() != null)
+					{
+						String ref = "'" + JRStringUtil.xmlEncode(currentSheetName) + "'!$" + JRXlsAbstractExporter.getColumIndexName(colIndex, maxColumnIndex) + "$" + (rowIndex + 1);
+						definedNames.append("<definedName name=\"" + getDefinedName(image.getAnchorName()) +"\">"+ ref +"</definedName>\n");
+					}
 				}
-			}
 
-//			boolean startedHyperlink = startHyperlink(image,false);
+//				boolean startedHyperlink = startHyperlink(image,false);
 
-			String imageName = getImagePath(renderer, image.isLazy(), gridCell);
-			drawingRelsHelper.exportImage(imageName);
+				drawingRelsHelper.exportImage(imageProcessorResult.imagePath);
 
-			sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
+				sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
 
-			ImageAnchorTypeEnum imageAnchorType = 
-				ImageAnchorTypeEnum.getByName(
-					JRPropertiesUtil.getOwnProperty(image, XlsReportConfiguration.PROPERTY_IMAGE_ANCHOR_TYPE)
-					);
-			if (imageAnchorType == null)
-			{
-				imageAnchorType = configuration.getImageAnchorType();
+				ImageAnchorTypeEnum imageAnchorType = 
+					ImageAnchorTypeEnum.getByName(
+						JRPropertiesUtil.getOwnProperty(image, XlsReportConfiguration.PROPERTY_IMAGE_ANCHOR_TYPE)
+						);
 				if (imageAnchorType == null)
 				{
-					imageAnchorType = ImageAnchorTypeEnum.MOVE_NO_SIZE;
+					imageAnchorType = configuration.getImageAnchorType();
+					if (imageAnchorType == null)
+					{
+						imageAnchorType = ImageAnchorTypeEnum.MOVE_NO_SIZE;
+					}
 				}
-			}
-			drawingHelper.write("<xdr:twoCellAnchor editAs=\"" + getAnchorType(imageAnchorType) + "\">\n");
-			drawingHelper.write("<xdr:from><xdr:col>" +
-				colIndex +
-				"</xdr:col><xdr:colOff>" +
-				LengthUtil.emu(leftPadding) +
-				"</xdr:colOff><xdr:row>" +
-				rowIndex +
-				"</xdr:row><xdr:rowOff>" +
-				LengthUtil.emu(topPadding) +
-				"</xdr:rowOff></xdr:from>\n");
-			drawingHelper.write("<xdr:to><xdr:col>" +
-				(colIndex + gridCell.getColSpan()) +
-				"</xdr:col><xdr:colOff>" +
-				LengthUtil.emu(-rightPadding) +
-				"</xdr:colOff><xdr:row>" +
-				(rowIndex + (configuration.isCollapseRowSpan() ? 1 : gridCell.getRowSpan())) +
-				"</xdr:row><xdr:rowOff>" +
-				LengthUtil.emu(-bottomPadding) +
-				"</xdr:rowOff></xdr:to>\n");
-			
-			drawingHelper.write("<xdr:pic>\n");
-			drawingHelper.write("<xdr:nvPicPr><xdr:cNvPr id=\"" + (image.hashCode() > 0 ? image.hashCode() : -image.hashCode()) + "\" name=\"Picture\">\n");
+				drawingHelper.write("<xdr:twoCellAnchor editAs=\"" + getAnchorType(imageAnchorType) + "\">\n");
+				drawingHelper.write("<xdr:from><xdr:col>" +
+					colIndex +
+					"</xdr:col><xdr:colOff>" +
+					LengthUtil.emu(leftPadding) +
+					"</xdr:colOff><xdr:row>" +
+					rowIndex +
+					"</xdr:row><xdr:rowOff>" +
+					LengthUtil.emu(topPadding) +
+					"</xdr:rowOff></xdr:from>\n");
+				drawingHelper.write("<xdr:to><xdr:col>" +
+					(colIndex + gridCell.getColSpan()) +
+					"</xdr:col><xdr:colOff>" +
+					LengthUtil.emu(-rightPadding) +
+					"</xdr:colOff><xdr:row>" +
+					(rowIndex + (configuration.isCollapseRowSpan() ? 1 : gridCell.getRowSpan())) +
+					"</xdr:row><xdr:rowOff>" +
+					LengthUtil.emu(-bottomPadding) +
+					"</xdr:rowOff></xdr:to>\n");
+				
+				drawingHelper.write("<xdr:pic>\n");
+				drawingHelper.write("<xdr:nvPicPr><xdr:cNvPr id=\"" + (image.hashCode() > 0 ? image.hashCode() : -image.hashCode()) + "\" name=\"Picture\">\n");
 
-			String href = HyperlinkTypeEnum.LOCAL_ANCHOR.equals(image.getHyperlinkTypeValue()) || HyperlinkTypeEnum.LOCAL_PAGE.equals(image.getHyperlinkTypeValue()) ? "#" + getHyperlinkURL(image) : getHyperlinkURL(image);
-			if (href != null)
-			{
-				drawingHelper.exportHyperlink(href);
-			}
-			
-			drawingHelper.write("</xdr:cNvPr><xdr:cNvPicPr/></xdr:nvPicPr>\n");
-			drawingHelper.write("<xdr:blipFill>\n");
-			drawingHelper.write("<a:blip r:embed=\"" + imageName + "\"/>");
-			drawingHelper.write("<a:srcRect");
-////			if (cropLeft > 0)
-//				drawingHelper.write(" l=\"" + (int)cropLeft + "\"");
-////			if (cropTop > 0)
-//				drawingHelper.write(" t=\"" + (int)cropTop + "\"");
-////			if (cropRight > 0)
-//				drawingHelper.write(" r=\"" + (int)cropRight + "\"");
-////			if (cropBottom > 0)
-//				drawingHelper.write(" b=\"" + (int)cropBottom + "\"");
-			drawingHelper.write("/>");
-			drawingHelper.write("<a:stretch><a:fillRect");
-//			if (cropLeft > 0)
-				drawingHelper.write(" l=\"" + (int)cropLeft + "\"");
-//			if (cropTop > 0)
-				drawingHelper.write(" t=\"" + (int)cropTop + "\"");
-//			if (cropRight > 0)
-				drawingHelper.write(" r=\"" + (int)cropRight + "\"");
-//			if (cropBottom > 0)
-				drawingHelper.write(" b=\"" + (int)cropBottom + "\"");
-			drawingHelper.write("/></a:stretch>\n");
-			drawingHelper.write("</xdr:blipFill>\n");
-			drawingHelper.write("<xdr:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + LengthUtil.emu(0) + "\" cy=\"" + LengthUtil.emu(0) + "\"/>");
-			drawingHelper.write("</a:xfrm><a:prstGeom prst=\"rect\"></a:prstGeom>\n");
-//			if (image.getModeValue() == ModeEnum.OPAQUE && image.getBackcolor() != null)
-//			{
-//				drawingHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getBackcolor()) + "\"/></a:solidFill>\n");
-//			}
-			drawingHelper.write("</xdr:spPr>\n");
-			drawingHelper.write("</xdr:pic>\n");
-			drawingHelper.write("<xdr:clientData/>\n");
-			drawingHelper.write("</xdr:twoCellAnchor>\n");
+				String href = HyperlinkTypeEnum.LOCAL_ANCHOR.equals(image.getHyperlinkTypeValue()) || HyperlinkTypeEnum.LOCAL_PAGE.equals(image.getHyperlinkTypeValue()) ? "#" + getHyperlinkURL(image) : getHyperlinkURL(image);
+				if (href != null)
+				{
+					drawingHelper.exportHyperlink(href);
+				}
+				
+				drawingHelper.write("</xdr:cNvPr><xdr:cNvPicPr/></xdr:nvPicPr>\n");
+				drawingHelper.write("<xdr:blipFill>\n");
+				drawingHelper.write("<a:blip r:embed=\"" + imageProcessorResult.imagePath + "\"/>");
+				drawingHelper.write("<a:srcRect");
+////				if (cropLeft > 0)
+//					drawingHelper.write(" l=\"" + (int)cropLeft + "\"");
+////				if (cropTop > 0)
+//					drawingHelper.write(" t=\"" + (int)cropTop + "\"");
+////				if (cropRight > 0)
+//					drawingHelper.write(" r=\"" + (int)cropRight + "\"");
+////				if (cropBottom > 0)
+//					drawingHelper.write(" b=\"" + (int)cropBottom + "\"");
+				drawingHelper.write("/>");
+				drawingHelper.write("<a:stretch><a:fillRect");
+//				if (cropLeft > 0)
+					drawingHelper.write(" l=\"" + (int)cropLeft + "\"");
+//				if (cropTop > 0)
+					drawingHelper.write(" t=\"" + (int)cropTop + "\"");
+//				if (cropRight > 0)
+					drawingHelper.write(" r=\"" + (int)cropRight + "\"");
+//				if (cropBottom > 0)
+					drawingHelper.write(" b=\"" + (int)cropBottom + "\"");
+				drawingHelper.write("/></a:stretch>\n");
+				drawingHelper.write("</xdr:blipFill>\n");
+				drawingHelper.write("<xdr:spPr><a:xfrm><a:off x=\"0\" y=\"0\"/><a:ext cx=\"" + LengthUtil.emu(0) + "\" cy=\"" + LengthUtil.emu(0) + "\"/>");
+				drawingHelper.write("</a:xfrm><a:prstGeom prst=\"rect\"></a:prstGeom>\n");
+//				if (image.getModeValue() == ModeEnum.OPAQUE && image.getBackcolor() != null)
+//				{
+//					drawingHelper.write("<a:solidFill><a:srgbClr val=\"" + JRColorUtil.getColorHexa(image.getBackcolor()) + "\"/></a:solidFill>\n");
+//				}
+				drawingHelper.write("</xdr:spPr>\n");
+				drawingHelper.write("</xdr:pic>\n");
+				drawingHelper.write("<xdr:clientData/>\n");
+				drawingHelper.write("</xdr:twoCellAnchor>\n");
 
-//			if(startedHyperlink)
-//			{
-//				endHyperlink(false);
-//			}
+//				if(startedHyperlink)
+//				{
+//					endHyperlink(false);
+//				}
+			}
 		}
 
 //		drawingHelper.write("</w:p>");
@@ -1295,6 +1191,114 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	private class InternalImageProcessor
+	{
+		private final JRPrintElement imageElement;
+		private final boolean needDimension; 
+		private final JRExporterGridCell cell;
+		private final int availableImageWidth;
+		private final int availableImageHeight;
+
+		protected InternalImageProcessor(
+			JRPrintElement imageElement,
+			boolean needDimension, 
+			JRExporterGridCell cell,
+			int availableImageWidth,
+			int availableImageHeight
+			)
+		{
+			this.imageElement = imageElement;
+			this.needDimension = needDimension;
+			this.cell = cell;
+			this.availableImageWidth = availableImageWidth;
+			this.availableImageHeight = availableImageHeight;
+		}
+		
+		private InternalImageProcessorResult process(Renderable renderer) throws JRException
+		{
+			if (renderer instanceof ResourceRenderer)
+			{
+				renderer = renderersCache.getLoadedRenderer((ResourceRenderer)renderer);
+			}
+			
+			// check dimension first, to avoid caching renderers that might not be used eventually, due to their dimension errors 
+			Dimension2D dimension = null;
+			if (needDimension)
+			{
+				DimensionRenderable dimensionRenderer = renderersCache.getDimensionRenderable(renderer);
+				dimension = dimensionRenderer == null ? null :  dimensionRenderer.getDimension(jasperReportsContext);
+			}
+			
+			
+			String imagePath = null;
+
+//			if (image.isLazy()) //FIXMEXLSX learn how to link images
+//			{
+//				
+//			}
+//			else
+//			{
+				if (
+					renderer instanceof DataRenderable //we do not cache imagePath for non-data renderers because they render width different width/height each time
+					&& rendererToImagePathMap.containsKey(renderer.getId())
+					)
+				{
+					imagePath = rendererToImagePathMap.get(renderer.getId());
+				}
+				else
+				{
+					JRPrintElementIndex imageIndex = getElementIndex(cell);
+
+					DataRenderable imageRenderer = 
+						getRendererUtil().getImageDataRenderable(
+							renderersCache,
+							renderer,
+							new Dimension(availableImageWidth, availableImageHeight),
+							ModeEnum.OPAQUE == imageElement.getModeValue() ? imageElement.getBackcolor() : null
+							);
+
+					byte[] imageData = imageRenderer.getData(jasperReportsContext);
+					String fileExtension = JRTypeSniffer.getImageTypeValue(imageData).getFileExtension();
+					String imageName = IMAGE_NAME_PREFIX + imageIndex.toString() + (fileExtension == null ? "" : ("." + fileExtension));
+
+					xlsxZip.addEntry(//FIXMEDOCX optimize with a different implementation of entry
+						new FileBufferedZipEntry(
+							"xl/media/" + imageName,
+							imageData
+							)
+						);
+					
+//					drawingRelsHelper.exportImage(imageName);
+
+					imagePath = imageName;
+					//imagePath = "Pictures/" + imageName;
+	
+					if (imageRenderer == renderer)
+					{
+						//cache imagePath only for true ImageRenderable instances because the wrapping ones render with different width/height each time
+						rendererToImagePathMap.put(renderer.getId(), imagePath);
+					}
+				}
+//			}
+			
+			return new InternalImageProcessorResult(imagePath, dimension);
+		}
+	}
+
+	private class InternalImageProcessorResult
+	{
+		protected final String imagePath;
+		protected final Dimension2D dimension;
+		
+		protected InternalImageProcessorResult(String imagePath, Dimension2D dimension)
+		{
+			this.imagePath = imagePath;
+			this.dimension = dimension;
+		}
+	}
+
+
+	@Override
 	protected void exportLine(
 		JRPrintLine line, 
 		JRExporterGridCell gridCell,
@@ -1333,12 +1337,13 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 
 		gridCell.setBox(box);//CAUTION: only some exporters set the cell box
 		
-		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 		sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
 		cellHelper.exportFooter();
 	}
 
 
+	@Override
 	protected void exportRectangle(
 		JRPrintGraphicElement rectangle,
 		JRExporterGridCell gridCell, 
@@ -1354,12 +1359,13 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 
 		gridCell.setBox(box);//CAUTION: only some exporters set the cell box
 		
-		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(gridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 		sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
 		cellHelper.exportFooter();
 	}
 
 
+	@Override
 	public void exportText(
 		final JRPrintText text, 
 		JRExporterGridCell gridCell,
@@ -1391,16 +1397,19 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 			}
 		}
 		
+		final String convertedPattern = getConvertedPattern(text, pattern);
+				
 		cellHelper.exportHeader(
 			gridCell, rowIndex, colIndex, maxColumnIndex, textValue, 
-			getConvertedPattern(text, pattern), 
+			convertedPattern, 
 			getTextLocale(text), 
 			isWrapText(gridCell.getElement()) || Boolean.TRUE.equals(((JRXlsxExporterNature)nature).getColumnAutoFit(gridCell.getElement())), 
 			isCellHidden(gridCell.getElement()), 
 			isCellLocked(gridCell.getElement()),
 			isShrinkToFit(gridCell.getElement()), 
 			isIgnoreTextFormatting(text),
-			text.getRotationValue()
+			text.getRotationValue(),
+			sheetInfo
 			);
 		sheetHelper.exportMergedCells(rowIndex, colIndex, maxColumnIndex, gridCell.getRowSpan(), gridCell.getColSpan());
 
@@ -1430,7 +1439,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 			insertPageAnchor(colIndex,rowIndex);
 			if (text.getAnchorName() != null)
 			{
-				String ref = "'" + currentSheetName + "'!$" + JRXlsAbstractExporter.getColumIndexName(colIndex, maxColumnIndex) + "$" + (rowIndex + 1);
+				String ref = "'" + JRStringUtil.xmlEncode(currentSheetName) + "'!$" + JRXlsAbstractExporter.getColumIndexName(colIndex, maxColumnIndex) + "$" + (rowIndex + 1);
 				definedNames.append("<definedName name=\"" + getDefinedName(text.getAnchorName()) +"\">"+ ref +"</definedName>\n");
 			}
 		}
@@ -1450,10 +1459,12 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		TextValueHandler handler = 
 			new TextValueHandler() 
 			{
+				@Override
 				public void handle(BooleanTextValue textValue) throws JRException {
 					sheetHelper.write("<v>" + textValue.getValue() + "</v>");
 				}
 				
+				@Override
 				public void handle(DateTextValue textValue) throws JRException {
 					Date date = textValue.getValue();
 					sheetHelper.write(
@@ -1467,15 +1478,22 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 						);
 				}
 				
+				@Override
 				public void handle(NumberTextValue textValue) throws JRException {
-					Number number = textValue.getValue();
-					sheetHelper.write(
-						"<v>" 
-						+ (number == null ? "" : number) 
-						+ "</v>"
-						);
+					sheetHelper.write("<v>"); 
+					if (textValue.getValue() != null)
+					{
+						double doubleValue = textValue.getValue().doubleValue();
+						if (DefaultFormatFactory.STANDARD_NUMBER_FORMAT_DURATION.equals(convertedPattern))
+						{
+							doubleValue = doubleValue / 86400;
+						}
+						sheetHelper.write(String.valueOf(doubleValue));
+					}
+					sheetHelper.write("</v>");
 				}
 				
+				@Override
 				public void handle(StringTextValue textValue) throws JRException {
 					writeText();
 				}
@@ -1509,6 +1527,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	protected void exportGenericElement(
 		JRGenericPrintElement element, 
 		JRExporterGridCell gridCell, 
@@ -1538,13 +1557,13 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	protected void openWorkbook(OutputStream os) throws JRException 
 	{
 		rendererToImagePathMap = new HashMap<String,String>();
 //		imageMaps = new HashMap();
-		imagesToProcess = new ArrayList<JRPrintElementIndex>();
 //		hyperlinksMap = new HashMap();
-		definedNames = new StringBuffer();
+		definedNames = new StringBuilder();
 		try
 		{
 			String memoryThreshold = jasperPrint.getPropertiesMap().getProperty(FileBufferedOutputStream.PROPERTY_MEMORY_THRESHOLD);
@@ -1584,7 +1603,6 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 //		runHelper = new RunHelper(sheetWriter, fontMap, null);//FIXMEXLSX check this null
 	}
 
-
 	protected void setBackground() {
 		// TODO Auto-generated method stub
 		
@@ -1596,20 +1614,23 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 //	}
 
 
+	@Override
 	protected void addOccupiedCell(OccupiedGridCell occupiedGridCell, int colIndex, int rowIndex) 
 	{
 		ElementGridCell elementGridCell = (ElementGridCell)occupiedGridCell.getOccupier();
-		cellHelper.exportHeader(elementGridCell, rowIndex, colIndex, maxColumnIndex);
+		cellHelper.exportHeader(elementGridCell, rowIndex, colIndex, maxColumnIndex, sheetInfo);
 		cellHelper.exportFooter();
 	}
 
 
+	@Override
 	protected void setColumnWidth(int col, int width, boolean autoFit) 
 	{
 		sheetHelper.exportColumn(col, width, autoFit);
 	}
 
 
+	@Override
 	protected void setRowHeight(
 		int rowIndex, 
 		int rowHeight,
@@ -1621,32 +1642,39 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 	}
 
 
+	@Override
 	protected void addRowBreak(int rowIndex) 
 	{
 		sheetHelper.addRowBreak(rowIndex);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterKey()
 	{
 		return XLSX_EXPORTER_KEY;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getExporterPropertiesPrefix()
 	{
 		return XLSX_EXPORTER_PROPERTIES_PREFIX;
 	}
 	
-	protected void setFreezePane(int rowIndex, int colIndex, boolean isRowEdge, boolean isColumnEdge)
+	@Override
+	protected void setFreezePane(int rowIndex, int colIndex)
 	{
-		//TODO: set freeze pane for element-level defined indexes
+		//nothing to do here
 	}
 
+	/**
+	 * @deprecated to be removed; replaced by {@link #setFreezePane(int, int)}
+	 */ 
+	@Override
+	protected void setFreezePane(int rowIndex, int colIndex, boolean isRowEdge, boolean isColumnEdge) {
+		// nothing to do here
+	}
+
+	@Override
 	protected void setSheetName(String sheetName)
 	{
 		/* nothing to do here; it's done in createSheet() */
@@ -1658,6 +1686,7 @@ public class JRXlsxExporter extends JRXlsAbstractExporter<XlsxReportConfiguratio
 		sheetAutoFilter = autoFilterRange;
 	}
 	
+	@Override
 	protected void resetAutoFilters()
 	{
 		super.resetAutoFilters();
