@@ -23,7 +23,10 @@
  */
 package net.sf.jasperreports.engine.fill;
 
+import java.util.List;
+
 import net.sf.jasperreports.engine.JRException;
+import net.sf.jasperreports.engine.JRStyle;
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
@@ -41,4 +44,8 @@ public interface BandReportFillerParent extends FillerParent
 
 	void addPage(FillerPageAddedEvent pageAdded) throws JRException;
 
+	String getReportLocation();
+	
+	void registerReportStyles(List<JRStyle> styles);
+
 }
