@@ -33,6 +33,7 @@ import java.text.Format;
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
@@ -42,8 +43,12 @@ import java.util.Map;
 import java.util.ResourceBundle;
 import java.util.Set;
 import java.util.TimeZone;
+import java.util.UUID;
 import java.util.concurrent.ConcurrentHashMap;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.JRBand;
 import net.sf.jasperreports.engine.JRDefaultStyleProvider;
 import net.sf.jasperreports.engine.JRException;
@@ -76,9 +81,8 @@ import net.sf.jasperreports.engine.type.WhenNoDataTypeEnum;
 import net.sf.jasperreports.engine.type.WhenResourceMissingTypeEnum;
 import net.sf.jasperreports.engine.util.JRDataUtils;
 import net.sf.jasperreports.engine.util.JRStyledTextParser;
-
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
+import net.sf.jasperreports.engine.util.JRStyledTextUtil;
+import net.sf.jasperreports.engine.util.StyleResolver;
 
 
 /**
@@ -152,6 +156,8 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 	protected List<JRTemplate> templates;
 
 	protected JRStyle defaultStyle;
+	
+	protected StyleResolver styleResolver;
 
 	protected JRStyle[] styles;
 
@@ -224,6 +230,8 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 
 	protected boolean isLastPageFooter;
 
+	protected boolean isReorderBandElements;
+
 	/**
 	 *
 	 */
@@ -335,6 +343,14 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		return fillBand;
 	}
 
+	@Override
+	protected void setJasperReportsContext(JasperReportsContext jasperReportsContext)
+	{
+		super.setJasperReportsContext(jasperReportsContext);
+
+		this.styleResolver = new StyleResolver(jasperReportsContext);
+	}
+
 	/**
 	 * Returns the report fields indexed by name.
 	 *
@@ -452,6 +468,11 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 	{
 		return styledTextParser;
 	}
+	
+	protected JRStyledTextUtil getStyledTextUtil()
+	{
+		return fillContext.getStyledTextUtil();
+	}
 
 	/**
 	 * Returns the number of generated master print pages.
@@ -463,14 +484,18 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		return getMasterFiller().jasperPrint.getPages().size();
 	}
 	
-	/**
-	 *
-	 */
+	@Override
 	public JRStyle getDefaultStyle()
 	{
 		return defaultStyle;
 	}
 
+	@Override
+	public StyleResolver getStyleResolver()
+	{
+		return styleResolver;
+	}
+
 	protected boolean isSubreportRunToBottom()
 	{
 		return bandReportParent != null && bandReportParent.isRunToBottom();
@@ -638,6 +663,10 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		}
 
 		List<JRStyle> includedStyles = factory.setStyles(styleList);
+		if (bandReportParent != null)
+		{
+			bandReportParent.registerReportStyles(includedStyles);
+		}
 
 		styles = includedStyles.toArray(new JRStyle[includedStyles.size()]);
 
@@ -647,13 +676,31 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		}
 	}
 
+	public void registerReportStyles(UUID id, List<JRStyle> styles)
+	{
+		if (bandReportParent == null)
+		{
+			fillContext.registerReportStyles(jasperReport, id, styles);
+		}
+		else
+		{
+			String reportLocation = bandReportParent.getReportLocation();
+			if (reportLocation != null)
+			{
+				fillContext.registerReportStyles(reportLocation, id, styles);
+			}
+		}
+		
+	}
 
 	private static final JRStyleSetter DUMMY_STYLE_SETTER = new JRStyleSetter()
 	{
+		@Override
 		public void setStyle(JRStyle style)
 		{
 		}
 
+		@Override
 		public void setStyleNameReference(String name)
 		{
 		}
@@ -666,7 +713,7 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		JRStyle[] reportStyles = jasperReport.getStyles();
 		if (reportStyles != null)
 		{
-			styles = new JRStyle[reportStyles.length];
+			styles = new JRStyle[reportStyles.length];//FIXME remove this
 
 			for (int i = 0; i < reportStyles.length; i++)
 			{
@@ -806,6 +853,7 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		{
 			factory.registerDelayedStyleSetter(new JRStyleSetter()
 			{
+				@Override
 				public void setStyle(JRStyle style)
 				{
 					if (style.isDefault())
@@ -814,6 +862,7 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 					}
 				}
 
+				@Override
 				public void setStyleNameReference(String name)
 				{
 				}
@@ -1151,6 +1200,40 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 	}
 
 
+	/**
+	 *
+	 */
+	protected void fillBand(JRPrintBand band)
+	{
+		if (isReorderBandElements())
+		{
+			List<JRPrintElement> elements = new ArrayList<JRPrintElement>();
+			for(Iterator<JRPrintElement> it = band.iterateElements(); it.hasNext();)
+			{
+				JRPrintElement element = it.next();
+				element.setX(element.getX() + offsetX);
+				element.setY(element.getY() + offsetY);
+				elements.add(element);
+			}
+			Collections.sort(elements, new JRYXComparator());//FIXME make singleton comparator; same for older comparator
+			for (JRPrintElement element : elements)
+			{
+				printPage.addElement(element);
+			}
+		}
+		else
+		{
+			for(Iterator<JRPrintElement> it = band.iterateElements(); it.hasNext();)
+			{
+				JRPrintElement element = it.next();
+				element.setX(element.getX() + offsetX);
+				element.setY(element.getY() + offsetY);
+				printPage.addElement(element);
+			}
+		}
+	}
+
+
 	protected void addPage(JRPrintPage page)
 	{
 		if (!isSubreport())
@@ -1267,6 +1350,19 @@ public abstract class JRBaseFiller extends BaseReportFiller implements JRDefault
 		this.bandOverFlowAllowed = splittableBand;
 	}
 
+
+	protected boolean isReorderBandElements()
+	{
+		return isReorderBandElements;
+	}
+
+
+	protected void setReorderBandElements(boolean isReorderBandElements)
+	{
+		this.isReorderBandElements = isReorderBandElements;
+	}
+
+
 	protected int getMasterColumnCount()
 	{
 		FillerParent fillerParent = parent;
