@@ -41,6 +41,9 @@ import java.util.Set;
 import java.util.TreeMap;
 import java.util.concurrent.atomic.AtomicInteger;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.components.iconlabel.IconLabelComponent;
 import net.sf.jasperreports.components.iconlabel.IconLabelComponentUtil;
 import net.sf.jasperreports.components.table.fill.BuiltinExpressionEvaluatorFactory;
@@ -119,14 +122,10 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.SortOrderEnum;
 import net.sf.jasperreports.engine.util.ElementsVisitorUtils;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.JRValueStringUtils;
 import net.sf.jasperreports.engine.xml.JRXmlConstants;
 import net.sf.jasperreports.web.util.JacksonUtil;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 /**
  * Fill-time implementation of a {@link net.sf.jasperreports.crosstabs.JRCrosstab crosstab}.
  * 
@@ -296,12 +295,10 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return filler.getPropertiesUtil().getBooleanProperty(PROPERTY_IGNORE_WIDTH);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+		return getStyleResolver().getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	private void copyRowGroups(JRCrosstab crosstab, JRFillCrosstabObjectFactory factory)
@@ -446,6 +443,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 	}
 
+	@Override
 	public JRBaseFiller getFiller()
 	{
 		return filler;
@@ -519,9 +517,15 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 		
 		BucketOrderer orderer = createOrderer(group, groupIndex, comparator);
-		return new BucketDefinition(bucket.getValueClass(),
+		BucketDefinition bucketDefinition = new BucketDefinition(bucket.getValueClass(),
 				orderer, comparator, bucket.getOrder(), 
 				group.getTotalPositionValue());
+		
+		Boolean mergeHeaderCells = group.getMergeHeaderCells();
+		// by default the header cells are merged
+		bucketDefinition.setMergeHeaderCells(mergeHeaderCells == null || mergeHeaderCells);
+		
+		return bucketDefinition;
 	}
 
 	protected BucketOrderer createOrderer(JRCrosstabGroup group, int groupIndex, Comparator<Object> bucketComparator)
@@ -577,6 +581,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return crosstabEvaluator.evaluate(expression, JRExpression.EVALUATION_DEFAULT);
 	}
 	
+	@Override
 	protected void reset()
 	{
 		super.reset();
@@ -590,6 +595,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		printFrames = null;
 	}
 
+	@Override
 	protected void evaluate(byte evaluation) throws JRException
 	{
 		reset();
@@ -718,6 +724,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 	}
 
+	@Override
 	protected boolean prepare(int availableHeight, boolean isOverflow) throws JRException
 	{
 		super.prepare(availableHeight, isOverflow);
@@ -742,7 +749,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 			else
 			{
-				setStretchHeight(getHeight());
+				setPrepareHeight(getHeight());
 				setToPrint(false);
 
 				return false;
@@ -783,13 +790,13 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		boolean willOverflow = crosstabFiller.willOverflow();
 		if (willOverflow)
 		{
-			setStretchHeight(availableHeight - getRelativeY());
+			setPrepareHeight(availableHeight - getRelativeY());
 		}
 		else if (!printFrames.isEmpty())
 		{
 			JRTemplatePrintFrame lastFrame = printFrames.get(printFrames.size() - 1);
 			int usedHeight = lastFrame.getY() + lastFrame.getHeight();
-			setStretchHeight(usedHeight);
+			setPrepareHeight(usedHeight);
 		}
 		
 		return willOverflow;
@@ -1046,6 +1053,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return columnValues;
 	}
 	
+	@Override
 	protected JRPrintElement fill()
 	{
 		// don't return anything, see getPrintElements()
@@ -1057,6 +1065,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return (JRTemplateFrame) getElementTemplate();
 	}
 
+	@Override
 	protected JRTemplateElement createElementTemplate()
 	{
 		JRTemplateFrame template = new JRTemplateFrame(getElementOrigin(), 
@@ -1066,6 +1075,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return template;
 	}
 
+	@Override
 	protected void rewind()
 	{
 		crosstabFiller.initCrosstab();
@@ -1088,19 +1098,19 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 	}
 
+	@Override
 	protected void resolveElement(JRPrintElement element, byte evaluation)
 	{
 		// nothing
 	}
 
+	@Override
 	public void collectExpressions(JRExpressionCollector collector)
 	{
 		collector.collect(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void visit(JRVisitor visitor)
 	{
 		visitor.visitCrosstab(this);
@@ -1111,26 +1121,31 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 	}
 
+	@Override
 	public int getId()
 	{
 		return parentCrosstab.getId();
 	}
 
+	@Override
 	public JRCrosstabDataset getDataset()
 	{
 		return dataset;
 	}
 
+	@Override
 	public JRCrosstabRowGroup[] getRowGroups()
 	{
 		return rowGroups;
 	}
 
+	@Override
 	public JRCrosstabColumnGroup[] getColumnGroups()
 	{
 		return columnGroups;
 	}
 
+	@Override
 	public JRCrosstabMeasure[] getMeasures()
 	{
 		return measures;
@@ -1180,11 +1195,13 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			this.measureValues = new Object[measures.length];
 		}
 
+		@Override
 		protected void customInitialize()
 		{
 			initBucketingService();
 		}
 
+		@Override
 		protected void customEvaluate(JRCalculator calculator) throws JRExpressionEvalException
 		{
 			for (int i = 0; i < rowGroups.length; i++)
@@ -1203,6 +1220,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 		}
 
+		@Override
 		protected void customIncrement()
 		{
 			try
@@ -1219,10 +1237,12 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			}
 		}
 
+		@Override
 		public void collectExpressions(JRExpressionCollector collector)
 		{
 		}
 
+		@Override
 		public boolean isDataPreSorted()
 		{
 			return ((JRCrosstabDataset) parent).isDataPreSorted();
@@ -1549,15 +1569,15 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				}
 			}
 
-			//FIXME is this needed?  we do setStretchHeight in prepare()
+			//FIXME is this needed?  we do setPrepareHeight in prepare()
 			boolean fillEnded = lastRowIndex >= rowHeadersData[0].length && lastColumnIndex >= columnHeadersData[0].length;
 			if (fillEnded)
 			{
-				setStretchHeight(yOffset);
+				setPrepareHeight(yOffset);
 			}
 			else
 			{
-				setStretchHeight(availableHeight);
+				setPrepareHeight(availableHeight);
 			}
 
 			startRowIndex = lastRowIndex;
@@ -1889,6 +1909,7 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 			List<JRChild> cellElements = cell.getChildren();
 			BucketDefinition[] rowBuckets = bucketingService.getRowBuckets();
 			int[] headerTextIndices = new int[rowBuckets.length];
+			Arrays.fill(headerTextIndices, -1);
 			boolean[] alignedText = new boolean[rowBuckets.length];
 			boolean foundHeader = false;
 			for (int bucketIdx = 0, bucketXOffset = 0; bucketIdx < rowBuckets.length; 
@@ -1907,7 +1928,6 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 				BucketDefinition rowBucket = rowBuckets[bucketIdx];
 				if (bucketOrder(rowBucket) == BucketOrder.NONE && !aligned)
 				{
-					headerTextIndices[bucketIdx] = -1;
 					continue;
 				}
 				
@@ -2975,47 +2995,56 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		}
 	}
 
+	@Override
 	public int getColumnBreakOffset()
 	{
 		return parentCrosstab.getColumnBreakOffset();
 	}
 
+	@Override
 	public boolean isRepeatColumnHeaders()
 	{
 		return parentCrosstab.isRepeatColumnHeaders();
 	}
 
+	@Override
 	public boolean isRepeatRowHeaders()
 	{
 		return parentCrosstab.isRepeatRowHeaders();
 	}
 
+	@Override
 	public JRCrosstabCell[][] getCells()
 	{
 		return crossCells;
 	}
 
+	@Override
 	public JRCellContents getWhenNoDataCell()
 	{
 		return whenNoDataCell;
 	}
 
+	@Override
 	public JRCrosstabParameter[] getParameters()
 	{
 		return parameters;
 	}
 
+	@Override
 	public JRExpression getParametersMapExpression()
 	{
 		return parentCrosstab.getParametersMapExpression();
 	}
 
 	
+	@Override
 	public JRElement getElementByKey(String elementKey)
 	{
 		return JRBaseCrosstab.getElementByKey(this, elementKey);
 	}
 
+	@Override
 	public JRFillCloneable createClone(JRFillCloneFactory factory)
 	{
 		//not needed
@@ -3028,27 +3057,25 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		return parentCrosstab.getTitleCell();
 	}
 
+	@Override
 	public JRCellContents getHeaderCell()
 	{
 		return headerCell;
 	}
 
+	@Override
 	public JRVariable[] getVariables()
 	{
 		return variables;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public RunDirectionEnum getRunDirectionValue()
 	{
 		return parentCrosstab.getRunDirectionValue();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setRunDirection(RunDirectionEnum runDirection)
 	{
 		throw new UnsupportedOperationException();
@@ -3066,31 +3093,37 @@ public class JRFillCrosstab extends JRFillElement implements JRCrosstab, JROrigi
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public JROrigin getOrigin()
 	{
 		return getElementOrigin();
 	}
 
+	@Override
 	public Boolean getIgnoreWidth()
 	{
 		return parentCrosstab.getIgnoreWidth();
 	}
 
+	@Override
 	public void setIgnoreWidth(Boolean ignoreWidth)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public void setIgnoreWidth(boolean ignoreWidth)
 	{
 		throw new UnsupportedOperationException();
 	}
 
+	@Override
 	public Color getDefaultLineColor()
 	{
 		return parentCrosstab.getDefaultLineColor();
 	}
 
+	@Override
 	public JRLineBox getLineBox()
 	{
 		return lineBox;
