@@ -35,14 +35,11 @@ import net.sf.jasperreports.engine.JRExpressionCollector;
 import net.sf.jasperreports.engine.JRGroup;
 import net.sf.jasperreports.engine.JRHyperlinkParameter;
 import net.sf.jasperreports.engine.JRImage;
-import net.sf.jasperreports.engine.JRImageRenderer;
 import net.sf.jasperreports.engine.JRLineBox;
 import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRPrintHyperlinkParameters;
 import net.sf.jasperreports.engine.JRPrintImage;
 import net.sf.jasperreports.engine.JRVisitor;
-import net.sf.jasperreports.engine.Renderable;
-import net.sf.jasperreports.engine.RenderableUtil;
 import net.sf.jasperreports.engine.type.EvaluationTimeEnum;
 import net.sf.jasperreports.engine.type.HorizontalImageAlignEnum;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
@@ -50,7 +47,12 @@ import net.sf.jasperreports.engine.type.ModeEnum;
 import net.sf.jasperreports.engine.type.OnErrorTypeEnum;
 import net.sf.jasperreports.engine.type.ScaleImageEnum;
 import net.sf.jasperreports.engine.type.VerticalImageAlignEnum;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
+import net.sf.jasperreports.engine.util.Pair;
+import net.sf.jasperreports.engine.util.StyleUtil;
+import net.sf.jasperreports.renderers.DimensionRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.ResourceRenderer;
+import net.sf.jasperreports.renderers.util.RendererUtil;
 
 
 /**
@@ -113,9 +115,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected void evaluateStyle(
 		byte evaluation
 		) throws JRException
@@ -127,35 +127,30 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		if (providerStyle != null)
 		{
 			lineBox = initLineBox.clone(this);
-			JRStyleResolver.appendBox(lineBox, providerStyle.getLineBox());
+			StyleUtil.appendBox(lineBox, providerStyle.getLineBox());
 		}
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+		return getStyleResolver().getMode(this, ModeEnum.TRANSPARENT);
 	}
 
-	/**
-	 * 
-	 */
+	@Override
 	public ScaleImageEnum getScaleImageValue()
 	{
-		return JRStyleResolver.getScaleImageValue(this);
+		return getStyleResolver().getScaleImageValue(this);
 	}
 		
+	@Override
 	public ScaleImageEnum getOwnScaleImageValue()
 	{
 		return providerStyle == null || providerStyle.getOwnScaleImageValue() == null ? ((JRImage)this.parent).getOwnScaleImageValue() : providerStyle.getOwnScaleImageValue();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setScaleImage(ScaleImageEnum scaleImage)
 	{
 		throw new UnsupportedOperationException();
@@ -164,6 +159,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getHorizontalImageAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.HorizontalAlignEnum getHorizontalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalAlignEnum(getHorizontalImageAlign());
@@ -172,6 +168,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getOwnHorizontalImageAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.HorizontalAlignEnum getOwnHorizontalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalAlignEnum(getOwnHorizontalImageAlign());
@@ -180,6 +177,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #setHorizontalImageAlign(HorizontalImageAlignEnum)}.
 	 */
+	@Override
 	public void setHorizontalAlignment(net.sf.jasperreports.engine.type.HorizontalAlignEnum horizontalAlignmentValue)
 	{
 		setHorizontalImageAlign(net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalImageAlignEnum(horizontalAlignmentValue));
@@ -188,6 +186,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getVerticalImageAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.VerticalAlignEnum getVerticalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalAlignEnum(getVerticalImageAlign());
@@ -196,6 +195,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getOwnVerticalImageAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.VerticalAlignEnum getOwnVerticalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalAlignEnum(getOwnVerticalImageAlign());
@@ -204,48 +204,43 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #setVerticalImageAlign(VerticalImageAlignEnum)}.
 	 */
+	@Override
 	public void setVerticalAlignment(net.sf.jasperreports.engine.type.VerticalAlignEnum verticalAlignmentValue)
 	{
 		setVerticalImageAlign(net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalImageAlignEnum(verticalAlignmentValue));
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public HorizontalImageAlignEnum getHorizontalImageAlign()
 	{
-		return JRStyleResolver.getHorizontalImageAlign(this);
+		return getStyleResolver().getHorizontalImageAlign(this);
 	}
 		
+	@Override
 	public HorizontalImageAlignEnum getOwnHorizontalImageAlign()
 	{
 		return providerStyle == null || providerStyle.getOwnHorizontalImageAlign() == null ? ((JRImage)this.parent).getOwnHorizontalImageAlign() : providerStyle.getOwnHorizontalImageAlign();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setHorizontalImageAlign(HorizontalImageAlignEnum horizontalAlignment)
 	{
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public VerticalImageAlignEnum getVerticalImageAlign()
 	{
-		return JRStyleResolver.getVerticalImageAlign(this);
+		return getStyleResolver().getVerticalImageAlign(this);
 	}
 		
+	@Override
 	public VerticalImageAlignEnum getOwnVerticalImageAlign()
 	{
 		return providerStyle == null || providerStyle.getOwnVerticalImageAlign() == null ? ((JRImage)this.parent).getOwnVerticalImageAlign() : providerStyle.getOwnVerticalImageAlign();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setVerticalImageAlign(VerticalImageAlignEnum verticalAlignment)
 	{
 		throw new UnsupportedOperationException();
@@ -254,6 +249,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
+	@Override
 	public boolean isUsingCache()
 	{
 		return ((JRImage)this.parent).isUsingCache();
@@ -262,83 +258,64 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	/**
 	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
+	@Override
 	public Boolean isOwnUsingCache()
 	{
 		return ((JRImage)this.parent).isOwnUsingCache();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public Boolean getUsingCache()
 	{
 		return ((JRImage)this.parent).getUsingCache();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public void setUsingCache(boolean isUsingCache)
 	{
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public void setUsingCache(Boolean isUsingCache)
 	{
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public boolean isLazy()
 	{
 		return ((JRImage)this.parent).isLazy();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public void setLazy(boolean isLazy)
 	{
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public OnErrorTypeEnum getOnErrorTypeValue()
 	{
 		return ((JRImage)this.parent).getOnErrorTypeValue();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public void setOnErrorType(OnErrorTypeEnum onErrorType)
 	{
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public EvaluationTimeEnum getEvaluationTimeValue()
 	{
 		return ((JRImage)this.parent).getEvaluationTimeValue();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public JRGroup getEvaluationGroup()
 	{
 		return this.evaluationGroup;
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public JRLineBox getLineBox()
 	{
 		return lineBox == null ? initLineBox : lineBox;
@@ -352,73 +329,55 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return getHyperlinkTypeValue().getValue();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public HyperlinkTypeEnum getHyperlinkTypeValue()
 	{
 		return ((JRImage)parent).getHyperlinkTypeValue();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public byte getHyperlinkTarget()
 	{
 		return ((JRImage)this.parent).getHyperlinkTarget();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public String getLinkTarget()
 	{
 		return ((JRImage)this.parent).getLinkTarget();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getExpression()
 	{
 		return ((JRImage)this.parent).getExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getAnchorNameExpression()
 	{
 		return ((JRImage)this.parent).getAnchorNameExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getHyperlinkReferenceExpression()
 	{
 		return ((JRImage)this.parent).getHyperlinkReferenceExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getHyperlinkWhenExpression()
 	{
 		return ((JRImage)this.parent).getHyperlinkWhenExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getHyperlinkAnchorExpression()
 	{
 		return ((JRImage)this.parent).getHyperlinkAnchorExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getHyperlinkPageExpression()
 	{
 		return ((JRImage)this.parent).getHyperlinkPageExpression();
@@ -480,6 +439,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return (JRTemplateImage) getElementTemplate();
 	}
 
+	@Override
 	protected JRTemplateElement createElementTemplate()
 	{
 		JRTemplateImage template = 
@@ -499,9 +459,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected void evaluate(
 		byte evaluation
 		) throws JRException
@@ -546,9 +504,15 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 				isUsingCache = source instanceof String;
 			}
 			
-			if (isUsingCache && filler.fillContext.hasLoadedImage(source))
+			Object srcKey = source;
+			if (source instanceof String)
 			{
-				newRenderer = filler.fillContext.getLoadedImage(source).getRenderable();
+				srcKey = new Pair<Boolean, String>(isLazy(), (String)source);
+			}
+
+			if (isUsingCache && filler.fillContext.hasLoadedRenderer(srcKey))
+			{
+				newRenderer = filler.fillContext.getLoadedRenderer(srcKey);
 			}
 			else
 			{
@@ -558,38 +522,37 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 					? (net.sf.jasperreports.engine.JRRenderable)source 
 					: null;
 
-				if (source instanceof Image)
+				if (source instanceof String)
+				{
+					String strSource = (String) source;
+					if (isLazy())
+					{
+						newRenderer = ResourceRenderer.getInstance(strSource, true);
+					}
+					else
+					{
+						newRenderer = RendererUtil.getInstance(filler.getJasperReportsContext()).getNonLazyRenderable(strSource, getOnErrorTypeValue());
+					}
+				}
+				else if (source instanceof Image)
 				{
 					Image img = (Image) source;
-					newRenderer = RenderableUtil.getInstance(filler.getJasperReportsContext()).getRenderable(img, getOnErrorTypeValue());
+					newRenderer = RendererUtil.getInstance(filler.getJasperReportsContext()).getRenderable(img, getOnErrorTypeValue());
 				}
 				else if (source instanceof InputStream)
 				{
 					InputStream is = (InputStream) source;
-					newRenderer = RenderableUtil.getInstance(filler.getJasperReportsContext()).getRenderable(is, getOnErrorTypeValue());
+					newRenderer = RendererUtil.getInstance(filler.getJasperReportsContext()).getRenderable(is, getOnErrorTypeValue());
 				}
 				else if (source instanceof URL)
 				{
 					URL url = (URL) source;
-					newRenderer = RenderableUtil.getInstance(filler.getJasperReportsContext()).getRenderable(url, getOnErrorTypeValue());
+					newRenderer = RendererUtil.getInstance(filler.getJasperReportsContext()).getRenderable(url, getOnErrorTypeValue());
 				}
 				else if (source instanceof File)
 				{
 					File file = (File) source;
-					newRenderer = RenderableUtil.getInstance(filler.getJasperReportsContext()).getRenderable(file, getOnErrorTypeValue());
-				}
-				else if (source instanceof String)
-				{
-					String location = (String) source;
-					newRenderer = 
-						RenderableUtil.getInstance(filler.getJasperReportsContext()).getRenderable(
-							location, 
-							getOnErrorTypeValue(), 
-							isLazy()//, 
-//							filler.reportClassLoader,
-//							filler.urlHandlerFactory,
-//							filler.fileResolver
-							);
+					newRenderer = RendererUtil.getInstance(filler.getJasperReportsContext()).getRenderable(file, getOnErrorTypeValue());
 				}
 				else if (source instanceof Renderable)
 				{
@@ -599,13 +562,13 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 				{
 					@SuppressWarnings("deprecation")
 					Renderable wrappingRenderable = 
-						RenderableUtil.getWrappingRenderable(deprecatedRenderable);
+						net.sf.jasperreports.engine.RenderableUtil.getWrappingRenderable(deprecatedRenderable);
 					newRenderer = wrappingRenderable;
 				}
 				else
 				{
 					newRenderer = 
-						JRImageRenderer.getOnErrorRenderer(
+						RendererUtil.getInstance(filler.getJasperReportsContext()).getOnErrorRenderer(
 							getOnErrorTypeValue(), 
 							new JRException(
 									EXCEPTION_MESSAGE_KEY_UNKNOWN_SOURCE_CLASS,  
@@ -616,10 +579,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 
 				if (isUsingCache)
 				{
-					JRPrintImage img = new JRTemplatePrintImage(getJRTemplateImage(), 
-							printElementOriginator);//doesn't actually need a printElementId
-					img.setRenderable(newRenderer);
-					filler.fillContext.registerLoadedImage(source, img);
+					filler.fillContext.registerLoadedRenderer(srcKey, newRenderer);
 				}
 			}
 		}
@@ -638,6 +598,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 	
 
+	@Override
 	protected boolean prepare(
 		int availableHeight,
 		boolean isOverflow
@@ -706,8 +667,10 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 					isToPrint = false;
 					willOverflow = true;
 				}
-				else if (!isLazy() && (getScaleImageValue() == ScaleImageEnum.REAL_HEIGHT
-						|| getScaleImageValue() == ScaleImageEnum.REAL_SIZE))
+				else if (
+					!isLazy() 
+					&& (getScaleImageValue() == ScaleImageEnum.REAL_HEIGHT || getScaleImageValue() == ScaleImageEnum.REAL_SIZE)
+					)
 				{
 					int padding = getLineBox().getBottomPadding().intValue() 
 							+ getLineBox().getTopPadding().intValue();
@@ -717,21 +680,73 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 										|| (!this.isAlreadyPrinted() && !this.isPrintRepeatedValues())));
 					boolean imageOverflowAllowed = 
 							filler.isBandOverFlowAllowed() && !reprinted && !hasOverflowed;
-					boolean fits = fitImage(availableHeight - getRelativeY() - padding, imageOverflowAllowed, 
-							getHorizontalImageAlign());
-					if (fits)
+
+					if (renderer == null)
 					{
-						if (imageHeight != null)
-						{
-							setStretchHeight(imageHeight.intValue() + padding);
-						}
+						// if renderer is null, it means the isRemoveLineWhenBlank was false further up; 
+						// no need to do anything here 
 					}
 					else
 					{
-						hasOverflowed = true;
-						isToPrint = false;
-						willOverflow = true;
-						setStretchHeight(availableHeight - getRelativeY() - padding);
+						// image fill does not normally produce non-lazy ResourceRenderer instances, 
+						// so we do not need to attempt load resource renderers from cache here, as we do in the catch below
+						
+						DimensionRenderable dimensionRenderer = filler.fillContext.getRenderersCache().getDimensionRenderable(renderer);
+						
+						if (dimensionRenderer != null)
+						{
+							try
+							{
+								dimensionRenderer.getDimension(filler.getJasperReportsContext());
+							}
+							catch (Exception e)
+							{
+								renderer = RendererUtil.getInstance(filler.getJasperReportsContext()).handleImageError(e, getOnErrorTypeValue());
+
+								if (renderer instanceof ResourceRenderer)
+								{
+									renderer = filler.fillContext.getRenderersCache().getLoadedRenderer((ResourceRenderer)renderer);
+								}
+
+								dimensionRenderer = filler.fillContext.getRenderersCache().getDimensionRenderable(renderer);
+							}
+							
+							if (dimensionRenderer == null) // OnErrorTypeEnum.BLANK can return null above
+							{
+								isToPrint = !isRemoveLineWhenBlank();
+							}
+							else
+							{
+								boolean fits = true; 
+
+								Dimension2D imageSize = dimensionRenderer.getDimension(filler.getJasperReportsContext()); 
+								if (imageSize != null)
+								{
+									fits = 
+										fitImage(
+											imageSize, 
+											availableHeight - getRelativeY() - padding, 
+											imageOverflowAllowed, 
+											getHorizontalImageAlign()
+											);
+								}
+
+								if (fits)
+								{
+									if (imageHeight != null)
+									{
+										setPrepareHeight(imageHeight.intValue() + padding);
+									}
+								}
+								else
+								{
+									hasOverflowed = true;
+									isToPrint = false;
+									willOverflow = true;
+									setPrepareHeight(availableHeight - getRelativeY() - padding);
+								}
+							}
+						}
 					}
 				}
 			}
@@ -779,6 +794,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return willOverflow;
 	}
 
+	@Override
 	protected void reset()
 	{
 		imageHeight = null;
@@ -788,28 +804,17 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		super.reset();
 	}
 
-	protected boolean fitImage(int availableHeight, boolean overflowAllowed,
-			HorizontalImageAlignEnum hAlign) throws JRException
+	protected boolean fitImage(
+		Dimension2D imageSize, 
+		int availableHeight, 
+		boolean overflowAllowed,
+		HorizontalImageAlignEnum hAlign
+		) throws JRException
 	{
 		imageHeight = null;
 		imageWidth = null;
 		imageX = null;
 		
-		Dimension2D imageSize = null;
-		try
-		{
-			imageSize = renderer == null ? null : renderer.getDimension(filler.getJasperReportsContext());
-		}
-		catch (Exception e)
-		{
-			//ignore exception here; will be raised again when rendering the image
-		}
-		
-		if (imageSize == null)
-		{
-			return true;
-		}
-		
 		int realHeight = (int) imageSize.getHeight();
 		int realWidth = (int) imageSize.getWidth();
 		boolean fitted;
@@ -865,9 +870,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		return fitted;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	protected JRPrintElement fill() throws JRException
 	{
 		EvaluationTimeEnum evaluationTime = this.getEvaluationTimeValue();
@@ -923,7 +926,7 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 			printImage.setWidth(imageWidth.intValue());
 		}
 		
-		printImage.setRenderable(getRenderable());
+		printImage.setRenderer(getRenderable());
 		printImage.setAnchorName(getAnchorName());
 		if (getHyperlinkWhenExpression() == null || hyperlinkWhen == Boolean.TRUE)
 		{
@@ -935,29 +938,31 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 		}
 		else
 		{
+			if (printImage instanceof JRTemplatePrintImage)//this is normally the case
+			{
+				((JRTemplatePrintImage) printImage).setHyperlinkOmitted(true);
+			}
+			
 			printImage.setHyperlinkReference(null);
 		}
 		transferProperties(printImage);
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void collectExpressions(JRExpressionCollector collector)
 	{
 		collector.collect(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void visit(JRVisitor visitor)
 	{
 		visitor.visitImage(this);
 	}
 
 	
+	@Override
 	protected void resolveElement(JRPrintElement element, byte evaluation) throws JRException
 	{
 		evaluateImage(evaluation);
@@ -966,10 +971,48 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 
 		if (getScaleImageValue() == ScaleImageEnum.REAL_SIZE)//to avoid get dimension and thus unnecessarily load the image
 		{
-			int padding = printImage.getLineBox().getBottomPadding().intValue() 
-			+ printImage.getLineBox().getTopPadding().intValue();
-			fitImage(getHeight() - padding, false, 
-					printImage.getHorizontalImageAlign());
+			// image fill does not normally produce non-lazy ResourceRenderer instances, 
+			// so we do not need to attempt load resource renderers from cache here, as we do in the catch below
+
+			DimensionRenderable dimensionRenderer = filler.fillContext.getRenderersCache().getDimensionRenderable(renderer);
+			
+			if (dimensionRenderer != null)
+			{
+				try
+				{
+					dimensionRenderer.getDimension(filler.getJasperReportsContext());
+				}
+				catch (Exception e)
+				{
+					renderer = RendererUtil.getInstance(filler.getJasperReportsContext()).handleImageError(e, getOnErrorTypeValue());
+
+					if (renderer instanceof ResourceRenderer)
+					{
+						renderer = filler.fillContext.getRenderersCache().getLoadedRenderer((ResourceRenderer)renderer);
+					}
+					
+					dimensionRenderer = filler.fillContext.getRenderersCache().getDimensionRenderable(renderer);
+				}
+				
+				if (dimensionRenderer != null) // OnErrorTypeEnum.BLANK can return null above
+				{
+					
+					Dimension2D imageSize = dimensionRenderer.getDimension(filler.getJasperReportsContext());
+					if (imageSize != null)
+					{
+						int padding = 
+							printImage.getLineBox().getBottomPadding().intValue() 
+							+ printImage.getLineBox().getTopPadding().intValue();
+							
+						fitImage(
+							imageSize,
+							getHeight() - padding, 
+							false, 
+							printImage.getHorizontalImageAlign()
+							);
+					}
+				}
+			}
 		}
 		
 		copy(printImage);
@@ -977,17 +1020,21 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 
+	@Override
 	public int getBookmarkLevel()
 	{
 		return ((JRImage)this.parent).getBookmarkLevel();
 	}
 
 
+	@Override
 	public JRFillCloneable createClone(JRFillCloneFactory factory)
 	{
 		return new JRFillImage(this, factory);
 	}
-	
+
+
+	@Override
 	protected void collectDelayedEvaluations()
 	{
 		super.collectDelayedEvaluations();
@@ -1001,18 +1048,21 @@ public class JRFillImage extends JRFillGraphicElement implements JRImage
 	}
 
 
+	@Override
 	public JRHyperlinkParameter[] getHyperlinkParameters()
 	{
 		return ((JRImage) parent).getHyperlinkParameters();
 	}
 
 
+	@Override
 	public String getLinkType()
 	{
 		return ((JRImage) parent).getLinkType();
 	}
 
 
+	@Override
 	public JRExpression getHyperlinkTooltipExpression()
 	{
 		return ((JRImage) parent).getHyperlinkTooltipExpression();
