@@ -35,6 +35,9 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.data.cache.DataCacheHandler;
 import net.sf.jasperreports.engine.CommonReturnValue;
 import net.sf.jasperreports.engine.JRDataSource;
@@ -50,6 +53,7 @@ import net.sf.jasperreports.engine.JRPropertiesUtil;
 import net.sf.jasperreports.engine.JRRewindableDataSource;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRScriptlet;
+import net.sf.jasperreports.engine.JRStyle;
 import net.sf.jasperreports.engine.JRSubreport;
 import net.sf.jasperreports.engine.JRSubreportParameter;
 import net.sf.jasperreports.engine.JRSubreportReturnValue;
@@ -68,12 +72,8 @@ import net.sf.jasperreports.engine.type.OverflowType;
 import net.sf.jasperreports.engine.type.SectionTypeEnum;
 import net.sf.jasperreports.engine.util.JRLoader;
 import net.sf.jasperreports.engine.util.JRSingletonCache;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.repo.RepositoryUtil;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
@@ -197,17 +197,16 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+		return getStyleResolver().getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
 	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
+	@Override
 	public boolean isUsingCache()
 	{
 		return ((JRSubreport)parent).isUsingCache();
@@ -226,11 +225,13 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		return isUsingCache.booleanValue();
 	}
 		
+	@Override
 	public Boolean isRunToBottom()
 	{
 		return ((JRSubreport) parent).isRunToBottom();
 	}
 
+	@Override
 	public void setRunToBottom(Boolean runToBottom)
 	{
 		throw new UnsupportedOperationException();
@@ -248,41 +249,31 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getParametersMapExpression()
 	{
 		return ((JRSubreport)parent).getParametersMapExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRSubreportParameter[] getParameters()
 	{
 		return parameters;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getConnectionExpression()
 	{
 		return ((JRSubreport)parent).getConnectionExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getDataSourceExpression()
 	{
 		return ((JRSubreport)parent).getDataSourceExpression();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRExpression getExpression()
 	{
 		return ((JRSubreport)parent).getExpression();
@@ -297,6 +288,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
+	@Override
 	protected JRTemplateElement createElementTemplate()
 	{
 		return new JRTemplateRectangle(getElementOrigin(), 
@@ -335,9 +327,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected void evaluate(
 		byte evaluation
 		) throws JRException
@@ -524,6 +514,12 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
+	protected boolean isReorderBandElements()
+	{
+		return false;
+	}
+
+	
 	protected void initSubreportFiller(DatasetExpressionEvaluator evaluator) throws JRException
 	{
 		if (log.isDebugEnabled())
@@ -558,6 +554,8 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			}
 		}
 		
+		subreportFiller.setReorderBandElements(isReorderBandElements());
+
 		runner = getRunnerFactory().createSubreportRunner(this, subreportFiller);
 		subFillerParent.setSubreportRunner(runner);
 		
@@ -744,9 +742,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 	
 
-	/**
-	 *
-	 */
+	@Override
 	protected boolean prepare(
 		int availableHeight,
 		boolean isOverflow
@@ -855,7 +851,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			else
 			{
 				printPage = null;
-				setStretchHeight(getHeight());
+				setPrepareHeight(getHeight());
 				setToPrint(false);
 
 				return willOverflow;
@@ -896,7 +892,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 			}
 
 			printPage = subreportFiller.getCurrentPage();
-			setStretchHeight(result.hasFinished() ? subFillerParent.getCurrentPageStretchHeight() : pageHeight);
+			setPrepareHeight(result.hasFinished() ? subFillerParent.getCurrentPageStretchHeight() : pageHeight);
 
 			//if the subreport fill thread has not finished, 
 			// it means that the subreport will overflow on the next page
@@ -922,9 +918,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void rewind() throws JRException
 	{
 		if (subreportFiller == null)
@@ -977,9 +971,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected JRPrintElement fill()
 	{
 		//FIXME lucianc create a frame instead to avoid HTML layers
@@ -1024,23 +1016,20 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void collectExpressions(JRExpressionCollector collector)
 	{
 		collector.collect(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void visit(JRVisitor visitor)
 	{
 		visitor.visitSubreport(this);
 	}
 	
 
+	@Override
 	public JRSubreportReturnValue[] getReturnValues()
 	{
 		return ((JRSubreport) parent).getReturnValues();
@@ -1108,6 +1097,7 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	}
 	
 	
+	@Override
 	protected void resolveElement (JRPrintElement element, byte evaluation)
 	{
 		// nothing
@@ -1117,23 +1107,27 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	/**
 	 * @deprecated Replaced by {@link #getUsingCache()}.
 	 */
+	@Override
 	public Boolean isOwnUsingCache()
 	{
 		return ((JRSubreport)parent).isOwnUsingCache();
 	}
 
 
+	@Override
 	public Boolean getUsingCache()
 	{
 		return ((JRSubreport)parent).getUsingCache();
 	}
 
 
+	@Override
 	public void setUsingCache(Boolean isUsingCache)
 	{
 	}
 
 
+	@Override
 	public JRFillCloneable createClone(JRFillCloneFactory factory)
 	{
 		return new JRFillSubreport(this, factory);
@@ -1157,4 +1151,14 @@ public class JRFillSubreport extends JRFillElement implements JRSubreport
 	{
 		return subFillerParent.getCurrentPageStretchHeight();
 	}
+
+	protected String getReportLocation()
+	{
+		return source instanceof String ? (String) source : null;
+	}
+
+	protected void registerReportStyles(List<JRStyle> styles)
+	{
+		//NOP
+	}
 }
