@@ -48,11 +48,11 @@ import net.sf.jasperreports.engine.type.RunDirectionEnum;
 import net.sf.jasperreports.engine.type.VerticalTextAlignEnum;
 import net.sf.jasperreports.engine.util.JRSingletonCache;
 import net.sf.jasperreports.engine.util.JRStringUtil;
-import net.sf.jasperreports.engine.util.JRStyleResolver;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.JRTextMeasurerUtil;
 import net.sf.jasperreports.engine.util.MarkupProcessor;
 import net.sf.jasperreports.engine.util.MarkupProcessorFactory;
+import net.sf.jasperreports.engine.util.StyleUtil;
 
 
 /**
@@ -89,6 +89,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	private String textTruncateSuffix;
 	private String rawText;
 	private JRStyledText styledText;
+	private JRStyledText processedStyledText;
 	private Map<JRStyle,Map<Attribute,Object>> styledTextAttributesMap = new HashMap<JRStyle,Map<Attribute,Object>>();
 	
 	protected final JRLineBox initLineBox;
@@ -160,9 +161,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected void evaluateStyle(
 		byte evaluation
 		) throws JRException
@@ -180,8 +179,8 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		{
 			lineBox = initLineBox.clone(this);
 			paragraph = initParagraph.clone(this);
-			JRStyleResolver.appendBox(lineBox, providerStyle.getLineBox());
-			JRStyleResolver.appendParagraph(paragraph, providerStyle.getParagraph());
+			StyleUtil.appendBox(lineBox, providerStyle.getLineBox());
+			StyleUtil.appendParagraph(paragraph, providerStyle.getParagraph());
 			
 			fillStyleObjects = null;
 		}
@@ -214,17 +213,16 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public ModeEnum getModeValue()
 	{
-		return JRStyleResolver.getMode(this, ModeEnum.TRANSPARENT);
+		return getStyleResolver().getMode(this, ModeEnum.TRANSPARENT);
 	}
 
 	/**
 	 * @deprecated Replaced by {@link #getHorizontalTextAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.HorizontalAlignEnum getHorizontalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalAlignEnum(getHorizontalTextAlign());
@@ -233,6 +231,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #getOwnHorizontalTextAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.HorizontalAlignEnum getOwnHorizontalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalAlignEnum(getOwnHorizontalTextAlign());
@@ -241,6 +240,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #setHorizontalTextAlign(HorizontalTextAlignEnum)}.
 	 */
+	@Override
 	public void setHorizontalAlignment(net.sf.jasperreports.engine.type.HorizontalAlignEnum horizontalAlignmentValue)
 	{
 		setHorizontalTextAlign(net.sf.jasperreports.engine.type.HorizontalAlignEnum.getHorizontalTextAlignEnum(horizontalAlignmentValue));
@@ -249,6 +249,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #getVerticalTextAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.VerticalAlignEnum getVerticalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalAlignEnum(getVerticalTextAlign());
@@ -257,6 +258,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #getOwnVerticalTextAlign()}.
 	 */
+	@Override
 	public net.sf.jasperreports.engine.type.VerticalAlignEnum getOwnVerticalAlignmentValue()
 	{
 		return net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalAlignEnum(getOwnVerticalTextAlign());
@@ -265,69 +267,61 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #setVerticalTextAlign(VerticalTextAlignEnum)}.
 	 */
+	@Override
 	public void setVerticalAlignment(net.sf.jasperreports.engine.type.VerticalAlignEnum verticalAlignmentValue)
 	{
 		setVerticalTextAlign(net.sf.jasperreports.engine.type.VerticalAlignEnum.getVerticalTextAlignEnum(verticalAlignmentValue));
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public HorizontalTextAlignEnum getHorizontalTextAlign()
 	{
-		return JRStyleResolver.getHorizontalTextAlign(this);
+		return getStyleResolver().getHorizontalTextAlign(this);
 	}
 		
+	@Override
 	public HorizontalTextAlignEnum getOwnHorizontalTextAlign()
 	{
 		return providerStyle == null || providerStyle.getOwnHorizontalTextAlign() == null ? ((JRTextElement)this.parent).getOwnHorizontalTextAlign() : providerStyle.getOwnHorizontalTextAlign();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setHorizontalTextAlign(HorizontalTextAlignEnum horizontalAlignment)
 	{
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public VerticalTextAlignEnum getVerticalTextAlign()
 	{
-		return JRStyleResolver.getVerticalTextAlign(this);
+		return getStyleResolver().getVerticalTextAlign(this);
 	}
 		
+	@Override
 	public VerticalTextAlignEnum getOwnVerticalTextAlign()
 	{
 		return providerStyle == null || providerStyle.getOwnVerticalTextAlign() == null ? ((JRTextElement)this.parent).getOwnVerticalTextAlign() : providerStyle.getOwnVerticalTextAlign();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setVerticalTextAlign(VerticalTextAlignEnum verticalAlignment)
 	{
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public RotationEnum getRotationValue()
 	{
-		return JRStyleResolver.getRotationValue(this);
+		return getStyleResolver().getRotationValue(this);
 	}
 		
+	@Override
 	public RotationEnum getOwnRotationValue()
 	{
 		return providerStyle == null || providerStyle.getOwnRotationValue() == null ? ((JRTextElement)this.parent).getOwnRotationValue() : providerStyle.getOwnRotationValue();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setRotation(RotationEnum rotation)
 	{
 		throw new UnsupportedOperationException();
@@ -336,6 +330,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link JRParagraph#getLineSpacing()}.
 	 */
+	@Override
 	public LineSpacingEnum getLineSpacingValue()
 	{
 		return getParagraph().getLineSpacing();
@@ -344,6 +339,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link JRParagraph#getOwnLineSpacing()}.
 	 */
+	@Override
 	public LineSpacingEnum getOwnLineSpacingValue()
 	{
 		return getParagraph().getOwnLineSpacing();
@@ -352,30 +348,25 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link JRParagraph#setLineSpacing(LineSpacingEnum)}.
 	 */
+	@Override
 	public void setLineSpacing(LineSpacingEnum lineSpacing)
 	{
 		throw new UnsupportedOperationException();
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public String getMarkup()
 	{
-		return JRStyleResolver.getMarkup(this);
+		return getStyleResolver().getMarkup(this);
 	}
 		
-	/**
-	 *
-	 */
+	@Override
 	public String getOwnMarkup()
 	{
 		return providerStyle == null || providerStyle.getOwnMarkup() == null ? ((JRTextElement)parent).getOwnMarkup() : providerStyle.getOwnMarkup();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setMarkup(String markup)
 	{
 		throw new UnsupportedOperationException();
@@ -386,9 +377,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		return lineBox == null ? initLineBox : lineBox;
 	}
 	
-	/**
-	 *
-	 */
+	@Override
 	public JRLineBox getLineBox()
 	{
 		return lineBox == null 
@@ -401,9 +390,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		return paragraph == null ? initParagraph : paragraph;
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public JRParagraph getParagraph()
 	{
 		return paragraph == null 
@@ -581,12 +568,11 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	{
 		this.rawText = rawText;
 		styledText = null;
+		processedStyledText = null;
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void reset()
 	{
 		super.reset();
@@ -599,9 +585,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void rewind()
 	{
 		resetTextChunk();
@@ -626,10 +610,24 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 						filler.getLocale()
 						);
 			}
+			processedStyledText = null;
 		}
 		
 		return styledText;
 	}
+	
+	protected JRStyledText getProcessedStyledText()
+	{
+		if (processedStyledText == null)
+		{
+			JRStyledText text = getStyledText();
+			if (text != null)
+			{
+				processedStyledText = filler.getStyledTextUtil().resolveFonts(text, filler.getLocale());
+			}
+		}
+		return processedStyledText;
+	}
 
 	/**
 	 *
@@ -669,8 +667,9 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		}
 
 		boolean canOverflow = canOverflow();
+		JRStyledText processedText = getProcessedStyledText();
 		JRMeasuredText measuredText = textMeasurer.measure(
-			tmpStyledText,
+			processedText,
 			getTextEnd(),
 			availableStretchHeight,
 			canOverflow
@@ -689,14 +688,13 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 			boolean textEnded = measuredText.getTextOffset() >= tmpStyledText.getText().length();
 			if (textEnded || !canOverflow || !consumeSpaceOnOverflow)
 			{
-				setStretchHeight(elementTextHeight);
+				setPrepareHeight(elementTextHeight);
 			}
 			else
 			{
 				// occupy all remaining space so that no other element renders there
 				// but do not change the print element height
-				int stretchHeight = getHeight() + availableStretchHeight;
-				setStretchHeight(stretchHeight);
+				setPrepareHeight(getHeight() + availableStretchHeight);
 				
 				// store the difference between the consumed stretch height and the text stretch height.
 				// this will be used in fill() to set the print element height, 
@@ -707,7 +705,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 		}
 		else
 		{
-			setStretchHeight(getHeight());
+			setPrepareHeight(getHeight());
 		}
 		
 		setTextStart(getTextEnd());
@@ -726,50 +724,38 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	protected abstract boolean canOverflow();
 
 
-	/**
-	 *
-	 */
+	@Override
 	public String getFontName()
 	{
-		return JRStyleResolver.getFontName(this);
+		return getStyleResolver().getFontName(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getOwnFontName()
 	{
 		return providerStyle == null || providerStyle.getOwnFontName() == null ? ((JRFont)parent).getOwnFontName() : providerStyle.getOwnFontName();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setFontName(String fontName)
 	{
 		throw new UnsupportedOperationException();
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean isBold()
 	{
-		return JRStyleResolver.isBold(this);
+		return getStyleResolver().isBold(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Boolean isOwnBold()
 	{
 		return providerStyle == null || providerStyle.isOwnBold() == null ? ((JRFont)parent).isOwnBold() : providerStyle.isOwnBold();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setBold(boolean isBold)
 	{
 		throw new UnsupportedOperationException();
@@ -779,31 +765,26 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 * Alternative setBold method which allows also to reset
 	 * the "own" isBold property.
 	 */
+	@Override
 	public void setBold(Boolean isBold)
 	{
 		throw new UnsupportedOperationException();
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean isItalic()
 	{
-		return JRStyleResolver.isItalic(this);
+		return getStyleResolver().isItalic(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Boolean isOwnItalic()
 	{
 		return providerStyle == null || providerStyle.isOwnItalic() == null ? ((JRFont)parent).isOwnItalic() : providerStyle.isOwnItalic();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setItalic(boolean isItalic)
 	{
 		throw new UnsupportedOperationException();
@@ -813,30 +794,25 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 * Alternative setItalic method which allows also to reset
 	 * the "own" isItalic property.
 	 */
+	@Override
 	public void setItalic(Boolean isItalic)
 	{
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean isUnderline()
 	{
-		return JRStyleResolver.isUnderline(this);
+		return getStyleResolver().isUnderline(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Boolean isOwnUnderline()
 	{
 		return providerStyle == null || providerStyle.isOwnUnderline() == null ? ((JRFont)parent).isOwnUnderline() : providerStyle.isOwnUnderline();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setUnderline(boolean isUnderline)
 	{
 		throw new UnsupportedOperationException();
@@ -846,30 +822,25 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 * Alternative setUnderline method which allows also to reset
 	 * the "own" isUnderline property.
 	 */
+	@Override
 	public void setUnderline(Boolean isUnderline)
 	{
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean isStrikeThrough()
 	{
-		return JRStyleResolver.isStrikeThrough(this);
+		return getStyleResolver().isStrikeThrough(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Boolean isOwnStrikeThrough()
 	{
 		return providerStyle == null || providerStyle.isOwnStrikeThrough() == null ? ((JRFont)parent).isOwnStrikeThrough() : providerStyle.isOwnStrikeThrough();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setStrikeThrough(boolean isStrikeThrough)
 	{
 		throw new UnsupportedOperationException();
@@ -879,30 +850,25 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 * Alternative setStrikeThrough method which allows also to reset
 	 * the "own" isStrikeThrough property.
 	 */
+	@Override
 	public void setStrikeThrough(Boolean isStrikeThrough)
 	{
 		throw new UnsupportedOperationException();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public float getFontsize()
 	{
-		return JRStyleResolver.getFontsize(this);
+		return getStyleResolver().getFontsize(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Float getOwnFontsize()
 	{
 		return providerStyle == null || providerStyle.getOwnFontsize() == null ? ((JRFont)parent).getOwnFontsize() : providerStyle.getOwnFontsize();
 	}
 
-	/**
-	 * 
-	 */
+	@Override
 	public void setFontSize(Float size)
 	{
 		throw new UnsupportedOperationException();
@@ -911,6 +877,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #getFontsize()}.
 	 */
+	@Override
 	public int getFontSize()
 	{
 		return (int)getFontsize();
@@ -919,6 +886,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #getOwnFontsize()}.
 	 */
+	@Override
 	public Integer getOwnFontSize()
 	{
 		Float fontSize = getOwnFontsize();
@@ -928,6 +896,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #setFontSize(Float)}.
 	 */
+	@Override
 	public void setFontSize(int size)
 	{
 		setFontSize((float)size);
@@ -936,80 +905,63 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	/**
 	 * @deprecated Replaced by {@link #setFontSize(Float)}.
 	 */
+	@Override
 	public void setFontSize(Integer size)
 	{
 		setFontSize(size == null ? null : size.floatValue());
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getPdfFontName()
 	{
-		return JRStyleResolver.getPdfFontName(this);
+		return getStyleResolver().getPdfFontName(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getOwnPdfFontName()
 	{
 		return providerStyle == null || providerStyle.getOwnPdfFontName() == null ? ((JRFont)parent).getOwnPdfFontName() : providerStyle.getOwnPdfFontName();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setPdfFontName(String pdfFontName)
 	{
 		throw new UnsupportedOperationException();
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public String getPdfEncoding()
 	{
-		return JRStyleResolver.getPdfEncoding(this);
+		return getStyleResolver().getPdfEncoding(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public String getOwnPdfEncoding()
 	{
 		return providerStyle == null || providerStyle.getOwnPdfEncoding() == null ? ((JRFont)parent).getOwnPdfEncoding() : providerStyle.getOwnPdfEncoding();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setPdfEncoding(String pdfEncoding)
 	{
 		throw new UnsupportedOperationException();
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public boolean isPdfEmbedded()
 	{
-		return JRStyleResolver.isPdfEmbedded(this);
+		return getStyleResolver().isPdfEmbedded(this);
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public Boolean isOwnPdfEmbedded()
 	{
 		return providerStyle == null || providerStyle.isOwnPdfEmbedded() == null ? ((JRFont)parent).isOwnPdfEmbedded() : providerStyle.isOwnPdfEmbedded();
 	}
 
-	/**
-	 *
-	 */
+	@Override
 	public void setPdfEmbedded(boolean isPdfEmbedded)
 	{
 		throw new UnsupportedOperationException();
@@ -1019,24 +971,21 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	 * Alternative setPdfEmbedded method which allows also to reset
 	 * the "own" isPdfEmbedded property.
 	 */
+	@Override
 	public void setPdfEmbedded(Boolean isPdfEmbedded)
 	{
 		throw new UnsupportedOperationException();
 	}
 
 	
-	/**
-	 * 
-	 */
+	@Override
 	public Color getDefaultLineColor() 
 	{
 		return getForecolor();
 	}
 
 	
-	/**
-	 *
-	 */
+	@Override
 	public void setHeight(int height)
 	{
 		super.setHeight(height);
@@ -1045,6 +994,7 @@ public abstract class JRFillTextElement extends JRFillElement implements JRTextE
 	}
 
 
+	@Override
 	public void setWidth(int width)
 	{
 		super.setWidth(width);
