@@ -23,12 +23,9 @@
  */
 package net.sf.jasperreports.engine.fill;
 
-import java.util.Iterator;
-
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRExpression;
 import net.sf.jasperreports.engine.JRGroup;
-import net.sf.jasperreports.engine.JRPrintElement;
 import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JasperReport;
 import net.sf.jasperreports.engine.JasperReportsContext;
@@ -75,9 +72,7 @@ public class JRVerticalFiller extends JRBaseFiller
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected void setPageHeight(int pageHeight)
 	{
 		this.pageHeight = pageHeight;
@@ -110,9 +105,7 @@ public class JRVerticalFiller extends JRBaseFiller
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	protected synchronized void fillReport() throws JRException
 	{
 		setLastPageFooter(false);
@@ -2088,21 +2081,6 @@ public class JRVerticalFiller extends JRBaseFiller
 	}
 
 
-	/**
-	 *
-	 */
-	protected void fillBand(JRPrintBand band)
-	{
-		for(Iterator<JRPrintElement> it = band.iterateElements(); it.hasNext();)
-		{
-			JRPrintElement element = it.next();
-			element.setX(element.getX() + offsetX);
-			element.setY(element.getY() + offsetY);
-			printPage.addElement(element);
-		}
-	}
-
-
 	/**
 	 *
 	 */
