@@ -29,7 +29,9 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.JRCommonText;
 import net.sf.jasperreports.engine.JRParagraph;
 import net.sf.jasperreports.engine.JRPrintText;
@@ -46,9 +48,6 @@ import net.sf.jasperreports.engine.util.JRStringUtil;
 import net.sf.jasperreports.engine.util.JRStyledText;
 import net.sf.jasperreports.engine.util.ParagraphUtil;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 
 /**
  * Default text measurer implementation.
@@ -242,26 +241,31 @@ public class TextMeasurer implements JRTextMeasurer
 			this.saveLineBreakOffsets = saveLineBreakOffsets;
 		}
 		
+		@Override
 		public boolean isLeftToRight()
 		{
 			return isLeftToRight;
 		}
 		
+		@Override
 		public int getTextOffset()
 		{
 			return textOffset;
 		}
 		
+		@Override
 		public float getTextWidth()
 		{
 			return textWidth;
 		}
 		
+		@Override
 		public float getTextHeight()
 		{
 			return textHeight;
 		}
 		
+		@Override
 		public float getLineSpacingFactor()
 		{
 			if (isMeasured && lines > 0 && fontSizeSum > 0)
@@ -271,6 +275,7 @@ public class TextMeasurer implements JRTextMeasurer
 			return 0;
 		}
 		
+		@Override
 		public float getLeadingOffset()
 		{
 			if (isMeasured && lines > 0 && fontSizeSum > 0)
@@ -280,6 +285,7 @@ public class TextMeasurer implements JRTextMeasurer
 			return 0;
 		}
 
+		@Override
 		public String getTextSuffix()
 		{
 			return textSuffix;
@@ -322,6 +328,7 @@ public class TextMeasurer implements JRTextMeasurer
 			}
 		}
 		
+		@Override
 		public short[] getLineBreakOffsets()
 		{
 			if (!saveLineBreakOffsets)
@@ -415,14 +422,6 @@ public class TextMeasurer implements JRTextMeasurer
 		complextLineWrapper.init(measureContext);
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #TextMeasurer(JasperReportsContext, JRCommonText)}.
-	 */
-	public TextMeasurer(JRCommonText textElement)
-	{
-		this(DefaultJasperReportsContext.getInstance(), textElement);
-	}
-	
 	/**
 	 * 
 	 */
@@ -518,9 +517,7 @@ public class TextMeasurer implements JRTextMeasurer
 		
 	}
 
-	/**
-	 * 
-	 */
+	@Override
 	public JRMeasuredText measure(
 		JRStyledText styledText,
 		int remainingTextStart,
