@@ -30,7 +30,6 @@ import java.io.InputStreamReader;
 import java.io.OutputStream;
 import java.io.OutputStreamWriter;
 import java.io.Writer;
-import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
@@ -41,12 +40,6 @@ import javax.xml.parsers.DocumentBuilder;
 import javax.xml.parsers.DocumentBuilderFactory;
 import javax.xml.parsers.ParserConfigurationException;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
-import net.sf.jasperreports.engine.JRException;
-import net.sf.jasperreports.engine.JRRuntimeException;
-import net.sf.jasperreports.engine.JasperReportsContext;
-import net.sf.jasperreports.repo.RepositoryUtil;
-
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 import org.w3c.dom.Document;
@@ -58,6 +51,14 @@ import org.xml.sax.InputSource;
 import org.xml.sax.SAXException;
 import org.xml.sax.SAXParseException;
 
+import net.sf.jasperreports.engine.DefaultJasperReportsContext;
+import net.sf.jasperreports.engine.JRException;
+import net.sf.jasperreports.engine.JRRuntimeException;
+import net.sf.jasperreports.engine.JasperReportsContext;
+import net.sf.jasperreports.engine.util.JRXmlWriteHelper;
+import net.sf.jasperreports.repo.RepositoryUtil;
+import net.sf.jasperreports.util.StringBuilderWriter;
+
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
@@ -109,9 +110,15 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	private static final String NODE_export = "export";
 	private static final String NODE_locales = "locales";
 	private static final String NODE_locale = "locale";
+	private static final String NODE_includedScript = "includedScript";
+	private static final String NODE_excludedScript = "excludedScript";
+	private static final String NODE_fontSet = "fontSet";
+	private static final String NODE_family = "family";
 	private static final String ATTRIBUTE_name = "name";
 	private static final String ATTRIBUTE_visible = "visible";
 	private static final String ATTRIBUTE_key = "key";
+	private static final String ATTRIBUTE_familyName = "familyName";
+	private static final String ATTRIBUTE_primary = "primary";
 	
 	/**
 	 * Return a new instance.
@@ -160,13 +167,21 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	 *
 	 */
 	public List<FontFamily> loadFontFamilies(JasperReportsContext jasperReportsContext, String file)
+	{
+		FontExtensionsCollector collector = new FontExtensionsCollector();
+		loadFontExtensions(jasperReportsContext, file, collector);
+		return collector.getFontFamilies();
+	}
+	
+	public void loadFontExtensions(JasperReportsContext jasperReportsContext, String file,
+			FontExtensionsReceiver receiver)
 	{
 		InputStream is = null; 
 		
 		try
 		{
 			is = RepositoryUtil.getInstance(jasperReportsContext).getInputStreamFromLocation(file);
-			return loadFontFamilies(jasperReportsContext, is);
+			loadFontExtensions(jasperReportsContext, is, receiver);
 		}
 		catch (JRException e)
 		{
@@ -192,12 +207,18 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	 */
 	public List<FontFamily> loadFontFamilies(JasperReportsContext jasperReportsContext, InputStream is)
 	{
-		List<FontFamily> fontFamilies = null;
+		FontExtensionsCollector collector = new FontExtensionsCollector();
+		loadFontExtensions(jasperReportsContext, is, collector);
+		return collector.getFontFamilies();
+	}
 
+	public void loadFontExtensions(JasperReportsContext jasperReportsContext, InputStream is,
+			FontExtensionsReceiver receiver)
+	{
 		try
 		{
 			Document document = documentBuilder.parse(new InputSource(new InputStreamReader(is, "UTF-8")));
-			fontFamilies = parseFontFamilies(jasperReportsContext, document.getDocumentElement());
+			parseFontExtensions(jasperReportsContext, document.getDocumentElement(), receiver);
 		}
 		catch (SAXException e)
 		{
@@ -208,39 +229,32 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 		{
 			throw new JRRuntimeException(e);
 		}
-		
-		return fontFamilies;
-	}
-	
-	/**
-	 * @deprecated To be removed.
-	 */
-	public List<FontFamily> loadFontFamilies(InputStream is)
-	{
-		return loadFontFamilies(DefaultJasperReportsContext.getInstance(), is);
 	}
 
 	/**
 	 *
 	 */
-	private List<FontFamily> parseFontFamilies(JasperReportsContext jasperReportsContext, Node fontFamiliesNode) throws SAXException
+	private void parseFontExtensions(JasperReportsContext jasperReportsContext, Node fontFamiliesNode,
+			FontExtensionsReceiver receiver) throws SAXException
 	{
-		List<FontFamily> fontFamilies = new ArrayList<FontFamily>();
-		
 		NodeList nodeList = fontFamiliesNode.getChildNodes();
 		for(int i = 0; i < nodeList.getLength(); i++)
 		{
 			Node node = nodeList.item(i);
-			if (
-				node.getNodeType() == Node.ELEMENT_NODE
-				&& NODE_fontFamily.equals(node.getNodeName())
-				)
+			if (node.getNodeType() == Node.ELEMENT_NODE)
 			{
-				fontFamilies.add(parseFontFamily(jasperReportsContext, node));
+				if (NODE_fontFamily.equals(node.getNodeName()))
+				{
+					SimpleFontFamily fontFamily = parseFontFamily(jasperReportsContext, node);
+					receiver.acceptFontFamily(fontFamily);
+				}
+				else if (NODE_fontSet.equals(node.getNodeName()))
+				{
+					SimpleFontSet fontSet = parseFontSet(node);
+					receiver.acceptFontSet(fontSet);
+				}
 			}
 		}
-		
-		return fontFamilies;
 	}
 
 	/**
@@ -378,7 +392,7 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	/**
 	 *
 	 */
-	private Map<String,String> parseExportFonts(Node exportFontsNode) throws SAXException
+	private Map<String,String> parseExportFonts(Node exportFontsNode)
 	{
 		Map<String,String> exportFonts = new HashMap<String,String>();
 		
@@ -402,25 +416,92 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 		
 		return exportFonts;
 	}
+	
+	private SimpleFontSet parseFontSet(Node fontSetNode)
+	{
+		SimpleFontSet fontSet = new SimpleFontSet();
+		
+		NamedNodeMap nodeAttrs = fontSetNode.getAttributes();
+		if (nodeAttrs.getNamedItem(ATTRIBUTE_name) != null)
+		{
+			fontSet.setName(nodeAttrs.getNamedItem(ATTRIBUTE_name).getNodeValue());
+		}
+
+		NodeList nodeList = fontSetNode.getChildNodes();
+		for(int i = 0; i < nodeList.getLength(); i++)
+		{
+			Node node = nodeList.item(i);
+			if (node.getNodeType() == Node.ELEMENT_NODE)
+			{
+				if (NODE_family.equals(node.getNodeName()))
+				{
+					SimpleFontSetFamily family = parsetFontSetFamily(node);
+					fontSet.addFamily(family);
+				}
+				else if (NODE_exportFonts.equals(node.getNodeName()))
+				{
+					fontSet.setExportFonts(parseExportFonts(node));
+				}
+			}
+		}
+		
+		return fontSet;
+	}
+	
+	private SimpleFontSetFamily parsetFontSetFamily(Node familyNode)
+	{
+		SimpleFontSetFamily family = new SimpleFontSetFamily();
+		
+		NamedNodeMap nodeAttrs = familyNode.getAttributes();
+		if (nodeAttrs.getNamedItem(ATTRIBUTE_familyName) != null)
+		{
+			family.setFamilyName(nodeAttrs.getNamedItem(ATTRIBUTE_familyName).getNodeValue());
+		}
+		if (nodeAttrs.getNamedItem(ATTRIBUTE_primary) != null)
+		{
+			family.setPrimary(Boolean.parseBoolean(nodeAttrs.getNamedItem(ATTRIBUTE_primary).getNodeValue()));
+		}
+
+		NodeList nodeList = familyNode.getChildNodes();
+		for(int i = 0; i < nodeList.getLength(); i++)
+		{
+			Node node = nodeList.item(i);
+			if (node.getNodeType() == Node.ELEMENT_NODE)
+			{
+				if (NODE_includedScript.equals(node.getNodeName()))
+				{
+					family.addIncludedScript(node.getTextContent());
+				}
+				else if (NODE_excludedScript.equals(node.getNodeName()))
+				{
+					family.addExcludedScript(node.getTextContent());
+				}
+			}
+		}
+		
+		return family;
+	}
 
 	/**
 	 *
 	 */
 	public static String getFontsXml(List<FontFamily> fontFamilies)
 	{
-		StringBuffer buffer = null;
-		
 		if(fontFamilies != null)
 		{
-			buffer = new StringBuffer();
-			buffer.append("<?xml version=\"1.0\" encoding=\"" + DEFAULT_ENCODING + "\"?>\n");
-			buffer.append("<fontFamilies>\n");
-			for (FontFamily fontFamily : fontFamilies)
+			FontExtensionsContainer extensions = new SimpleFontExtensionsContainer(fontFamilies, null);
+			StringBuilder sb = new StringBuilder();
+			StringBuilderWriter writer = new StringBuilderWriter(sb);
+			try
 			{
-				writeFontFamily(buffer, fontFamily);
+				writeFontExtensions(writer, extensions);
 			}
-			buffer.append("</fontFamilies>\n");
-			return buffer.toString();
+			catch (IOException e)
+			{
+				//should not happen
+				throw new JRRuntimeException(e);
+			}
+			return sb.toString();
 		}
 		else
 		{
@@ -429,94 +510,119 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 		}
 	}
 
+	protected static void writeFontExtensions(Writer out, FontExtensionsContainer extensions) throws IOException
+	{
+		JRXmlWriteHelper writer = new JRXmlWriteHelper(out);
+		writer.writeProlog(DEFAULT_ENCODING);
+		
+		writer.startElement("fontFamilies");
+		
+		List<? extends FontFamily> fontFamilies = extensions.getFontFamilies();
+		if(fontFamilies != null)
+		{
+			for (FontFamily fontFamily : fontFamilies)
+			{
+				writeFontFamily(writer, fontFamily);
+			}
+		}
+		
+		List<? extends FontSet> fontSets = extensions.getFontSets();
+		if (fontSets != null)
+		{
+			for (FontSet fontSet : fontSets)
+			{
+				writeFontSet(writer, fontSet);
+			}
+		}
+
+		writer.closeElement();
+	}
+
 	/**
+	 * @throws IOException 
 	 *
 	 */
-	private static void writeFontFamily(StringBuffer buffer, FontFamily fontFamily) 
+	private static void writeFontFamily(JRXmlWriteHelper writer, FontFamily fontFamily) throws IOException 
 	{
-		if(fontFamily != null)
+		if (fontFamily != null)
 		{
-			if(fontFamily.getName() == null)
+			if (fontFamily.getName() == null)
 			{
 				log.error("Font family name is required.");
 				return;
 			}
 			
-			String indent = "  ";
-			buffer.append(indent + "<fontFamily name=\"" + fontFamily.getName() + "\""); 
-			if (!fontFamily.isVisible())
-			{
-				buffer.append(" visible=\"" + fontFamily.isVisible() + "\""); 
-			}
-			buffer.append(">\n");
-			indent = "    ";
+			writer.startElement(NODE_fontFamily);
+			writer.addAttribute(ATTRIBUTE_name, fontFamily.getName());
+			writer.addAttribute(ATTRIBUTE_visible, fontFamily.isVisible(), true);
 			
-			writeFontFace(buffer, fontFamily.getNormalFace(), NODE_normal);
-			writeFontFace(buffer, fontFamily.getBoldFace(), NODE_bold);
-			writeFontFace(buffer, fontFamily.getItalicFace(), NODE_italic);
-			writeFontFace(buffer, fontFamily.getBoldItalicFace(), NODE_boldItalic);
+			writeFontFace(writer, fontFamily.getNormalFace(), NODE_normal);
+			writeFontFace(writer, fontFamily.getBoldFace(), NODE_bold);
+			writeFontFace(writer, fontFamily.getItalicFace(), NODE_italic);
+			writeFontFace(writer, fontFamily.getBoldItalicFace(), NODE_boldItalic);
 
-			if(fontFamily.getPdfEncoding() != null)
+			if (fontFamily.getPdfEncoding() != null)
 			{
-				buffer.append(indent + "<pdfEncoding>" + fontFamily.getPdfEncoding() +"</pdfEncoding>\n");
+				writer.writeCDATAElement(NODE_pdfEncoding, fontFamily.getPdfEncoding());
 				
 			}
-			if(fontFamily.isPdfEmbedded() != null)
+			if (fontFamily.isPdfEmbedded() != null)
 			{
-				buffer.append(indent + "<pdfEmbedded>" + fontFamily.isPdfEmbedded() +"</pdfEmbedded>\n");
-				
+				//TODO lucianc we can do without CDATA here
+				writer.writeCDATAElement(NODE_pdfEmbedded, Boolean.toString(fontFamily.isPdfEmbedded()));
 			}
 			
-			if(fontFamily instanceof SimpleFontFamily)
+			if (fontFamily instanceof SimpleFontFamily)
 			{
 				SimpleFontFamily simpleFontFamily = (SimpleFontFamily)fontFamily;
 				
 				Map<String, String> exportFonts = simpleFontFamily.getExportFonts();
-				
-				if(exportFonts != null)
-				{
-					buffer.append(indent + "<exportFonts>\n");
-					indent = "      ";
-					for(String key : exportFonts.keySet())
-					{
-						buffer.append(indent + "<export key=\"" + key +"\">" + exportFonts.get(key) + "</export>\n");
-					}
-					indent = "    ";
-					buffer.append(indent + "</exportFonts>\n");
-				}
+				writeExportFonts(writer, exportFonts);
 				
 				Set<String> locales = simpleFontFamily.getLocales();
 				
-				if(locales != null)
+				if (locales != null)
 				{
-					buffer.append(indent + "<locales>\n");
-					indent = "      ";
+					writer.startElement(NODE_locales);
 					for(String locale : locales)
 					{
-						buffer.append(indent + "<locale>" + locale + "</locale>\n");
+						writer.writeCDATAElement(NODE_locale, locale);
 					}
-					indent = "    ";
-					buffer.append(indent + "</locales>\n");
+					writer.closeElement();
 				}
 			}
-			indent = "  ";
-			buffer.append(indent + "</fontFamily>\n\n");
+			writer.closeElement();
 		}		
 		else
 		{
 			log.info("Null font family encountered.");
 		}
 	}
+
+
+	protected static void writeExportFonts(JRXmlWriteHelper writer, 
+			Map<String, String> exportFonts) throws IOException
+	{
+		if(exportFonts != null)
+		{
+			writer.startElement(NODE_exportFonts);
+			for(String key : exportFonts.keySet())
+			{
+				writer.writeCDATAElement(NODE_export, exportFonts.get(key), ATTRIBUTE_key, key);
+			}
+			writer.closeElement();
+		}
+	}
 	
 
 
 	/**
+	 * @throws IOException 
 	 *
 	 */
-	private static void writeFontFace(StringBuffer buffer, FontFace fontFace, String faceTypeName) 
+	private static void writeFontFace(JRXmlWriteHelper writer, FontFace fontFace, String faceTypeName) throws IOException 
 	{
-		String indent = "    ";
-		if(fontFace != null)
+		if (fontFace != null)
 		{
 			if (
 				fontFace.getPdf() == null
@@ -527,37 +633,111 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 			{
 				if (fontFace.getTtf() != null)
 				{
-					buffer.append(indent + "<" + faceTypeName + ">"	+ fontFace.getTtf() + "</" + faceTypeName + ">\n");
+					writer.writeCDATAElement(faceTypeName, fontFace.getTtf());
 				}
 			}
 			else
 			{
-				buffer.append(indent + "<" + faceTypeName + ">\n");
+				writer.startElement(faceTypeName);
 				if (fontFace.getTtf() != null)
 				{
-					buffer.append(indent + "  <ttf>"	+ fontFace.getTtf() + "</ttf>\n");
+					writer.writeCDATAElement("ttf", fontFace.getTtf());
 				}
 				if (fontFace.getPdf() != null)
 				{
-					buffer.append(indent + "  <pdf>"	+ fontFace.getPdf() + "</pdf>\n");
+					writer.writeCDATAElement("pdf", fontFace.getPdf());
 				}
 				if (fontFace.getEot() != null)
 				{
-					buffer.append(indent + "  <eot>"	+ fontFace.getEot() + "</eot>\n");
+					writer.writeCDATAElement("eot", fontFace.getEot());
 				}
 				if (fontFace.getSvg() != null)
 				{
-					buffer.append(indent + "  <svg>"	+ fontFace.getSvg() + "</svg>\n");
+					writer.writeCDATAElement("svg", fontFace.getSvg());
 				}
 				if (fontFace.getWoff() != null)
 				{
-					buffer.append(indent + "  <woff>"	+ fontFace.getWoff() + "</woff>\n");
+					writer.writeCDATAElement("woff", fontFace.getWoff());
 				}
-				buffer.append(indent + "</" + faceTypeName + ">\n");
+				writer.closeElement();
 			}
 		}
 	}
 	
+	private static void writeFontSet(JRXmlWriteHelper writer, FontSet fontSet) throws IOException
+	{
+		if (fontSet == null)
+		{
+			log.info("Null font set encountered.");
+			return;
+		}
+		
+		if(fontSet.getName() == null)
+		{
+			log.error("Font set name is required.");
+			return;
+		}
+			
+		writer.startElement(NODE_fontSet);
+		writer.addAttribute(ATTRIBUTE_name, fontSet.getName());
+			
+		if(fontSet instanceof SimpleFontSet)
+		{
+			Map<String, String> exportFonts = ((SimpleFontSet) fontSet).getExportFonts();
+			writeExportFonts(writer, exportFonts);
+		}
+			
+		List<FontSetFamily> families = fontSet.getFamilies();
+		if (families != null)
+		{
+			for (FontSetFamily family : families)
+			{
+				writeFontSetFamily(writer, family);
+			}
+		}
+		
+		writer.closeElement();
+	}
+
+	private static void writeFontSetFamily(JRXmlWriteHelper writer, FontSetFamily family) throws IOException
+	{
+		if (family == null)
+		{
+			log.info("Null font set family encountered.");
+			return;
+		}
+		
+		if(family.getFamilyName() == null)
+		{
+			log.error("Font set name is required.");
+			return;
+		}
+		
+		writer.startElement(NODE_family);
+		writer.addAttribute(ATTRIBUTE_familyName, family.getFamilyName());
+		writer.addAttribute(ATTRIBUTE_primary, family.isPrimary(), false);
+		
+		List<String> includedScripts = family.getIncludedScripts();
+		if (includedScripts != null)
+		{
+			for (String script : includedScripts)
+			{
+				writer.writeCDATAElement(NODE_includedScript, script);
+			}
+		}
+		
+		List<String> excludedScripts = family.getExcludedScripts();
+		if (excludedScripts != null)
+		{
+			for (String script : excludedScripts)
+			{
+				writer.writeCDATAElement(NODE_excludedScript, script);
+			}
+		}
+		
+		writer.closeElement();
+	}
+
 
 	/**
 	 *
@@ -566,13 +746,22 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 		String destFileName,
 		List<FontFamily> fontFamilies
 		) throws JRException
+	{
+		FontExtensionsContainer extensions = new SimpleFontExtensionsContainer(fontFamilies, null);
+		writeFontExtensionsXml(destFileName, extensions);
+	}
+
+	public static void writeFontExtensionsXml(
+		String destFileName,
+		FontExtensionsContainer extensions
+		) throws JRException
 	{
 		FileOutputStream fos = null;
 
 		try
 		{
 			fos = new FileOutputStream(destFileName);
-			writeFontsXml(fos, fontFamilies);
+			writeFontExtensionsXml(fos, extensions);
 		}
 		catch (IOException e)
 		{
@@ -605,12 +794,21 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 		OutputStream outputStream,
 		List<FontFamily> fontFamilies
 		) throws JRException
+	{
+		FontExtensionsContainer extensions = new SimpleFontExtensionsContainer(fontFamilies, null);
+		writeFontExtensionsXml(outputStream, extensions);
+	}
+
+	public static void writeFontExtensionsXml(
+		OutputStream outputStream,
+		FontExtensionsContainer extensions
+		) throws JRException
 	{
 		Writer out = null;
 		try
 		{
 			out = new OutputStreamWriter(outputStream, DEFAULT_ENCODING);
-			out.write(getFontsXml(fontFamilies));
+			writeFontExtensions(out, extensions);
 			out.flush();
 		}
 		catch (Exception e)
@@ -751,22 +949,25 @@ public final class SimpleFontExtensionHelper implements ErrorHandler
 	}
 
 
+	@Override
 	public void error(SAXParseException e) {
-		if(log.isErrorEnabled())
+		if (log.isErrorEnabled())
 		{
 			log.error("Error parsing styled text.", e);
 		}
 	}
 
+	@Override
 	public void fatalError(SAXParseException e) {
-		if(log.isFatalEnabled())
+		if (log.isFatalEnabled())
 		{
 			log.fatal("Error parsing styled text.", e);
 		}
 	}
 
+	@Override
 	public void warning(SAXParseException e) {
-		if(log.isWarnEnabled())
+		if (log.isWarnEnabled())
 		{
 			log.warn("Error parsing styled text.", e);
 		}
