@@ -26,6 +26,7 @@ package net.sf.jasperreports.engine.query;
 import java.lang.reflect.Array;
 import java.lang.reflect.Constructor;
 import java.math.BigDecimal;
+import java.sql.CallableStatement;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.PreparedStatement;
@@ -37,10 +38,14 @@ import java.util.Collection;
 import java.util.Iterator;
 import java.util.Map;
 import java.util.TimeZone;
+import java.util.regex.Matcher;
+import java.util.regex.Pattern;
 
 import javax.sql.rowset.CachedRowSet;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRDataset;
 import net.sf.jasperreports.engine.JRException;
@@ -51,9 +56,6 @@ import net.sf.jasperreports.engine.JRRuntimeException;
 import net.sf.jasperreports.engine.JRValueParameter;
 import net.sf.jasperreports.engine.JasperReportsContext;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 
 /**
  * JDBC query executer for SQL queries.
@@ -100,6 +102,9 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	protected static final String CLOSE_CURSORS_AT_COMMIT = "close";
 	
 	protected static final String CACHED_ROWSET_CLASS = "com.sun.rowset.CachedRowSetImpl";
+	
+	protected static final Pattern PROCEDURE_CALL_PATTERN = Pattern.compile("\\s*\\{\\s*call\\s+", 
+			Pattern.MULTILINE | Pattern.CASE_INSENSITIVE);
 
 	protected Connection connection;
 	
@@ -117,6 +122,9 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	private TimeZone fieldsTimeZone;
 	private boolean fieldsTimeZoneOverride;
 	
+	private boolean isProcedureCall;
+	private ProcedureCallHandler procedureCallHandler;
+	
 	/**
 	 * 
 	 */
@@ -168,14 +176,6 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		parseQuery();		
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #JRJdbcQueryExecuter(JasperReportsContext, JRDataset, Map)}.
-	 */
-	public JRJdbcQueryExecuter(JRDataset dataset, Map<String,? extends JRValueParameter> parameters)
-	{
-		this(DefaultJasperReportsContext.getInstance(), dataset, parameters);
-	}
-
 	
 	/**
 	 * Registers built-in {@link JRClauseFunction clause functions}.
@@ -279,6 +279,7 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	}
 
 
+	@Override
 	protected String getParameterReplacement(String parameterName)
 	{
 		return "?";
@@ -288,6 +289,7 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	/* (non-Javadoc)
 	 * @see net.sf.jasperreports.engine.util.JRQueryExecuter#createDatasource()
 	 */
+	@Override
 	public JRDataSource createDatasource() throws JRException
 	{
 		JRResultSetDataSource dataSource = null;
@@ -298,39 +300,39 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		{
 			try
 			{
+				ResultSet queryResult;
+				if (isProcedureCall)
+				{
+					queryResult = procedureCallHandler.execute();
+				}
+				else
+				{
+					queryResult = statement.executeQuery();
+				}
+				
 				if(isCachedRowSet)
 				{
+					CachedRowSet cachedRowSet;
 					try
 					{
 						Class<? extends CachedRowSet> clazz = (Class<? extends CachedRowSet>)Class.forName(CACHED_ROWSET_CLASS);
 						Constructor<? extends CachedRowSet> constructor = clazz.getConstructor();
-						resultSet = constructor.newInstance();
+						cachedRowSet = constructor.newInstance();
 					}
 					catch (Exception e)
 					{
 						throw new JRException(e);
 					}
 					
-					((CachedRowSet)resultSet).populate(statement.executeQuery());
-					
-					try
-					{
-						statement.close();
-					}
-					catch (SQLException e)
-					{
-						if (log.isErrorEnabled())
-							log.error("Error while closing statement.", e);
-					}
-					finally
-					{
-						statement = null;
-					}
+					cachedRowSet.populate(queryResult);
+					closeStatement();
+					resultSet = cachedRowSet;
 				}
 				else
 				{
-					resultSet = statement.executeQuery();
+					resultSet = queryResult;
 				}
+				
 				dataSource = new JRResultSetDataSource(getJasperReportsContext(), resultSet);
 				dataSource.setTimeZone(fieldsTimeZone, fieldsTimeZoneOverride);
 				
@@ -364,13 +366,23 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		{
 			try
 			{
+				isProcedureCall = isProcedureCall(queryString);
+				CallableStatement callableStatement = null;
+				
 				String type = getPropertiesUtil().getProperty(dataset,	JRJdbcQueryExecuterFactory.PROPERTY_JDBC_RESULT_SET_TYPE);
 				String concurrency = getPropertiesUtil().getProperty(dataset, JRJdbcQueryExecuterFactory.PROPERTY_JDBC_CONCURRENCY);
 				String holdability = getPropertiesUtil().getProperty(dataset, JRJdbcQueryExecuterFactory.PROPERTY_JDBC_HOLDABILITY);
 				
 				if (type == null && concurrency == null && holdability == null)
 				{
-					statement = connection.prepareStatement(queryString);
+					if (isProcedureCall)
+					{
+						statement = callableStatement = connection.prepareCall(queryString);
+					}
+					else
+					{
+						statement = connection.prepareStatement(queryString);
+					}
 				}
 				else
 				{
@@ -379,22 +391,47 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 			
 					if (holdability == null)
 					{
-						statement = 
-							connection.prepareStatement(
-								queryString, 
-								getResultSetType(type), 
-								getConcurrency(concurrency)
-								);
+						if (isProcedureCall)
+						{
+							statement = callableStatement =
+									connection.prepareCall(
+										queryString, 
+										getResultSetType(type), 
+										getConcurrency(concurrency)
+										);
+						}
+						else
+						{
+							statement = 
+									connection.prepareStatement(
+										queryString, 
+										getResultSetType(type), 
+										getConcurrency(concurrency)
+										);
+						}
 					}
 					else
 					{
-						statement = 
-							connection.prepareStatement(
-								queryString, 
-								getResultSetType(type), 
-								getConcurrency(concurrency),
-								getHoldability(holdability, connection)
-								);
+						if (isProcedureCall)
+						{
+							statement = callableStatement =
+									connection.prepareCall(
+										queryString, 
+										getResultSetType(type), 
+										getConcurrency(concurrency),
+										getHoldability(holdability, connection)
+										);
+						}
+						else
+						{
+							statement = 
+									connection.prepareStatement(
+										queryString, 
+										getResultSetType(type), 
+										getConcurrency(concurrency),
+										getHoldability(holdability, connection)
+										);
+						}
 					}
 				}
 				
@@ -419,6 +456,11 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 				{
 					statement.setMaxRows(reportMaxCount.intValue());
 				}
+				
+				if (isProcedureCall)
+				{
+					initProcedureCall(callableStatement);
+				}
 
 				visitQueryParameters(new QueryParameterVisitor()
 				{
@@ -492,6 +534,24 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		}
 	}
 
+	protected boolean isProcedureCall(String queryString) throws SQLException
+	{
+		if (!OracleProcedureCallHandler.isOracle(connection))
+		{
+			//only supporting oracle for now
+			return false;
+		}
+		
+		Matcher matcher = PROCEDURE_CALL_PATTERN.matcher(queryString);
+		return matcher.find() && matcher.start() == 0;
+	}
+	
+	protected void initProcedureCall(CallableStatement callableStatement) throws SQLException
+	{
+		procedureCallHandler = new OracleProcedureCallHandler();
+		procedureCallHandler.init(callableStatement);
+	}
+
 
 	public ResultSet getResultSet() {
 		return resultSet;
@@ -697,6 +757,15 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		}
 		else
 		{
+			if (isProcedureCall)
+			{
+				boolean handled = procedureCallHandler.setParameterValue(parameterIndex, parameterType, parameterValue);
+				if (handled)
+				{
+					return;
+				}
+			}
+			
 			if (parameterValue == null)
 			{
 				statement.setNull(parameterIndex, Types.JAVA_OBJECT);
@@ -832,6 +901,7 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 	/* (non-Javadoc)
 	 * @see net.sf.jasperreports.engine.util.JRQueryExecuter#close()
 	 */
+	@Override
 	public synchronized void close()
 	{
 		if (resultSet != null)
@@ -852,24 +922,30 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		
 		if (statement != null)
 		{
-			try
-			{
-				statement.close();
-			}
-			catch (SQLException e)
-			{
-				log.error("Error while closing statement.", e);
-			}
-			finally
-			{
-				statement = null;
-			}
+			closeStatement();
+		}
+	}
+
+	protected void closeStatement()
+	{
+		try
+		{
+			statement.close();
+		}
+		catch (SQLException e)
+		{
+			log.error("Error while closing statement.", e);
+		}
+		finally
+		{
+			statement = null;
 		}
 	}
 	
 	/* (non-Javadoc)
 	 * @see net.sf.jasperreports.engine.util.JRQueryExecuter#cancelQuery()
 	 */
+	@Override
 	public synchronized boolean cancelQuery() throws JRException
 	{
 		if (statement != null)
@@ -902,7 +978,7 @@ public class JRJdbcQueryExecuter extends JRAbstractQueryExecuter
 		{
 			return ResultSet.TYPE_SCROLL_INSENSITIVE;
 		}
-		else if (TYPE_SCROLL_SENSITIVE.equals(TYPE_SCROLL_SENSITIVE))
+		else if (TYPE_SCROLL_SENSITIVE.equals(type))
 		{
 			return ResultSet.TYPE_SCROLL_SENSITIVE;
 		}
