@@ -23,6 +23,7 @@
  */
 package net.sf.jasperreports.export;
 
+import java.awt.Color;
 import java.util.Map;
 
 import net.sf.jasperreports.engine.JRPrintHyperlink;
@@ -297,14 +298,14 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	public static final String PROPERTY_SHEET_DIRECTION = JRXlsAbstractExporter.XLS_EXPORTER_PROPERTIES_PREFIX + "sheet.direction";
 
 	/**
-	 * Specifies the index of the first unlocked row in document's sheets. All rows above this will be 'frozen'. 
+	 * This property provides a default for the {@link #getFreezeRow()} exporter configuration setting. 
 	 * Allowed values are represented by positive integers in the 1..65536 range. Negative values are not considered. 
 	 * The property should be used when all sheets in the document have the same freeze row index.
 	 */
 	public static final String PROPERTY_FREEZE_ROW = JRXlsAbstractExporter.XLS_EXPORTER_PROPERTIES_PREFIX + "freeze.row";
 	
 	/**
-	 * Indicates the name of the first unlocked column in document's sheets. All columns to the left of this one will be 'frozen'. 
+	 * This property provides a default for the {@link #getFreezeColumn()} exporter configuration setting. 
 	 * Allowed values are letters or letter combinations representing valid column names in Excel, such as A, B, AB, AC, etc.
 	 * The property should be used when all document sheets have the same freeze column name.
 	 */
@@ -452,6 +453,26 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	public static final String PROPERTY_IGNORE_TEXT_FORMATTING = JRPropertiesUtil.PROPERTY_PREFIX + "export.xls.ignore.text.formatting";
 
+	/**
+	 * Property whose value is used as default state of the {@link #getSheetTabColor()} export configuration setting. 
+	 * <p/>
+	 * When set at report element level and multiple elements in a sheet provide this property, 
+	 * the last read value will be considered. The property works in XLSX and ODS output formats. 
+	 * It is not supported by the XLS output format.
+	 * <p/>
+	 * Property scope:
+	 * <ul>
+	 * <li><code>Global</code></li>
+	 * <li><code>Report</code></li>
+	 * <li><code>Element</code> - this setting can be used to set the property value per sheet.</li>
+	 * </ul>
+	 * Global settings are overriden by report level settings; report level settings are overriden by element (sheet) level settings.
+	 * 
+	 * @see JRPropertiesUtil
+	 */
+	public static final String PROPERTY_SHEET_TAB_COLOR = JRPropertiesUtil.PROPERTY_PREFIX + "export.xls.sheet.tab.color";
+
+		
 	/**
 	 * Returns a boolean value specifying whether each report page should be written in a different XLS sheet.
 	 * @see #PROPERTY_ONE_PAGE_PER_SHEET
@@ -808,7 +829,7 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	@ExporterProperty(
 		value=PROPERTY_FIT_WIDTH, 
-		acceptNull=true
+		nullDefault=true
 		)
 	public Integer getFitWidth();
 	
@@ -818,7 +839,7 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	@ExporterProperty(
 		value=PROPERTY_FIT_HEIGHT, 
-		acceptNull=true
+		nullDefault=true
 		)
 	public Integer getFitHeight();
 	
@@ -830,7 +851,7 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	@ExporterProperty(
 		value=PROPERTY_PAGE_SCALE, 
-		acceptNull=true
+		nullDefault=true
 		)
 	public Integer getPageScale();
 
@@ -857,7 +878,7 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	@ExporterProperty(
 		value=PROPERTY_COLUMN_WIDTH_RATIO,
-		acceptNull=true
+		nullDefault=true
 		)
 	public Float getColumnWidthRatio();
 	
@@ -887,7 +908,7 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 	 */
 	@ExporterProperty(
 		value=PROPERTY_FIRST_PAGE_NUMBER,
-		acceptNull=true
+		nullDefault=true
 		)
 	public Integer getFirstPageNumber();
 	
@@ -955,4 +976,41 @@ public interface XlsReportConfiguration extends ReportExportConfiguration
 		)
 	public Boolean isIgnoreTextFormatting();
 	
+	/**
+	 * This setting is used to set the tab color of the sheets. Global and  
+	 * report-level settings are overriden by element-level settings for this property.
+	 * If several elements in a sheet contain this property, the engine will consider the value of the 
+	 * last exported element's property.
+	 * <p/>
+	 * The setting is neglected in XLS export channel (works with XLSX and ODS only)
+	 * @see #PROPERTY_SHEET_TAB_COLOR
+	 */
+	@ExporterProperty(
+		value=PROPERTY_SHEET_TAB_COLOR, 
+		nullDefault=true
+		)
+	public Color getSheetTabColor();
+	
+	/**
+	 * Specifies the index of the first unlocked row in document's sheets. All rows above this will be 'frozen'. 
+	 * Allowed values are represented by positive integers in the 1..65536 range. Negative values are not considered. 
+	 * @see #PROPERTY_FREEZE_ROW
+	 */
+	@ExporterProperty(
+		value=PROPERTY_FREEZE_ROW, 
+		nullDefault=true
+		)
+	public Integer getFreezeRow();
+	
+	/**
+	 * Indicates the name of the first unlocked column in document's sheets. All columns to the left of this one will be 'frozen'. 
+	 * Allowed values are letters or letter combinations representing valid column names in Excel, such as A, B, AB, AC, etc.
+	 * @see #PROPERTY_FREEZE_COLUMN
+	 */
+	@ExporterProperty(
+		value=PROPERTY_FREEZE_COLUMN, 
+		nullDefault=true
+		)
+	public String getFreezeColumn();
+	
 }
