@@ -23,6 +23,7 @@
  */
 package net.sf.jasperreports.export;
 
+import net.sf.jasperreports.engine.export.XmlResourceHandler;
 
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
@@ -33,4 +34,9 @@ public interface XmlExporterOutput extends WriterExporterOutput
 	 * Returns a boolean value specifying whether images should be store internally or rather as files on disk.
 	 */
 	public Boolean isEmbeddingImages();
+
+	/**
+	 * 
+	 */
+	public XmlResourceHandler getImageHandler(); 
 }
