@@ -32,6 +32,10 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
+import antlr.ANTLRException;
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRDataset;
 import net.sf.jasperreports.engine.JRException;
@@ -57,11 +61,6 @@ import net.sf.jasperreports.olap.result.JROlapMemberTuple;
 import net.sf.jasperreports.olap.result.JROlapResult;
 import net.sf.jasperreports.olap.result.JROlapResultAxis;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
-import antlr.ANTLRException;
-
 
 /**
  * @author Lucian Chirita (lucianc@users.sourceforge.net)
@@ -131,6 +130,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 		}
 	}
 
+	@Override
 	public boolean next() throws JRException
 	{
 		boolean next;
@@ -236,6 +236,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 	 * @return value of field in the requested type
 	 *
 	 */
+	@Override
 	public Object getFieldValue(JRField jrField) throws JRException {
 		Class<?> valueClass = jrField.getValueClass();
 		Object value = fieldValues.get(jrField.getName());
@@ -446,6 +447,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 	}
 
 
+	@Override
 	public int getDimensionIndex(net.sf.jasperreports.olap.mapping.Axis axis, String dimension)
 	{
 		JROlapHierarchy[] hierarchies = axes[axis.getIdx()].getHierarchiesOnAxis();
@@ -483,6 +485,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 		return hierName.equals(hierarchy.getHierarchyUniqueName());
 	}
 
+	@Override
 	public int getLevelDepth(TuplePosition pos, String levelName)
 	{
 		JROlapHierarchy hierarchy = axes[pos.getAxis().getIdx()].getHierarchiesOnAxis()[pos.getIdx()];
@@ -551,6 +554,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 			this.property = mapping.getProperty();
 		}
 
+		@Override
 		public boolean matches()
 		{
 			member = member(memberInfo, axisPositions);
@@ -559,6 +563,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 			return member != null;
 		}
 
+		@Override
 		public Object value()
 		{
 			Object value;
@@ -646,6 +651,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 			}
 		}
 
+		@Override
 		public boolean matches()
 		{
 			if (dataPositions != null)
@@ -672,6 +678,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 			return matches;
 		}
 
+		@Override
 		public Object value()
 		{
 			JROlapCell cell = olapResult.getCell(positions);
@@ -713,6 +720,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 	}
 
 
+	@Override
 	public int getTuplePosition(int axisIndex, Tuple tuple)
 	{
 		if (axisIndex > axes.length)
@@ -753,7 +761,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 
 		if (pos == -1)
 		{
-			StringBuffer sb = new StringBuffer();
+			StringBuilder sb = new StringBuilder();
 			sb.append('(');
 			for (int i = 0; i < memberUniqueNames.length; i++)
 			{
@@ -763,6 +771,7 @@ public class JROlapDataSource implements JRDataSource, MappingMetadata
 				}
 				sb.append(memberUniqueNames[i]);
 			}
+			sb.append(')');
 			throw 
 				new JRRuntimeException(
 					EXCEPTION_MESSAGE_KEY_OLAP_TUPLE_NOT_FOUND,
