@@ -52,7 +52,9 @@ import javax.xml.transform.TransformerFactory;
 import javax.xml.transform.dom.DOMSource;
 import javax.xml.transform.stream.StreamResult;
 
-import net.sf.jasperreports.engine.DefaultJasperReportsContext;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.JRDataSource;
 import net.sf.jasperreports.engine.JRDataset;
 import net.sf.jasperreports.engine.JRException;
@@ -64,9 +66,6 @@ import net.sf.jasperreports.olap.JRMdxQueryExecuterFactory;
 import net.sf.jasperreports.olap.JROlapDataSource;
 import net.sf.jasperreports.olap.result.JROlapResult;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 
 /**
  * @author Michael Gunther (m.guenther at users.sourceforge.net)
@@ -114,20 +113,13 @@ public class JRXmlaQueryExecuter extends JRAbstractQueryExecuter
 		parseQuery();
 	}
 
-	/**
-	 * @deprecated Replaced by {@link #JRXmlaQueryExecuter(JasperReportsContext, JRDataset, Map)}.
-	 */
-	public JRXmlaQueryExecuter(JRDataset dataset, Map<String, ? extends JRValueParameter> parametersMap)
-	{
-		this(DefaultJasperReportsContext.getInstance(), dataset, parametersMap);
-	}
-
 	@Override
 	protected String getCanonicalQueryLanguage()
 	{
 		return JRMdxQueryExecuterFactory.CANONICAL_LANGUAGE;
 	}
 
+	@Override
 	protected String getParameterReplacement(String parameterName)
 	{
 		return String.valueOf(getParameterValue(parameterName));
@@ -159,6 +151,7 @@ public class JRXmlaQueryExecuter extends JRAbstractQueryExecuter
 		return xmlaResult;
 	}
 	
+	@Override
 	public JRDataSource createDatasource() throws JRException
 	{
 		getResult();
@@ -196,11 +189,13 @@ public class JRXmlaQueryExecuter extends JRAbstractQueryExecuter
 		return soapUrl;
 	}
 
+	@Override
 	public boolean cancelQuery() throws JRException
 	{
 		return false;
 	}
 
+	@Override
 	public void close()
 	{
 		if (connection != null)
@@ -538,7 +533,7 @@ public class JRXmlaQueryExecuter extends JRAbstractQueryExecuter
 
 	protected void handleResultFault(SOAPFault fault)
 	{
-		StringBuffer errorMsg = new StringBuffer();
+		StringBuilder errorMsg = new StringBuilder();
 		errorMsg.append("XML/A fault: ");
 		
 		String faultString = fault.getFaultString();
@@ -724,7 +719,7 @@ public class JRXmlaQueryExecuter extends JRAbstractQueryExecuter
 	{
 		SOAPElement errorElem = (SOAPElement) errorElems.next();
 		
-		StringBuffer errorMsg = new StringBuffer();
+		StringBuilder errorMsg = new StringBuilder();
 		errorMsg.append("Cell error: ");
 		
 		Iterator<?> descriptionElems = errorElem.getChildElements(sf.createName("Description", "", MDD_URI));
