@@ -57,7 +57,9 @@ import javax.swing.JPanel;
 import javax.swing.JViewport;
 import javax.swing.SwingUtilities;
 
-import net.sf.jasperreports.engine.ImageMapRenderable;
+import org.apache.commons.logging.Log;
+import org.apache.commons.logging.LogFactory;
+
 import net.sf.jasperreports.engine.JRConstants;
 import net.sf.jasperreports.engine.JRException;
 import net.sf.jasperreports.engine.JRPrintAnchorIndex;
@@ -74,17 +76,16 @@ import net.sf.jasperreports.engine.JasperPrintManager;
 import net.sf.jasperreports.engine.PrintPageFormat;
 import net.sf.jasperreports.engine.PrintPart;
 import net.sf.jasperreports.engine.PrintParts;
-import net.sf.jasperreports.engine.Renderable;
 import net.sf.jasperreports.engine.export.JRGraphics2DExporter;
 import net.sf.jasperreports.engine.type.HyperlinkTypeEnum;
 import net.sf.jasperreports.export.SimpleExporterInput;
 import net.sf.jasperreports.export.SimpleGraphics2DExporterOutput;
 import net.sf.jasperreports.export.SimpleGraphics2DReportConfiguration;
+import net.sf.jasperreports.renderers.AreaHyperlinksRenderable;
+import net.sf.jasperreports.renderers.Renderable;
+import net.sf.jasperreports.renderers.RenderersCache;
 import net.sf.jasperreports.view.JRHyperlinkListener;
 
-import org.apache.commons.logging.Log;
-import org.apache.commons.logging.LogFactory;
-
 /**
  * @author Teodor Danciu (teodord@users.sourceforge.net)
  */
@@ -138,6 +139,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	private MouseListener mouseListener =
 		new java.awt.event.MouseAdapter()
 		{
+			@Override
 			public void mouseClicked(java.awt.event.MouseEvent evt)
 			{
 				hyperlinkClicked(evt);
@@ -146,15 +148,18 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 	protected KeyListener keyNavigationListener = new KeyListener()
 	{
+		@Override
 		public void keyTyped(KeyEvent evt)
 		{
 		}
 
+		@Override
 		public void keyPressed(KeyEvent evt)
 		{
 			keyNavigate(evt);
 		}
 
+		@Override
 		public void keyReleased(KeyEvent evt)
 		{
 		}
@@ -193,12 +198,14 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 		setLayout(new java.awt.BorderLayout());
 		addComponentListener(new java.awt.event.ComponentAdapter() {
+			@Override
 			public void componentResized(java.awt.event.ComponentEvent evt) {
 				pnlMainComponentResized(evt);
 			}
 		});
 
 		pnlTabs.addChangeListener(new javax.swing.event.ChangeListener() {
+			@Override
 			public void stateChanged(javax.swing.event.ChangeEvent evt) {
 				pnlTabsStateChanged(evt);
 			}
@@ -222,14 +229,17 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		pnlLinks.setPreferredSize(new java.awt.Dimension(5, 5));
 		pnlLinks.setOpaque(false);
 		pnlLinks.addMouseListener(new java.awt.event.MouseAdapter() {
+			@Override
 			public void mousePressed(java.awt.event.MouseEvent evt) {
 				pnlLinksMousePressed(evt);
 			}
+			@Override
 			public void mouseReleased(java.awt.event.MouseEvent evt) {
 				pnlLinksMouseReleased(evt);
 			}
 		});
 		pnlLinks.addMouseMotionListener(new java.awt.event.MouseMotionAdapter() {
+			@Override
 			public void mouseDragged(java.awt.event.MouseEvent evt) {
 				pnlLinksMouseDragged(evt);
 			}
@@ -336,9 +346,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 	}
 
 
-	/**
-	 *
-	 */
+	@Override
 	public void gotoHyperlink(JRPrintHyperlink hyperlink)
 	{
 		switch(hyperlink.getHyperlinkTypeValue())
@@ -495,16 +503,27 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			}
 
 			exporter.setExporterInput(new SimpleExporterInput(viewerContext.getJasperPrint()));
-			SimpleGraphics2DExporterOutput output = new SimpleGraphics2DExporterOutput();
-			output.setGraphics2D((Graphics2D)grx.create());
-			exporter.setExporterOutput(output);
+
 			SimpleGraphics2DReportConfiguration configuration = new SimpleGraphics2DReportConfiguration();
 			configuration.setPageIndex(viewerContext.getPageIndex());
 			configuration.setZoomRatio(realZoom);
 			configuration.setOffsetX(1); //lblPage border
 			configuration.setOffsetY(1);
 			exporter.setConfiguration(configuration);
-			exporter.exportReport();
+
+			SimpleGraphics2DExporterOutput output = new SimpleGraphics2DExporterOutput();
+			Graphics2D g = (Graphics2D)grx.create();
+			output.setGraphics2D(g);
+			exporter.setExporterOutput(output);
+
+			try
+			{
+				exporter.exportReport();
+			}
+			finally
+			{
+				g.dispose();
+			}
 		}
 		catch(Exception e)
 		{
@@ -518,6 +537,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			paintPageError(grx);
 			SwingUtilities.invokeLater(new Runnable()
 			{
+				@Override
 				public void run()
 				{
 					JOptionPane.showMessageDialog(JRViewerPanel.this, viewerContext.getBundleString("error.displaying"));
@@ -529,7 +549,15 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 	protected JRGraphics2DExporter getGraphics2DExporter() throws JRException
 	{
-		return new JRGraphics2DExporter(viewerContext.getJasperReportsContext());
+		return 
+			new JRGraphics2DExporter(viewerContext.getJasperReportsContext())
+			{
+				@Override
+				protected RenderersCache getRenderersCache()
+				{
+					return viewerContext.getRenderersCache();
+				}
+			};
 	}
 
 	protected void paintPageError(Graphics2D grx)
@@ -568,6 +596,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		{
 		}
 
+		@Override
 		public void paintComponent(Graphics g)
 		{
 			if (isRenderImage())
@@ -576,7 +605,15 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			}
 			else
 			{
-				paintPage((Graphics2D)g.create());
+				Graphics2D grx = (Graphics2D)g.create();
+				try
+				{
+					paintPage(grx);
+				}
+				finally
+				{
+					grx.dispose();
+				}
 			}
 		}
 
@@ -711,11 +748,12 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				PrintParts parts = viewerContext.getJasperPrint().getParts();
 				Integer pageIndex = viewerContext.getPageIndex();
 				Integer partIndex = parts.getPartIndex(pageIndex);
+				Integer tabIndex = partIndex - (parts.startsAtZero() ? 1 : 0);
 				
-				if (partIndex < pnlTabs.getComponentCount())
+				if (tabIndex < pnlTabs.getComponentCount())
 				{
 					pnlTabsChangeListenerEnabled = false;
-					pnlTabs.setSelectedIndex(partIndex - (parts.startsAtZero() ? 1 : 0));
+					pnlTabs.setSelectedIndex(tabIndex);
 					((JPanel)pnlTabs.getSelectedComponent()).add(scrollPane);
 					pnlTabsChangeListenerEnabled = true;
 				}
@@ -858,12 +896,20 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 				BufferedImage.TYPE_INT_RGB
 				);
 		
-		Graphics2D grx = (Graphics2D) image.getGraphics();
 		AffineTransform transform = new AffineTransform();
 		transform.scale(realZoom, realZoom);
-		grx.transform(transform);
 
-		drawPageError(grx);
+		Graphics2D grx = (Graphics2D) image.getGraphics();
+		try
+		{
+			grx.transform(transform);
+
+			drawPageError(grx);
+		}
+		finally
+		{
+			grx.dispose();
+		}
 		
 		return image;
 	}
@@ -888,13 +934,13 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			{
 				JRPrintElement element = it.next();
 
-				ImageMapRenderable imageMap = null;
+				AreaHyperlinksRenderable imageMap = null;
 				if (element instanceof JRPrintImage)
 				{
-					Renderable renderer = ((JRPrintImage) element).getRenderable();
-					if (renderer instanceof ImageMapRenderable)
+					Renderable renderer = ((JRPrintImage) element).getRenderer();
+					if (renderer instanceof AreaHyperlinksRenderable)
 					{
-						imageMap = (ImageMapRenderable) renderer;
+						imageMap = (AreaHyperlinksRenderable) renderer;
 						if (!imageMap.hasImageAreaHyperlinks())
 						{
 							imageMap = null;
@@ -973,7 +1019,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 
 		protected final List<JRPrintImageAreaHyperlink> imageAreaHyperlinks;
 
-		public ImageMapPanel(Rectangle renderingArea, ImageMapRenderable imageMap)
+		public ImageMapPanel(Rectangle renderingArea, AreaHyperlinksRenderable imageMap)
 		{
 			try
 			{
@@ -988,6 +1034,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			addMouseMotionListener(this);
 		}
 
+		@Override
 		public String getToolTipText(MouseEvent event)
 		{
 			String tooltip = null;
@@ -1005,11 +1052,13 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			return tooltip;
 		}
 
+		@Override
 		public void mouseDragged(MouseEvent e)
 		{
 			pnlLinksMouseDragged(e);
 		}
 
+		@Override
 		public void mouseMoved(MouseEvent e)
 		{
 			JRPrintImageAreaHyperlink imageArea = getImageMapArea(e);
@@ -1046,6 +1095,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			return image;
 		}
 
+		@Override
 		public void mouseClicked(MouseEvent e)
 		{
 			JRPrintImageAreaHyperlink imageMapArea = getImageMapArea(e);
@@ -1055,20 +1105,24 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 			}
 		}
 
+		@Override
 		public void mouseEntered(MouseEvent e)
 		{
 		}
 
+		@Override
 		public void mouseExited(MouseEvent e)
 		{
 		}
 
+		@Override
 		public void mousePressed(MouseEvent e)
 		{
 			e.getComponent().setCursor(Cursor.getPredefinedCursor(Cursor.MOVE_CURSOR));
 			pnlLinksMousePressed(e);
 		}
 
+		@Override
 		public void mouseReleased(MouseEvent e)
 		{
 			e.getComponent().setCursor(Cursor.getDefaultCursor());
@@ -1269,6 +1323,7 @@ public class JRViewerPanel extends JPanel implements JRHyperlinkListener, JRView
 		}
 	}
 
+	@Override
 	public void viewerEvent(JRViewerEvent event)
 	{
 		switch (event.getCode())
